package com.qmth.sop.business.entity;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.qmth.sop.common.base.BaseEntity;
import com.qmth.sop.common.enums.ProductTypeEnum;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;

/**
 * <p>
 * 客户表
 * </p>
 *
 * @author wangliang
 * @since 2023-08-01
 */
@ApiModel(value="SysCustom对象", description="客户表")
public class SysCustom extends BaseEntity implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "名称")
    @NotBlank(message = "名称不能为空")
    private String name;

    @ApiModelProperty(value = "编码")
    private String code;

    @ApiModelProperty(value = "类型，OFFICE：教务处，CLOUD_MARK：研究生")
    private ProductTypeEnum type;

    @ApiModelProperty(value = "省份")
    @NotBlank(message = "省份不能为空")
    private String province;

    @ApiModelProperty(value = "城市")
    @NotBlank(message = "城市不能为空")
    private String city;

    @ApiModelProperty(value = "县区")
    private String area;

    @ApiModelProperty(value = "地址")
    private String address;

    @ApiModelProperty(value = "客户经理id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long managerId;

    @ApiModelProperty(value = "档位id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long levelId;

    @ApiModelProperty(value = "标准人天")
    private Integer peoperDay;

    @ApiModelProperty(value = "是否crm同步，0：否，1：是")
    @NotNull(message = "是否crm同步不能为空")
    private Boolean sync;

    @ApiModelProperty(value = "是否启用，0：停用，1：启用")
    @NotNull(message = "是否启用不能为空")
    private Boolean enable;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public ProductTypeEnum getType() {
        return type;
    }

    public void setType(ProductTypeEnum type) {
        this.type = type;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Long getManagerId() {
        return managerId;
    }

    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }

    public Long getLevelId() {
        return levelId;
    }

    public void setLevelId(Long levelId) {
        this.levelId = levelId;
    }

    public Integer getPeoperDay() {
        return peoperDay;
    }

    public void setPeoperDay(Integer peoperDay) {
        this.peoperDay = peoperDay;
    }

    public Boolean getSync() {
        return sync;
    }

    public void setSync(Boolean sync) {
        this.sync = sync;
    }

    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }
}
