package com.qmth.sop.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.boot.api.exception.ApiException;
import com.qmth.sop.business.bean.dto.SopCrmInfo;
import com.qmth.sop.business.bean.dto.UserArchivesDto;
import com.qmth.sop.business.bean.params.ServiceScopeParam;
import com.qmth.sop.business.bean.result.*;
import com.qmth.sop.business.entity.*;
import com.qmth.sop.business.mapper.TBCrmMapper;
import com.qmth.sop.business.service.*;
import com.qmth.sop.common.contant.SystemConstant;
import com.qmth.sop.common.enums.*;
import com.qmth.sop.common.util.ResultUtil;
import com.qmth.sop.common.util.ServletUtil;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * <p>
 * 派单信息表 服务实现类
 * </p>
 *
 * @author wangliang
 * @since 2023-08-01
 */
@Service
public class TBCrmServiceImpl extends ServiceImpl<TBCrmMapper, TBCrm> implements TBCrmService {
    @Resource
    private TBServiceService tbServiceService;
    @Resource
    private TBUserArchivesAllocationService tbUserArchivesAllocationService;
    @Resource
    private SysRoleService sysRoleService;
    @Resource
    private TBUserArchivesService tbUserArchivesService;
    @Resource
    private TBServiceRegionService tbServiceRegionService;

    @Override
    public IPage<CrmServiceResult> findServiceScopePage(Long serviceUnitId, String city, ProductTypeEnum productType, String customName, Boolean bindStatus, Integer pageNumber, Integer pageSize) {
        if (city != null && city.length() > 0) {
            city = SystemConstant.translateSpecificSign(city);
        }
        if (customName != null && customName.length() > 0) {
            customName = SystemConstant.translateSpecificSign(customName);
        }
        return this.baseMapper.findServiceScopePage(new Page<>(pageNumber, pageSize), serviceUnitId, city, productType, customName, bindStatus);
    }

    @Override
    public IPage<CrmServiceResult> findUnbindOrderPage(Long crmUserId, ProductTypeEnum productType, String customName, String crmNo, Long startTime, Long endTime, Integer pageNumber, Integer pageSize) {
        if (customName != null && customName.length() > 0) {
            customName = SystemConstant.translateSpecificSign(customName);
        }
        if (crmNo != null && crmNo.length() > 0) {
            crmNo = SystemConstant.translateSpecificSign(crmNo);
        }
        return this.baseMapper.findUnbindOrderPage(new Page<>(pageNumber, pageSize), crmUserId, productType, customName, crmNo, startTime, endTime);
    }

    @Override
    public List<CrmServiceResult> findCrmOrderByServiceIdList(List<Long> serviceIdList) {
        return this.baseMapper.findOrderListByServiceIds(serviceIdList);
    }

    @Transactional
    @Override
    public void bindCrmWithServiceBatch(ServiceScopeParam serviceScopeParam) {
        List<Long> crmIdList = serviceScopeParam.getCrmIdList();
        Long serviceUnitId = serviceScopeParam.getServiceUnitId();
        if (CollectionUtils.isEmpty(crmIdList)) {
            throw ExceptionResultEnum.ERROR.exception("未选择要划定的派单");
        }

        TBService tbService = tbServiceService.getById(serviceUnitId);
        if (Objects.isNull(tbService) || !tbService.getEnable()) {
            throw ExceptionResultEnum.ERROR.exception("服务单元不存在");
        } else {
            ServiceStatusEnum status = tbService.getStatus();
            if (ServiceStatusEnum.FINISH.equals(status) || ServiceStatusEnum.CANCEL.equals(status)) {
                throw ExceptionResultEnum.ERROR.exception("不能划定进已完结或已作废的服务单元");
            }
        }
        List<TBCrm> tbCrmList = this.listByIds(crmIdList);
        tbCrmList = tbCrmList.stream().peek(e -> {
            Long regionLeaderId = tbServiceRegionService.findRegionLeader(serviceUnitId, e.getCrmNo());
            if (Objects.nonNull(regionLeaderId)) {
                e.setLeadId(regionLeaderId);
            }
            e.setServiceId(serviceUnitId);
        }).collect(Collectors.toList());
        this.updateBatchById(tbCrmList);
    }

    @Transactional
    @Override
    public void unbindCrmWithService(Long crmId) {
        TBCrm tbCrm = this.getById(crmId);
        if (Objects.isNull(tbCrm)) {
            throw ExceptionResultEnum.ERROR.exception("未找到派单信息");
        }
        Long serviceUnitId = tbCrm.getServiceId();
        TBService tbService = tbServiceService.getById(serviceUnitId);
        if (Objects.nonNull(tbService)) {
            ServiceStatusEnum status = tbService.getStatus();
            if (ServiceStatusEnum.FINISH.equals(status)) {
                throw ExceptionResultEnum.ERROR.exception("服务单元的当前状态更新为" + ServiceStatusEnum.FINISH.name() + "不允许移除");
            }
        }
        UpdateWrapper<TBCrm> updateWrapper = new UpdateWrapper<>();
        updateWrapper.lambda()
                .set(TBCrm::getServiceId, null)
                .set(TBCrm::getLeadId, null)
                .eq(TBCrm::getId, tbCrm.getId());
        this.update(updateWrapper);
    }

    @Override
    public CrmSubTotalResult findCrmSubTotalData() {
        List<TBCrm> tbCrmList = this.list(new QueryWrapper<TBCrm>().lambda().eq(TBCrm::getEnable, true));
        int totalCrmCount = tbCrmList.size();
        int bindCrmCount = 0;
        int unbindCrmCount = 0;
        if (totalCrmCount > 0) {
            bindCrmCount = (int) tbCrmList.stream().filter(e -> e.getServiceId() != null).count();
            unbindCrmCount = (int) tbCrmList.stream().filter(e -> e.getServiceId() == null).count();
        }
        CrmSubTotalResult crmSubTotalResult = new CrmSubTotalResult();
        crmSubTotalResult.setTotalCrmCount(totalCrmCount);
        crmSubTotalResult.setBindCrmCount(bindCrmCount);
        crmSubTotalResult.setUnbindCrmCount(unbindCrmCount);
        return crmSubTotalResult;
    }

    @Override
    public TBCrm findByCrmNo(String crmNo) {
        List<TBCrm> tbCrmList = this.list(new QueryWrapper<TBCrm>().lambda().eq(TBCrm::getCrmNo, crmNo));
        if (CollectionUtils.isEmpty(tbCrmList)) {
            throw ExceptionResultEnum.ERROR.exception("派单不存在[" + crmNo + "]");
        }
        if (tbCrmList.size() > 1) {
            throw ExceptionResultEnum.ERROR.exception("有重复派单号[" + crmNo + "]");
        }
        return tbCrmList.get(0);
    }

    @Override
    public IPage<TBCrmResult> query(IPage<Map> iPage, Long serviceId, Long leadId, Long crmUserId, ProductTypeEnum type, String custom, String crmNo, Long startTime, Long endTime) {
        return this.baseMapper.query(iPage, serviceId, leadId, crmUserId, Objects.nonNull(type) ? type.name() : null, custom, crmNo, startTime, endTime);
    }


    /**
     * 新增修改派单信息表
     *
     * @param tBCrm
     */
    @Override
    @Transactional
    public Boolean saveTBCrm(TBCrm tBCrm) {
        try {
            tBCrm.setSync(false);
            tBCrm.setEnable(true);
            SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
            if (Objects.isNull(tBCrm.getId())) {// 新增
                tBCrm.setStatus(CrmStatusEnum.UN_PUBLISH);
                tBCrm.insertInfo(sysUser.getId());
            } else { // 修改
                tBCrm.updateInfo(sysUser.getId());
            }
            return saveOrUpdate(tBCrm);
        } catch (Exception e) {
            if (e instanceof DuplicateKeyException) {
                String errorColumn = e.getCause().toString();
                String columnStr = errorColumn.substring(errorColumn.lastIndexOf("key") + 3, errorColumn.length()).replaceAll("'", "");
                throw ExceptionResultEnum.SQL_ERROR.exception("[" + FieldUniqueEnum.convertToTitle(columnStr) + "]数据不允许重复插入");
            } else if (e instanceof ApiException) {
                ResultUtil.error((ApiException) e, e.getMessage());
            } else {
                ResultUtil.error(e.getMessage());
            }
        }
        return null;

    }

    /**
     * 删除派单信息表
     *
     * @param id
     */
    @Override
    @Transactional
    public Boolean delete(Long id) {
        return this.removeById(id);
    }

    @Override
    @Transactional
    public boolean batchZone(long serviceId, long[] crmIds) {
        List<Long> crmIdList = Arrays.stream(crmIds).boxed().collect(Collectors.toList());
        List<TBCrm> tbCrmList = this.listByIds(crmIdList);
        tbCrmList.forEach(e -> {
            Long regionLeaderId = tbServiceRegionService.findRegionLeader(serviceId, e.getCrmNo());
            if (Objects.nonNull(regionLeaderId)) {
                e.setLeadId(regionLeaderId);
            }
            e.setServiceId(serviceId);
        });
        return this.updateBatchById(tbCrmList);
    }

    @Override
    @Transactional
    public boolean batchDisable(long[] crmIds) {
        //批量修改
        List<Long> crmIdList = Arrays.stream(crmIds).boxed().collect(Collectors.toList());
        List<TBCrm> tbCrmList = this.listByIds(crmIdList);
        tbCrmList.forEach(e -> e.setEnable(false));
        return this.updateBatchById(tbCrmList);
    }

    @Override
    public CrmProjectResult findCrmProjectBySopNoOrCrmNo(String sopNo, String crmNo) {
        CrmProjectResult result = new CrmProjectResult();
        List<CrmProjectResult> crmProjectResults;
        if (sopNo != null && sopNo.length() > 0) {
            crmProjectResults = this.baseMapper.findCrmProjectBySopNo(sopNo);
        } else if (crmNo != null && crmNo.length() > 0) {
            crmProjectResults = this.baseMapper.findCrmProjectByCrmNo(crmNo);
        } else {
            throw ExceptionResultEnum.ERROR.exception("缺少sop单号和crm单号");
        }
        if (CollectionUtils.isNotEmpty(crmProjectResults)) {
            if (crmProjectResults.size() > 1) {
                throw ExceptionResultEnum.ERROR.exception("根据sop号找到多个与之对应的派单异常");
            }
            CrmProjectResult crmProjectResult = crmProjectResults.get(0);
            String tbCrmNo = crmProjectResult.getCrmNo();

            List<TBUserArchivesAllocation> archivesAllocationList = tbUserArchivesAllocationService.list(new QueryWrapper<TBUserArchivesAllocation>()
                    .lambda().eq(TBUserArchivesAllocation::getCrmNo, tbCrmNo));

            RoleResult effectRole = sysRoleService.findRoleInfoByArchivesType(RoleTypeEnum.EFFECT_ENGINEER);
            Long effectRoleId = effectRole.getRoleId();

            List<UserArchivesDto> effectEngineerList = archivesAllocationList.stream()
                    .filter(e -> effectRoleId.equals(e.getRoleId()))
                    .flatMap(e -> {
                        UserArchivesDto dto = new UserArchivesDto();
                        Long userArchivesId = e.getArchivesId();
                        dto.setUserArchivesId(userArchivesId);
                        dto.setUserId(e.getUserId());
                        dto.setName(tbUserArchivesService.getById(userArchivesId).getName());
                        return Stream.of(dto);
                    }).collect(Collectors.toList());

            RoleResult assistant = sysRoleService.findRoleInfoByArchivesType(RoleTypeEnum.ASSISTANT_ENGINEER);
            Long assistantRoleId = assistant.getRoleId();
            List<UserArchivesDto> assistantEngineerList = archivesAllocationList.stream()
                    .filter(e -> assistantRoleId.equals(e.getRoleId()))
                    .flatMap(e -> {
                        UserArchivesDto dto = new UserArchivesDto();
                        Long userArchivesId = e.getArchivesId();
                        dto.setUserArchivesId(userArchivesId);
                        dto.setUserId(e.getUserId());
                        dto.setName(tbUserArchivesService.getById(userArchivesId).getName());
                        return Stream.of(dto);
                    }).collect(Collectors.toList());
            crmProjectResult.setEffectEngineerList(effectEngineerList);
            crmProjectResult.setAssistantEngineerList(assistantEngineerList);
            result = crmProjectResult;
        }
        return result;
    }


    @Override
    public SopCrmInfo findSopCrmInfoBySop(String sopNo) {
        List<SopCrmInfo> sopCrmInfoList = this.baseMapper.findSopCrmInfoBySopNo(sopNo);
        if (CollectionUtils.isEmpty(sopCrmInfoList)) {
            throw ExceptionResultEnum.ERROR.exception(String.format("未找到sop单号为[%s]的派单信息", sopNo));
        } else if (sopCrmInfoList.size() > 1) {
            throw ExceptionResultEnum.ERROR.exception(String.format("sop单号为[%s]的派单信息异常", sopNo));
        }
        return sopCrmInfoList.get(0);
    }

    @Override
    public TBCrm findOccupiedCrm(Long userId, Long userArchivesId) {
        TBCrm result = null;
        List<TBCrm> tbCrmList = this.baseMapper.findOccupiedCrm(userId, userArchivesId);
        if (CollectionUtils.isNotEmpty(tbCrmList)) {
            if (tbCrmList.size() > 1) {
                throw ExceptionResultEnum.ERROR.exception("被多个派单占用异常");
            }
            result = tbCrmList.get(0);
        }
        return result;
    }

    @Transactional
    @Override
    public void updateCrmStatus(String crmNo, CrmStatusEnum status) {
        TBCrm tbCrm = this.findByCrmNo(crmNo);
        switch (status) {
            case UN_PUBLISH: // 撤回
                tbCrm.setStatus(CrmStatusEnum.UN_PUBLISH);
                break;
            case PUBLISH: // 发布
                tbCrm.setStatus(CrmStatusEnum.PUBLISH);
                break;
            case FINISH: // 完结
                tbCrm.setStatus(CrmStatusEnum.FINISH);
                // crm完结 释放工程师资源
                List<CrmArchivesAllocationResult> crmArchivesAllocationResultList = tbUserArchivesAllocationService.findAllocationByCrmNo(crmNo);
                List<Long> engineerArchivesIdList = crmArchivesAllocationResultList
                        .stream()
                        .filter(e -> !RoleTypeEnum.REGION_COORDINATOR.equals(e.getType()))
                        .map(CrmArchivesAllocationResult::getArchivesId)
                        .distinct()
                        .collect(Collectors.toList());

                if (CollectionUtils.isNotEmpty(engineerArchivesIdList)) {
                    UpdateWrapper<TBUserArchives> updateWrapper = new UpdateWrapper<>();
                    updateWrapper.lambda()
                            .set(TBUserArchives::getStatus, UserArchivesStatusEnum.FREE)
                            .in(TBUserArchives::getId, engineerArchivesIdList);
                    tbUserArchivesService.update(updateWrapper);
                }
                break;
        }
        this.updateById(tbCrm);
    }

    @Override
    public List<TBCrm> findByTBCrmListByServiceUnitIdAndAddress(Long serviceUnitId, String province, String city) {
        return this.baseMapper.findByTBCrmListByServiceUnitIdAndAddress(serviceUnitId, province, city);
    }
}
