package com.qmth.sop.business.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.sop.business.activiti.service.ActivitiService;
import com.qmth.sop.business.bean.params.*;
import com.qmth.sop.business.bean.result.CrmProjectResult;
import com.qmth.sop.business.bean.result.FlowFormWidgetResult;
import com.qmth.sop.business.bean.result.FlowResult;
import com.qmth.sop.business.bean.result.FlowTaskResult;
import com.qmth.sop.business.entity.*;
import com.qmth.sop.business.mapper.TBSopInfoMapper;
import com.qmth.sop.business.service.*;
import com.qmth.sop.common.contant.SystemConstant;
import com.qmth.sop.common.enums.*;
import com.qmth.sop.common.util.JacksonUtil;
import com.qmth.sop.common.util.ServletUtil;
import org.activiti.engine.TaskService;
import org.activiti.engine.task.IdentityLink;
import org.activiti.engine.task.Task;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.*;

/**
 * <p>
 * sop表 服务实现类
 * </p>
 *
 * @author wangliang
 * @since 2023-08-01
 */
@Service
public class TBSopInfoServiceImpl extends ServiceImpl<TBSopInfoMapper, TBSopInfo> implements TBSopInfoService {

    @Resource
    TBSopInfoMapper tbSopInfoMapper;

    @Resource
    ActivitiService activitiService;

    @Resource
    TFCustomFlowEntityService tfCustomFlowEntityService;

    @Resource
    TaskService taskService;

    @Resource
    TBSopInfoDetailService tbSopInfoDetailService;

    @Resource
    TBSopInfoService tbSopInfoService;

    @Resource
    TBCrmService tbCrmService;

    @Resource
    TFCustomFlowService tfCustomFlowService;

    @Resource
    TSJobRemindService tsJobRemindService;

    @Resource
    TFFlowApproveService tfFlowApproveService;

    /**
     * 查询动态sop表名是否存在
     *
     * @param db
     * @param tableName
     * @return
     */
    @Override
    public int selectSopDynamicExist(String db, String tableName) {
        return this.baseMapper.selectSopDynamicExist(db, tableName);
    }

    /**
     * 保存动态sop信息
     *
     * @param tfCustomFlow
     * @param code
     * @param flowId
     * @param flowTaskResult
     * @return
     */
    @Override
    @Transactional
    public Boolean saveDynamicSop(TFCustomFlow tfCustomFlow, String code, Long flowId, FlowTaskResult flowTaskResult) {
        String tableName = tfCustomFlow.getType().getTableName() + "_" + tfCustomFlow.getVersion();
        List<FlowFormWidgetResult> flowFormWidgetResultList = flowTaskResult.getFormProperty();
        Map<String, String> formFieldMap = new HashMap<>(flowFormWidgetResultList.size());
        for (FlowFormWidgetResult f : flowFormWidgetResultList) {
            if (f.getCode() != WidgetCodeEnum.FORM_GROUP_TITLE && f.getCode() != WidgetCodeEnum.ONLE_TITLE
                    && f.getCode() != WidgetCodeEnum.BUTTON && f.getCode() != WidgetCodeEnum.IMG
                    && f.getCode() != WidgetCodeEnum.LABEL && f.getCode() != WidgetCodeEnum.SIGN
                    && f.getCode() != WidgetCodeEnum.OTHER) {
                if (Objects.nonNull(f.getValue()) && f.getValue().startsWith("[") && f.getValue().endsWith("]")) {
                    f.setValue(f.getValue().replaceAll("\\[", "").replaceAll("\\]", ""));
                    formFieldMap.put(f.getFormId(), StringUtils.join(Arrays.asList(f.getValue()), SystemConstant.LIST_JOIN_SPLIT));
                } else {
                    if (Objects.nonNull(f.getValue()) && !Objects.equals(f.getValue(), "null")) {
                        formFieldMap.put(f.getFormId(), f.getValue());
                    }
                }
            }
        }
        //首先查询动态表里是否有当前表单的数据，没有插入，有则更新
        int count = this.selectDynamicSop(tableName, tfCustomFlow.getFlowDeploymentId(), flowId);
        if (count == 0) {//插入操作
            //查询所有列
            List<Map<String, String>> dynamicFieldList = this.baseMapper.selectDynamicSopAll(tableName);
            Map<String, Object> map = new LinkedHashMap<>();
            if (!CollectionUtils.isEmpty(dynamicFieldList)) {
                StringJoiner stringJoinerFieldName = new StringJoiner(",");
                StringJoiner stringJoinerFieldValue = new StringJoiner(",");
                for (Map<String, String> m : dynamicFieldList) {
                    for (Map.Entry<String, String> entry : m.entrySet()) {
                        switch (entry.getValue()) {
                            case SystemConstant.TYPE:
                                map.put(entry.getValue(), tfCustomFlow.getType());
                                break;
                            case SystemConstant.FLOW_DEPLOYMENT_ID_FIELD:
                                map.put(entry.getValue(), tfCustomFlow.getFlowDeploymentId());
                                break;
                            case SystemConstant.VERSION:
                                map.put(entry.getValue(), tfCustomFlow.getVersion());
                                break;
                            case SystemConstant.CODE:
                                map.put(entry.getValue(), code);
                                break;
                            case SystemConstant.FLOW_ID:
                                map.put(entry.getValue(), flowId);
                                break;
                            default:
                                if (formFieldMap.containsKey(entry.getValue())) {
                                    map.put(entry.getValue(), formFieldMap.get(entry.getValue()));
                                } else {
                                    map.put(entry.getValue(), null);
                                }
                                break;
                        }
                    }
                }
                for (Map.Entry<String, Object> entry : map.entrySet()) {
                    stringJoinerFieldName.add(entry.getKey());
                    stringJoinerFieldValue.add(Objects.nonNull(entry.getValue()) ? "'" + entry.getValue().toString() + "'" : null);
                }
                tbSopInfoMapper.saveDynamicSop(tableName, stringJoinerFieldName.toString(), stringJoinerFieldValue.toString());
            }
        } else {//否则更新
            if (!CollectionUtils.isEmpty(formFieldMap)) {
                StringJoiner stringJoinerFieldValue = new StringJoiner(",");
                for (Map.Entry<String, String> entry : formFieldMap.entrySet()) {
                    stringJoinerFieldValue.add(entry.getKey() + "='" + entry.getValue() + "'");
                }
                tbSopInfoMapper.updateDynamicSop(tableName, tfCustomFlow.getFlowDeploymentId(), flowId, stringJoinerFieldValue.toString());
            }
        }
        return true;
    }

    /**
     * 查询动态sop数据
     *
     * @param tableName
     * @param flowDeploymentId
     * @param flowId
     * @return
     */
    @Override
    public int selectDynamicSop(String tableName, String flowDeploymentId, Long flowId) {
        return this.baseMapper.selectDynamicSop(tableName, flowDeploymentId, flowId);
    }

    /**
     * sop发布信息
     *
     * @param sopPublishParam
     * @return
     * @throws InterruptedException
     */
    @Override
    @Transactional
    public Boolean sopPublish(SopPublishParam sopPublishParam) throws InterruptedException {
        Optional.ofNullable(sopPublishParam.getCrmNo()).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("crm编号不能为空"));
        if (sopPublishParam.getApprove() != FlowApprovePassEnum.DRAFT) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("sop发布只能为草稿");
        }
        return tbSopInfoService.sopApplyOrPublish(sopPublishParam.getSopNo(), sopPublishParam.getCrmNo(), sopPublishParam.getFlowDeploymentId(), sopPublishParam.getApprove(), sopPublishParam.getFormProperties());
    }

    /**
     * sop申请信息
     *
     * @param sopApplyParam
     * @return
     */
    @Override
    @Transactional
    public Boolean sopApply(SopApplyParam sopApplyParam) throws InterruptedException {
        Optional.ofNullable(sopApplyParam.getCrmNo()).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("crm编号不能为空"));
        if (sopApplyParam.getApprove() != FlowApprovePassEnum.START && sopApplyParam.getApprove() != FlowApprovePassEnum.DRAFT) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("sop申请只能为提交或草稿");
        }
        return tbSopInfoService.sopApplyOrPublish(sopApplyParam.getSopNo(), sopApplyParam.getCrmNo(), sopApplyParam.getFlowDeploymentId(), sopApplyParam.getApprove(), sopApplyParam.getFormProperties());
    }

    /**
     * sop填报信息
     *
     * @param flowApproveParam
     * @return
     */
    @Override
    @Transactional
    public Boolean sopApprove(FlowApproveParam flowApproveParam) throws InterruptedException {
        Optional.ofNullable(flowApproveParam.getTaskId()).orElseThrow(() -> ExceptionResultEnum.FLOW_TASK_ID_IS_NULL.exception());
        if (flowApproveParam.getApprove() != FlowApprovePassEnum.PASS && flowApproveParam.getApprove() != FlowApprovePassEnum.REJECT && flowApproveParam.getApprove() != FlowApprovePassEnum.DRAFT) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("sop填报只能为通过或驳回或草稿");
        }
        Optional.ofNullable(flowApproveParam.getFormProperties()).orElseThrow(() -> ExceptionResultEnum.FLOW_FORM_PROPERTIES_IS_NULL.exception());
        if (flowApproveParam.getApprove() == FlowApprovePassEnum.REJECT && Objects.isNull(flowApproveParam.getSetup())) {
            throw ExceptionResultEnum.FLOW_REJECT_SETUP_IS_NULL.exception();
        }
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        Task task = taskService.createTaskQuery().taskId(String.valueOf(flowApproveParam.getTaskId())).singleResult();
        Optional.ofNullable(task).orElseThrow(() -> ExceptionResultEnum.FLOW_TASK_NO_DATA.exception());

        List<String> taskApproveUserList = activitiService.getTaskApprove(task);
        if (flowApproveParam.getApprove() != FlowApprovePassEnum.DRAFT && !CollectionUtils.isEmpty(taskApproveUserList) && !taskApproveUserList.contains(sysUser.getId().toString())) {
            throw ExceptionResultEnum.ERROR.exception("不能审批他人的sop数据");
        }

        TFCustomFlowEntity tfCustomFlowEntity = tfCustomFlowEntityService.getOne(new QueryWrapper<TFCustomFlowEntity>().lambda().eq(TFCustomFlowEntity::getFlowId, Long.parseLong(task.getProcessInstanceId())));
        Optional.ofNullable(tfCustomFlowEntity).orElseThrow(() -> ExceptionResultEnum.FLOW_ENTITY_NO_DATA.exception());

        TFCustomFlow tfCustomFlow = tfCustomFlowService.getById(tfCustomFlowEntity.gettFCustomFlowId());
        Optional.ofNullable(tfCustomFlow).orElseThrow(() -> ExceptionResultEnum.FLOW_CUSTOM_NO_DATA.exception());

        if (tfCustomFlow.getType() != TFCustomTypeEnum.OFFICE_SOP_FLOW && tfCustomFlow.getType() != TFCustomTypeEnum.CLOUD_MARK_SOP_FLOW) {
            throw ExceptionResultEnum.ERROR.exception("sop流程类型错误");
        }

        TBSopInfo tbSopInfo = this.getOne(new QueryWrapper<TBSopInfo>().lambda().eq(TBSopInfo::getSopNo, tfCustomFlowEntity.getCode()));
        Optional.ofNullable(tbSopInfo).orElseThrow(() -> ExceptionResultEnum.SOP_INFO_NO_DATA.exception());

        TBSopInfoDetail tbSopInfoDetail = tbSopInfoDetailService.getOne(new QueryWrapper<TBSopInfoDetail>().lambda().eq(TBSopInfoDetail::getSopInfoId, tbSopInfo.getId()));
        Optional.ofNullable(tbSopInfoDetail).orElseThrow(() -> ExceptionResultEnum.SOP_DETAIL_INFO_NO_DATA.exception());

        //更新表单信息
        FlowTaskResult flowTaskResult = JSONObject.parseObject(flowApproveParam.getFormProperties(), FlowTaskResult.class);
        Long engineerUserId = null;
        if (flowTaskResult.getSetup().intValue() == 1) {
            Long regionUserId = null;
            String assistantEngineerUserIds = null;
            Map<String, Object> map = this.getApproveUserIds(flowTaskResult);
            regionUserId = (Long) map.get(SystemConstant.REGION_USER_ID);
            engineerUserId = (Long) map.get(SystemConstant.ENGINEER_USER_ID);
            assistantEngineerUserIds = (String) map.get(SystemConstant.ASSISTANT_ENGINEER_USER_ID);

            tbSopInfoDetail.updateUserIdInfo(regionUserId, engineerUserId, assistantEngineerUserIds);
            tbSopInfoDetailService.updateById(tbSopInfoDetail);
        } else {
            engineerUserId = Long.parseLong(taskApproveUserList.get(0));
        }
        List<String> approveUserIds = this.getNextApproveUserIds(tfCustomFlow.getType(), flowTaskResult, tbSopInfoDetail);
        flowApproveParam.setApproveUserIds(approveUserIds);

//        TFFlowApprove tfFlowApprove = tfFlowApproveService.getOne(new QueryWrapper<TFFlowApprove>().lambda().eq(TFFlowApprove::getFlowId, tfCustomFlowEntity.getFlowId()));
//        if (tfCustomFlow.getType() == TFCustomTypeEnum.OFFICE_SOP_FLOW && flowApproveParam.getApprove() == FlowApprovePassEnum.PASS && tfFlowApprove.getSetup().intValue() == 2
//                && tbSopInfoDetail.getLeadId().longValue() == tbSopInfoDetail.getRegionUserId().longValue()) {
//            flowApproveParam.setVar(Collections.singletonMap(SystemConstant.APPROVE, SystemConstant.APPROVE_AUTO));
//        }

        Map<String, Object> map = activitiService.taskApprove(flowApproveParam);
        if (flowApproveParam.getApprove() != FlowApprovePassEnum.DRAFT) {
            tbSopInfoService.saveJobRemind(map);
        }
        TFFlowApprove tfFlowApprove = (TFFlowApprove) map.get(SystemConstant.FLOW_APPROVE);

        tbSopInfo.updateInfo(sysUser.getId());
        this.updateById(tbSopInfo);

        //如果下一步审批是大区经理内审并且区域协调人和大区经理为同一人时，后台自动审批
        tbSopInfoService.sopSystemApprove(tfCustomFlow, tfCustomFlowEntity, tfFlowApprove, tbSopInfoDetail, flowApproveParam.getCrmNo());
        return true;
    }

    /**
     * sop管理列表
     *
     * @param sopInfoListParam
     * @return
     */
    @Override
    public IPage<Map> list(SopInfoListParam sopInfoListParam) {
        if (sopInfoListParam.getType() != TFCustomTypeEnum.OFFICE_SOP_FLOW && sopInfoListParam.getType() != TFCustomTypeEnum.CLOUD_MARK_SOP_FLOW) {
            throw ExceptionResultEnum.ERROR.exception("流程类型只能为教务处或研究生");
        }
        String tableName = sopInfoListParam.getType().getTableName() + "_" + sopInfoListParam.getVersion();
        String fieldName = null, fieldValue = null;
        if (!CollectionUtils.isEmpty(sopInfoListParam.getFormWidgetMetadataList())) {
            StringJoiner stringJoiner = new StringJoiner(",");
            StringJoiner stringJoinerValue = new StringJoiner("");
            for (FormWidgetMetadataParam f : sopInfoListParam.getFormWidgetMetadataList()) {
                stringJoiner.add(f.getFieldId());
                if (Objects.nonNull(f.getOperator())) {
                    if (f.getOperator() == FormWidgetMetadataOperator.LIKE) {
                        stringJoinerValue.add(SystemConstant.AND).add(f.getFieldId()).add(f.getOperator().getCode()).add("('%',").add(f.getFieldValue()).add(",'%')").add("\r\n");
                    } else {
                        stringJoinerValue.add(SystemConstant.AND).add(f.getFieldId()).add(f.getOperator().getCode()).add(f.getFieldValue()).add("\r\n");
                    }
                }
            }
            fieldName = stringJoiner.toString();
            fieldValue = !Objects.equals(stringJoinerValue.toString().trim(), "") ? stringJoinerValue.toString().trim() : null;
        }
        return this.baseMapper.list(new Page<>(sopInfoListParam.getPageNumber(), sopInfoListParam.getPageSize()), Objects.nonNull(sopInfoListParam.getType()) ? sopInfoListParam.getType().name() : null, sopInfoListParam.getServiceId(), tableName, fieldName, fieldValue);
    }

    /**
     * sop自动审批
     *
     * @param tfCustomFlow
     * @param tfCustomFlowEntity
     * @param tfFlowApprove
     * @param tbSopInfoDetail
     * @param crmNo
     * @throws InterruptedException
     */
    @Override
    @Transactional
    public void sopSystemApprove(TFCustomFlow tfCustomFlow, TFCustomFlowEntity tfCustomFlowEntity, TFFlowApprove tfFlowApprove, TBSopInfoDetail tbSopInfoDetail, String crmNo) throws InterruptedException {
        //如果下一步审批是大区经理内审并且区域协调人和大区经理为同一人时，后台自动审批
        if (tfFlowApprove.getStatus() != FlowStatusEnum.FINISH && tfFlowApprove.getStatus() != FlowStatusEnum.END
                && tfFlowApprove.getStatus() == FlowStatusEnum.AUDITING && tfFlowApprove.getSetup().intValue() == 3
                && tbSopInfoDetail.getLeadId().longValue() == tbSopInfoDetail.getRegionUserId().longValue()) {
            Task taskNew = taskService.createTaskQuery().processInstanceId(String.valueOf(tfFlowApprove.getFlowId())).singleResult();
            Optional.ofNullable(taskNew).orElseThrow(() -> ExceptionResultEnum.FLOW_TASK_NO_DATA.exception());

            FlowResult flowResult = JSONObject.parseObject(tfCustomFlowEntity.getFlowProcessVar(), FlowResult.class);
            LinkedHashMap<String, FlowTaskResult> setupMap = flowResult.getSetupMap();
            FlowTaskResult nextFlowTaskResult = null;
            for (Map.Entry<String, FlowTaskResult> entry : setupMap.entrySet()) {
                if (entry.getValue().getSetup().intValue() == 3) {
                    nextFlowTaskResult = entry.getValue();
                    break;
                }
            }

            if (Objects.nonNull(nextFlowTaskResult)) {
                List<FlowFormWidgetResult> flowFormWidgetResultList = nextFlowTaskResult.getFormProperty();
                for (FlowFormWidgetResult f : flowFormWidgetResultList) {
                    if (f.getFormId().contains(SystemConstant.APPROVE_RADIO)) {
                        f.setValue("1");
                    } else if (f.getFormId().contains(SystemConstant.APPROVE_REMARK)) {
                        f.setValue(SystemConstant.SYSTEM_AUTO_APPROVE);
                    }
                }
            }
            activitiService.taskApprove(new FlowApproveParam(Long.parseLong(taskNew.getId()), FlowApprovePassEnum.PASS, this.getNextApproveUserIds(tfCustomFlow.getType(), nextFlowTaskResult, tbSopInfoDetail), crmNo, SystemConstant.SYSTEM_AUTO_APPROVE, JacksonUtil.parseJson(nextFlowTaskResult)));
        }
    }

    /**
     * 获取下一级审批人
     *
     * @param type
     * @param flowTaskResult
     * @param tbSopInfoDetail
     * @return
     */
    public List<String> getNextApproveUserIds(TFCustomTypeEnum type, FlowTaskResult flowTaskResult, TBSopInfoDetail tbSopInfoDetail) {
        List<String> approveUserIds = null;
        if (type == TFCustomTypeEnum.OFFICE_SOP_FLOW) {//教务处sop流程待审核人
            if (flowTaskResult.getSetup().intValue() == 1) {
                approveUserIds = Arrays.asList(String.valueOf(tbSopInfoDetail.getRegionUserId()));
            } else if (flowTaskResult.getSetup().intValue() == 2 || flowTaskResult.getSetup().intValue() == 4) {
                approveUserIds = Arrays.asList(String.valueOf(tbSopInfoDetail.getLeadId()));
            } else {
                approveUserIds = Arrays.asList(String.valueOf(tbSopInfoDetail.getEngineerUserId()));
            }
        } else if (type == TFCustomTypeEnum.CLOUD_MARK_SOP_FLOW) {//研究生sop流程待审核人

        }
        return approveUserIds;
    }

    /**
     * 获取审批人
     *
     * @param flowTaskResult
     * @return
     */
    public Map<String, Object> getApproveUserIds(FlowTaskResult flowTaskResult) {
        Map<String, Object> map = new HashMap<>();
        Long regionUserId = null, engineerUserId = null;
        String assistantEngineerUserIds = null;
        List<FlowFormWidgetResult> formProperty = flowTaskResult.getFormProperty();
        for (FlowFormWidgetResult f : formProperty) {
            if (f.getFormId().contains(SystemConstant.REGION_USER_ID) && Objects.nonNull(f.getValue())) {
                regionUserId = Long.parseLong(f.getValue());
            }
            if (f.getFormId().contains(SystemConstant.ENGINEER_USER_ID) && Objects.nonNull(f.getValue())) {
                engineerUserId = Long.parseLong(f.getValue());
            }
            if (f.getFormId().contains(SystemConstant.ASSISTANT_ENGINEER_USER_ID) && Objects.nonNull(f.getValue())) {
                String string = f.getValue().replaceAll("\\[", "").replaceAll("\\]", "");
                assistantEngineerUserIds = StringUtils.join(Arrays.asList(string), SystemConstant.LIST_JOIN_SPLIT);
            }
            if (Objects.nonNull(regionUserId) && Objects.nonNull(engineerUserId) && Objects.nonNull(assistantEngineerUserIds)) {
                break;
            }
        }
        Optional.ofNullable(regionUserId).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("区域协调人不能为空"));
        Optional.ofNullable(engineerUserId).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("实施工程师不能为空"));
        map.put(SystemConstant.REGION_USER_ID, regionUserId);
        map.put(SystemConstant.ENGINEER_USER_ID, engineerUserId);
        map.put(SystemConstant.ASSISTANT_ENGINEER_USER_ID, assistantEngineerUserIds);
        return map;
    }

    /**
     * sop申请或发布
     *
     * @param sopNo
     * @param crmNo
     * @param flowDeploymentId
     * @param approve
     * @param formProperties
     * @return
     * @throws InterruptedException
     */
    @Override
    @Transactional
    public Boolean sopApplyOrPublish(String sopNo, String crmNo, String flowDeploymentId, FlowApprovePassEnum approve, String formProperties) throws InterruptedException {
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        CrmProjectResult crmProjectResult = tbCrmService.findCrmProjectBySopNoOrCrmNo(sopNo, crmNo);
        Optional.ofNullable(crmProjectResult).orElseThrow(() -> ExceptionResultEnum.CRM_NO_NO_DATA.exception());
        Optional.ofNullable(crmProjectResult.getRegionManagerId()).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("crm大区经理数据为空"));

        TFCustomFlow tfCustomFlow = null;
        TBSopInfoDetail tbSopInfoDetail = null;
        List<String> approveUserIds = new ArrayList<>();
        if (approve == FlowApprovePassEnum.DRAFT) {
            approveUserIds.add(String.valueOf(crmProjectResult.getRegionManagerId()));
        } else if (approve == FlowApprovePassEnum.START) {
            Optional.ofNullable(formProperties).orElseThrow(() -> ExceptionResultEnum.FLOW_FORM_PROPERTIES_IS_NULL.exception());

            tfCustomFlow = tfCustomFlowService.getOne(new QueryWrapper<TFCustomFlow>().lambda().eq(TFCustomFlow::getFlowDeploymentId, flowDeploymentId));
            Optional.ofNullable(tfCustomFlow).orElseThrow(() -> ExceptionResultEnum.FLOW_CUSTOM_NO_DATA.exception());

            if (tfCustomFlow.getType() != TFCustomTypeEnum.OFFICE_SOP_FLOW && tfCustomFlow.getType() != TFCustomTypeEnum.CLOUD_MARK_SOP_FLOW) {
                throw ExceptionResultEnum.ERROR.exception("sop流程类型错误");
            }

            FlowTaskResult flowTaskResult = JSONObject.parseObject(formProperties, FlowTaskResult.class);
            Map<String, Object> map = this.getApproveUserIds(flowTaskResult);
            Long regionUserId = (Long) map.get(SystemConstant.REGION_USER_ID);
            Long engineerUserId = (Long) map.get(SystemConstant.ENGINEER_USER_ID);
            String assistantEngineerUserIds = (String) map.get(SystemConstant.ASSISTANT_ENGINEER_USER_ID);
            tbSopInfoDetail = new TBSopInfoDetail(crmProjectResult.getRegionManagerId(), regionUserId, engineerUserId, assistantEngineerUserIds);
            approveUserIds = this.getNextApproveUserIds(tfCustomFlow.getType(), flowTaskResult, tbSopInfoDetail);
        }

        Map<String, Object> map = activitiService.taskApprove(new FlowApproveParam(flowDeploymentId, approve, approveUserIds, crmNo, formProperties));
        if (approve != FlowApprovePassEnum.DRAFT) {
            tbSopInfoService.saveJobRemind(map);
        }

        tfCustomFlow = Objects.isNull(tfCustomFlow) ? (TFCustomFlow) map.get(SystemConstant.FLOW_CUSTOM) : tfCustomFlow;
        TFCustomFlowEntity tfCustomFlowEntity = (TFCustomFlowEntity) map.get(SystemConstant.FLOW_ENTITY);

        TBSopInfo tbSopInfo = new TBSopInfo(crmNo, tfCustomFlowEntity.getCode(), crmProjectResult.getServiceUnitId(), crmProjectResult.getCustomId(), crmProjectResult.getProductId(), tfCustomFlow.getType(), sysUser.getId());
        if (Objects.isNull(tbSopInfoDetail)) {
            tbSopInfoDetail = new TBSopInfoDetail(tbSopInfo.getId(), crmProjectResult.getRegionManagerId());
        } else {
            tbSopInfoDetail.setSopInfoId(tbSopInfo.getId());
        }
        tbSopInfoDetailService.save(tbSopInfoDetail);

        tfCustomFlowEntity.setObjId(tbSopInfo.getId());
        tfCustomFlowEntityService.updateById(tfCustomFlowEntity);
        return tbSopInfoService.save(tbSopInfo);
    }

    /**
     * 保存提醒/延时任务
     *
     * @param map
     */
    @Override
    @Transactional
    public void saveJobRemind(Map<String, Object> map) {
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        TFCustomFlow tfCustomFlow = (TFCustomFlow) map.get(SystemConstant.FLOW_CUSTOM);
        Optional.ofNullable(tfCustomFlow).orElseThrow(() -> ExceptionResultEnum.FLOW_CUSTOM_NO_DATA.exception());

        TFCustomFlowEntity tfCustomFlowEntity = (TFCustomFlowEntity) map.get(SystemConstant.FLOW_ENTITY);
        Optional.ofNullable(tfCustomFlowEntity).orElseThrow(() -> ExceptionResultEnum.FLOW_ENTITY_NO_DATA.exception());

        TFFlowApprove tfFlowApprove = (TFFlowApprove) map.get(SystemConstant.FLOW_APPROVE);
        Optional.ofNullable(tfFlowApprove).orElseThrow(() -> ExceptionResultEnum.FLOW_APPROVE_NO_DATA.exception());

        TFFlowLog tfFlowLog = (TFFlowLog) map.get(SystemConstant.FLOW_APPROVE_LOG);
        Optional.ofNullable(tfFlowLog).orElseThrow(() -> ExceptionResultEnum.FLOW_APPROVE_LOG_NO_DATA.exception());

        Task task = taskService.createTaskQuery().processInstanceId(String.valueOf(tfCustomFlowEntity.getFlowId())).singleResult();
        if (Objects.nonNull(task) && (tfFlowApprove.getStatus() != FlowStatusEnum.DRAFT && tfFlowApprove.getStatus() != FlowStatusEnum.FINISH && tfFlowApprove.getStatus() != FlowStatusEnum.END)) {
            Long processLimitedTime = null;
            String execField = null;
            if (tfCustomFlow.getType() == TFCustomTypeEnum.OFFICE_SOP_FLOW) {//教务处sop
                if (tfFlowApprove.getSetup().intValue() == 2) {//项目关键信息
                    FlowTaskResult flowTaskResult = this.getFormProperties(tfCustomFlowEntity, 1);
                    processLimitedTime = this.getProcessLimitedTime(flowTaskResult, SystemConstant.PROJECT_KEY_INFO_DATE);
                    execField = SystemConstant.PROJECT_KEY_INFO_DATE;
                } else if (tfFlowApprove.getSetup().intValue() == 3 || tfFlowApprove.getSetup().intValue() == 4) {//大区经理内审或工程师内审
                    processLimitedTime = tfFlowApprove.getUpdateTime();
                } else if (tfFlowApprove.getSetup().intValue() == 6) {//扫描准备
                    FlowTaskResult flowTaskResult = this.getFormProperties(tfCustomFlowEntity, 2);
                    processLimitedTime = this.getProcessLimitedTime(flowTaskResult, SystemConstant.SCAN_START_TIME);
                    execField = SystemConstant.SCAN_START_TIME;
                } else if (tfFlowApprove.getSetup().intValue() == 8) {//校验收尾
                    FlowTaskResult flowTaskResult = this.getFormProperties(tfCustomFlowEntity, 2);
                    processLimitedTime = this.getProcessLimitedTime(flowTaskResult, SystemConstant.SCAN_END_TIME);
                    execField = SystemConstant.SCAN_END_TIME;
                } else if (tfFlowApprove.getSetup().intValue() == 9) {//评卷准备
                    FlowTaskResult flowTaskResult = this.getFormProperties(tfCustomFlowEntity, 2);
                    processLimitedTime = this.getProcessLimitedTime(flowTaskResult, SystemConstant.MARK_START_TIME);
                    execField = SystemConstant.MARK_START_TIME;
                } else if (tfFlowApprove.getSetup().intValue() == 10) {//评卷收尾
                    FlowTaskResult flowTaskResult = this.getFormProperties(tfCustomFlowEntity, 2);
                    processLimitedTime = this.getProcessLimitedTime(flowTaskResult, SystemConstant.MARK_END_TIME);
                    execField = SystemConstant.MARK_END_TIME;
                } else if (tfFlowApprove.getSetup().intValue() == 11) {//设备入库登记
                    FlowTaskResult flowTaskResult = this.getFormProperties(tfCustomFlowEntity, 1);
                    processLimitedTime = this.getProcessLimitedTime(flowTaskResult, SystemConstant.SERVICE_FINISH_PLAN_DATE);
                    execField = SystemConstant.SERVICE_FINISH_PLAN_DATE;
                }
            } else if (tfCustomFlow.getType() == TFCustomTypeEnum.CLOUD_MARK_SOP_FLOW) {//研究生sop

            }
            List<TSJobRemind> tsJobRemindList = new ArrayList<>();
            if (Objects.nonNull(task.getAssignee())) {
                tsJobRemindList.add(new TSJobRemind(JobQuartzTypeEnum.FLOW, tfCustomFlowEntity.getCode(), Long.parseLong(task.getId()), tfCustomFlow.getType().getTitle() + ";" + task.getName(), JobTypeEnum.BEFORE, Long.parseLong(task.getAssignee()), tfFlowLog.getApproveOperation(), processLimitedTime, execField, sysUser.getId()));
                tsJobRemindList.add(new TSJobRemind(JobQuartzTypeEnum.FLOW, tfCustomFlowEntity.getCode(), Long.parseLong(task.getId()), tfCustomFlow.getType().getTitle() + ";" + task.getName(), JobTypeEnum.AFTER, Long.parseLong(task.getAssignee()), tfFlowLog.getApproveOperation(), processLimitedTime, execField, sysUser.getId()));
            } else {
                List<IdentityLink> identityLinkList = taskService.getIdentityLinksForTask(task.getId());
                if (!CollectionUtils.isEmpty(identityLinkList)) {
                    for (IdentityLink i : identityLinkList) {
                        tsJobRemindList.add(new TSJobRemind(JobQuartzTypeEnum.FLOW, tfCustomFlowEntity.getCode(), Long.parseLong(i.getTaskId()), tfCustomFlow.getType().getTitle() + ";" + task.getName(), JobTypeEnum.BEFORE, Long.parseLong(i.getUserId()), tfFlowLog.getApproveOperation(), processLimitedTime, execField, sysUser.getId()));
                        tsJobRemindList.add(new TSJobRemind(JobQuartzTypeEnum.FLOW, tfCustomFlowEntity.getCode(), Long.parseLong(i.getTaskId()), tfCustomFlow.getType().getTitle() + ";" + task.getName(), JobTypeEnum.AFTER, Long.parseLong(i.getUserId()), tfFlowLog.getApproveOperation(), processLimitedTime, execField, sysUser.getId()));
                    }
                }
            }
            tsJobRemindService.saveJobRemind(tsJobRemindList);
        }
    }

    public static void main(String[] args) {
        String s = "{\"id\":\"432916157473751040\",\"flowDeploymentId\":\"432916157020766208\",\"flowName\":\"OFFICE_SOP_FLOW\",\"setupMap\":{\"f_usertask_office_first_1\":{\"taskName\":\"项目初审\",\"taskKey\":\"f_usertask_office_first_1\",\"setup\":1,\"formKey\":\"office_sop_first.form\",\"formProperty\":[{\"id\":\"18\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"project_basic_info_title_1\",\"formName\":\"project_basic_info_title_1\",\"title\":\"项目基本信息\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"19\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"course_count_1\",\"formName\":\"course_count_1\",\"title\":\"科目数量\",\"inputType\":\"INT\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"1\",\"name\":\"数字文本\",\"span\":3},{\"id\":\"20\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"exam_student_course_count_1\",\"formName\":\"exam_student_course_count_1\",\"title\":\"考生科次\",\"inputType\":\"INT\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"2\",\"name\":\"数字文本\",\"span\":3},{\"id\":\"21\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"scan_count_1\",\"formName\":\"scan_count_1\",\"title\":\"扫描仪数量(台)\",\"inputType\":\"INT\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"3\",\"name\":\"数字文本\",\"span\":3},{\"id\":\"22\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"week_people_day_1\",\"formName\":\"week_people_day_1\",\"title\":\"现场标准服务周期（人天）\",\"inputType\":\"INT\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"4\",\"name\":\"数字文本\",\"span\":3},{\"id\":\"23\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"exam_student_Internal_date_1\",\"formName\":\"exam_student_Internal_date_1\",\"title\":\"考生数据内部交接时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"1694402482000\",\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"24\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"exam_plan_date_1\",\"formName\":\"exam_plan_date_1\",\"title\":\"考试时间安排表获取时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"1694402482000\",\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"25\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"project_key_info_date_1\",\"formName\":\"project_key_info_date_1\",\"title\":\"项目关键信息提交截止时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"1694406082000\",\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"26\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"service_finish_plan_date_1\",\"formName\":\"service_finish_plan_date_1\",\"title\":\"现场服务完成撤场计划时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"1694492482000\",\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"27\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"project_people_plan_title_1\",\"formName\":\"project_people_plan_title_1\",\"title\":\"项目人员安排及风险预估\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"28\",\"code\":\"TEXT\",\"type\":\"FORM\",\"formId\":\"region_user_id_1\",\"formName\":\"region_user_id_1\",\"title\":\"区域协调人\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"2\",\"name\":\"文本\",\"span\":4},{\"id\":\"29\",\"code\":\"SINGLE_SELECT\",\"type\":\"FORM\",\"formId\":\"engineer_user_id_1\",\"formName\":\"engineer_user_id_1\",\"title\":\"实施工程师\",\"inputType\":\"LONG\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"431778413070516224\",\"name\":\"单选下拉框\",\"span\":4},{\"id\":\"30\",\"code\":\"MULTIPLE_SELECT\",\"type\":\"FORM\",\"formId\":\"assistant_engineer_user_id_1\",\"formName\":\"assistant_engineer_user_id_1\",\"title\":\"助理实施工程师\",\"inputType\":\"ARRAY\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"多选下拉框\",\"span\":4},{\"id\":\"31\",\"code\":\"ONLE_TITLE\",\"type\":\"FORM\",\"formId\":\"project_rish_title_1\",\"formName\":\"project_rish_title_1\",\"title\":\"项目风险预估（仅供参考）\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"普通标题，独占一行\",\"span\":12},{\"id\":\"32\",\"code\":\"CHECKBOX\",\"type\":\"FORM\",\"formId\":\"delay_rish_cb_1\",\"formName\":\"delay_rish_cb_1\",\"title\":\"延期风险\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":\\\"LOW\\\"}\",\"name\":\"复选框\",\"span\":12,\"options\":\"[{\\\"value\\\":\\\"LOW\\\",\\\"label\\\":\\\"低\\\"},{\\\"value\\\":\\\"MIDDLE\\\",\\\"label\\\":\\\"中\\\"},{\\\"value\\\":\\\"HIGH\\\",\\\"label\\\":\\\"高\\\"}]\"},{\"id\":\"33\",\"code\":\"CHECKBOX\",\"type\":\"FORM\",\"formId\":\"engineer_rish_cb_1\",\"formName\":\"engineer_rish_cb_1\",\"title\":\"实施难度\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"{\\\"value\\\":\\\"LOW\\\"}\",\"name\":\"复选框\",\"span\":12,\"options\":\"[{\\\"value\\\":\\\"LOW\\\",\\\"label\\\":\\\"低\\\"},{\\\"value\\\":\\\"MIDDLE\\\",\\\"label\\\":\\\"中\\\"},{\\\"value\\\":\\\"HIGH\\\",\\\"label\\\":\\\"高\\\"}]\"},{\"id\":\"34\",\"code\":\"TEXTAREA\",\"type\":\"FORM\",\"formId\":\"other_remark_1\",\"formName\":\"other_remark_1\",\"title\":\"其它备注（建议关注的其它方面）\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":\"beizhu1\",\"name\":\"文本域\",\"span\":12},{\"id\":\"35\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"project_contacts_title_1\",\"formName\":\"project_contacts_title_1\",\"title\":\"项目联系人\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"36\",\"code\":\"TABLE\",\"type\":\"FORM\",\"formId\":\"project_contacts_table_1\",\"formName\":\"project_contacts_table_1\",\"title\":\"项目联系人表格\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"表格\",\"span\":12,\"tablePropList\":[{\"id\":\"1\",\"widgetId\":\"36\",\"tdIndex\":1,\"tdId\":\"36_1_college_1\",\"tdName\":\"36_1_college_1\",\"title\":\"学院/分（子）机构\",\"tdOrder\":true,\"tdSearch\":true,\"editWidgetId\":\"37\",\"tdFormWidget\":{\"code\":\"TEXT\",\"name\":\"文本\"}},{\"id\":\"2\",\"widgetId\":\"36\",\"tdIndex\":2,\"tdId\":\"36_1_name_1\",\"tdName\":\"36_1_name_1\",\"title\":\"姓名\",\"tdOrder\":true,\"tdSearch\":true,\"editWidgetId\":\"38\",\"tdFormWidget\":{\"code\":\"TEXT\",\"name\":\"文本\"}},{\"id\":\"3\",\"widgetId\":\"36\",\"tdIndex\":3,\"tdId\":\"36_1_job_1\",\"tdName\":\"36_1_job_1\",\"title\":\"职务\",\"tdOrder\":true,\"tdSearch\":true,\"editWidgetId\":\"39\",\"tdFormWidget\":{\"code\":\"TEXT\",\"name\":\"文本\"}},{\"id\":\"4\",\"widgetId\":\"36\",\"tdIndex\":4,\"tdId\":\"36_1_mobileNumber_1\",\"tdName\":\"36_1_mobileNumber_1\",\"title\":\"电话\",\"tdOrder\":true,\"tdSearch\":true,\"editWidgetId\":\"40\",\"tdFormWidget\":{\"code\":\"TEXT\",\"name\":\"文本\"}}]}],\"approveRejectList\":null},\"f_usertask_office_information_2\":{\"taskName\":\"项目关键信息\",\"taskKey\":\"f_usertask_office_information_2\",\"setup\":2,\"formKey\":\"office_sop_information.form\",\"formProperty\":[{\"id\":\"41\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"cloud_mark_title_2\",\"formName\":\"cloud_mark_title_2\",\"title\":\"云阅卷（填写前请先认真查阅移交的项目初审及项目基本信息）\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"42\",\"code\":\"RADIO\",\"type\":\"FORM\",\"formId\":\"deploy_way_radio_2\",\"formName\":\"deploy_way_radio_2\",\"title\":\"部署方式\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"单选框\",\"span\":12,\"options\":\"[{\\\"value\\\":\\\"ONLINE\\\",\\\"label\\\":\\\"线上部署\\\"},{\\\"value\\\":\\\"LOCAL\\\",\\\"label\\\":\\\"本地部署\\\"}]\",\"value\":\"[{\\\"value\\\":\\\"ONLINE\\\"}]\"},{\"id\":\"43\",\"code\":\"RADIO\",\"type\":\"FORM\",\"formId\":\"mark_way_radio_2\",\"formName\":\"mark_way_radio_2\",\"title\":\"阅卷方式\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"单选框\",\"span\":12,\"options\":\"[{\\\"value\\\":\\\"TOGETHER\\\",\\\"label\\\":\\\"集中阅卷\\\"},{\\\"value\\\":\\\"ANYTIME\\\",\\\"label\\\":\\\"分散阅卷\\\"}]\"},{\"id\":\"44\",\"code\":\"RADIO\",\"type\":\"FORM\",\"formId\":\"scan_net_radio_2\",\"formName\":\"scan_net_radio_2\",\"title\":\"扫描场地网络情况\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"单选框\",\"span\":12,\"options\":\"[{\\\"value\\\":\\\"INTERNET\\\",\\\"label\\\":\\\"提供外网\\\"},{\\\"value\\\":\\\"LOCALHOST\\\",\\\"label\\\":\\\"不提供外网\\\"}]\"},{\"id\":\"45\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"scan_start_time_2\",\"formName\":\"scan_start_time_2\",\"title\":\"扫描开始时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"46\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"scan_end_time_2\",\"formName\":\"scan_end_time_2\",\"title\":\"扫描结束时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"47\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"mark_start_time_2\",\"formName\":\"mark_start_time_2\",\"title\":\"评卷开始时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"48\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"mark_end_time_2\",\"formName\":\"mark_end_time_2\",\"title\":\"评卷结束时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6},{\"id\":\"49\",\"code\":\"TEXTAREA\",\"type\":\"FORM\",\"formId\":\"remark_2\",\"formName\":\"remark_2\",\"title\":\"其它特殊要求\",\"inputType\":\"STRING\",\"required\":false,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文本域\",\"span\":12},{\"id\":\"50\",\"code\":\"FILE\",\"type\":\"FORM\",\"formId\":\"exam_plan_photos_2\",\"formName\":\"exam_plan_photos_2\",\"title\":\"考试时间安排表拍照上传\",\"inputType\":\"ARRAY\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"length\":5,\"name\":\"文件\",\"span\":12}],\"approveRejectList\":null}},\"version\":1}";
//        String s = "{\"taskName\":\"项目初审\",\"taskKey\":\"f_usertask_office_first_1\",\"setup\":1,\"formKey\":\"office_sop_first.form\",\"formProperty\":[{\"id\":\"18\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"project_basic_info_title_1\",\"formName\":\"project_basic_info_title_1\",\"title\":\"项目基本信息\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"19\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"course_count_1\",\"formName\":\"course_count_1\",\"title\":\"科目数量\",\"inputType\":\"INT\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"数字文本\",\"span\":3,\"value\":1},{\"id\":\"20\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"exam_student_course_count_1\",\"formName\":\"exam_student_course_count_1\",\"title\":\"考生科次\",\"inputType\":\"INT\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"数字文本\",\"span\":3,\"value\":2},{\"id\":\"21\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"scan_count_1\",\"formName\":\"scan_count_1\",\"title\":\"扫描仪数量(台)\",\"inputType\":\"INT\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"数字文本\",\"span\":3,\"value\":3},{\"id\":\"22\",\"code\":\"NUMBER\",\"type\":\"FORM\",\"formId\":\"week_people_day_1\",\"formName\":\"week_people_day_1\",\"title\":\"现场标准服务周期（人天）\",\"inputType\":\"INT\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"数字文本\",\"span\":3,\"value\":4},{\"id\":\"23\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"exam_student_Internal_date_1\",\"formName\":\"exam_student_Internal_date_1\",\"title\":\"考生数据内部交接时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6,\"value\":1694402482000},{\"id\":\"24\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"exam_plan_date_1\",\"formName\":\"exam_plan_date_1\",\"title\":\"考试时间安排表获取时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6,\"value\":1694402482000},{\"id\":\"25\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"project_key_info_date_1\",\"formName\":\"project_key_info_date_1\",\"title\":\"项目关键信息提交截止时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6,\"value\":1694406082000},{\"id\":\"26\",\"code\":\"DATE\",\"type\":\"FORM\",\"formId\":\"service_finish_plan_date_1\",\"formName\":\"service_finish_plan_date_1\",\"title\":\"现场服务完成撤场计划时间\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"format\":\"yyyy-MM-dd\",\"name\":\"日期\",\"span\":6,\"value\":1694492482000},{\"id\":\"27\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"project_people_plan_title_1\",\"formName\":\"project_people_plan_title_1\",\"title\":\"项目人员安排及风险预估\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"28\",\"code\":\"TEXT\",\"type\":\"FORM\",\"formId\":\"region_user_id_1\",\"formName\":\"region_user_id_1\",\"title\":\"区域协调人\",\"inputType\":\"STRING\",\"required\":true,\"readable\":true,\"writable\":false,\"visable\":true,\"value\":2,\"name\":\"文本\",\"span\":4},{\"id\":\"29\",\"code\":\"SINGLE_SELECT\",\"type\":\"FORM\",\"formId\":\"engineer_user_id_1\",\"formName\":\"engineer_user_id_1\",\"title\":\"实施工程师\",\"inputType\":\"LONG\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"value\":431778413070516224,\"name\":\"单选下拉框\",\"span\":4},{\"id\":\"30\",\"code\":\"MULTIPLE_SELECT\",\"type\":\"FORM\",\"formId\":\"assistant_engineer_user_id_1\",\"formName\":\"assistant_engineer_user_id_1\",\"title\":\"助理实施工程师\",\"inputType\":\"ARRAY\",\"required\":false,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"多选下拉框\",\"span\":4},{\"id\":\"31\",\"code\":\"ONLE_TITLE\",\"type\":\"FORM\",\"formId\":\"project_rish_title_1\",\"formName\":\"project_rish_title_1\",\"title\":\"项目风险预估（仅供参考）\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"普通标题，独占一行\",\"span\":12},{\"id\":\"32\",\"code\":\"CHECKBOX\",\"type\":\"FORM\",\"formId\":\"delay_rish_cb_1\",\"formName\":\"delay_rish_cb_1\",\"title\":\"延期风险\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"复选框\",\"span\":12,\"options\":\"[{\\\"value\\\":\\\"LOW\\\",\\\"label\\\":\\\"低\\\"},{\\\"value\\\":\\\"MIDDLE\\\",\\\"label\\\":\\\"中\\\"},{\\\"value\\\":\\\"HIGH\\\",\\\"label\\\":\\\"高\\\"}]\",\"value\":\"[{\\\"value\\\":\\\"LOW\\\"}]\"},{\"id\":\"33\",\"code\":\"CHECKBOX\",\"type\":\"FORM\",\"formId\":\"engineer_rish_cb_1\",\"formName\":\"engineer_rish_cb_1\",\"title\":\"实施难度\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"复选框\",\"span\":12,\"options\":\"[{\\\"value\\\":\\\"LOW\\\",\\\"label\\\":\\\"低\\\"},{\\\"value\\\":\\\"MIDDLE\\\",\\\"label\\\":\\\"中\\\"},{\\\"value\\\":\\\"HIGH\\\",\\\"label\\\":\\\"高\\\"}]\",\"value\":\"[{\\\"value\\\":\\\"LOW\\\"}]\"},{\"id\":\"34\",\"code\":\"TEXTAREA\",\"type\":\"FORM\",\"formId\":\"other_remark_1\",\"formName\":\"other_remark_1\",\"title\":\"其它备注（建议关注的其它方面）\",\"inputType\":\"STRING\",\"required\":false,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"文本域\",\"span\":12,\"value\":\"beizhu1\"},{\"id\":\"35\",\"code\":\"FORM_GROUP_TITLE\",\"type\":\"FORM\",\"formId\":\"project_contacts_title_1\",\"formName\":\"project_contacts_title_1\",\"title\":\"项目联系人\",\"inputType\":\"STRING\",\"required\":false,\"readable\":true,\"writable\":false,\"visable\":true,\"name\":\"带虚线分割线的标题\",\"span\":12},{\"id\":\"36\",\"code\":\"TABLE\",\"type\":\"FORM\",\"formId\":\"project_contacts_table_1\",\"formName\":\"project_contacts_table_1\",\"title\":\"项目联系人表格\",\"inputType\":\"STRING\",\"required\":true,\"readable\":false,\"writable\":true,\"visable\":true,\"name\":\"表格\",\"span\":12,\"tablePropList\":[{\"id\":\"1\",\"widgetId\":\"36\",\"tdIndex\":1,\"tdId\":\"36_1_college_1\",\"tdName\":\"36_1_college_1\",\"title\":\"学院/分（子）机构\",\"tdOrder\":true,\"tdSearch\":true,\"editWidgetId\":\"37\",\"tdFormWidget\":{\"code\":\"TEXT\",\"name\":\"文本\"}},{\"id\":\"2\",\"widgetId\":\"36\",\"tdIndex\":2,\"tdId\":\"36_1_name_1\",\"tdName\":\"36_1_name_1\",\"title\":\"姓名\",\"tdOrder\":true,\"tdSearch\":true,\"editWidgetId\":\"38\",\"tdFormWidget\":{\"code\":\"TEXT\",\"name\":\"文本\"}},{\"id\":\"3\",\"widgetId\":\"36\",\"tdIndex\":3,\"tdId\":\"36_1_job_1\",\"tdName\":\"36_1_job_1\",\"title\":\"职务\",\"tdOrder\":true,\"tdSearch\":true,\"editWidgetId\":\"39\",\"tdFormWidget\":{\"code\":\"TEXT\",\"name\":\"文本\"}},{\"id\":\"4\",\"widgetId\":\"36\",\"tdIndex\":4,\"tdId\":\"36_1_mobileNumber_1\",\"tdName\":\"36_1_mobileNumber_1\",\"title\":\"电话\",\"tdOrder\":true,\"tdSearch\":true,\"editWidgetId\":\"40\",\"tdFormWidget\":{\"code\":\"TEXT\",\"name\":\"文本\"}}]}],\"approveRejectList\":null}";
        System.out.println(JacksonUtil.parseJson(s));
    }

    /**
     * sop编辑
     *
     * @param id
     * @return
     */
    @Override
    public FlowResult sopEdit(Long id) {
        Optional.ofNullable(id).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("sopId不能为空"));
        TBSopInfo tbSopInfo = this.getById(id);
        Optional.ofNullable(tbSopInfo).orElseThrow(() -> ExceptionResultEnum.SOP_INFO_NO_DATA.exception());

        TFCustomFlowEntity tfCustomFlowEntity = tfCustomFlowEntityService.getOne(new QueryWrapper<TFCustomFlowEntity>().lambda().eq(TFCustomFlowEntity::getCode, tbSopInfo.getSopNo()));
        Optional.ofNullable(tfCustomFlowEntity).orElseThrow(() -> ExceptionResultEnum.FLOW_ENTITY_NO_DATA.exception());

        TFFlowApprove tfFlowApprove = tfFlowApproveService.getOne(new QueryWrapper<TFFlowApprove>().lambda().eq(TFFlowApprove::getFlowId, tfCustomFlowEntity.getFlowId()));
        Optional.ofNullable(tfFlowApprove).orElseThrow(() -> ExceptionResultEnum.FLOW_APPROVE_NO_DATA.exception());

        if (tfFlowApprove.getStatus() == FlowStatusEnum.FINISH || tfFlowApprove.getStatus() == FlowStatusEnum.END) {
            throw ExceptionResultEnum.ERROR.exception("已结束的流程不允许修改");
        }

        FlowResult flowResult = JSONObject.parseObject(tfCustomFlowEntity.getFlowProcessVar(), FlowResult.class);
        FlowResult flowResultNew = new FlowResult();
        BeanUtils.copyProperties(flowResult, flowResultNew);
        LinkedHashMap<String, FlowTaskResult> setupMap = flowResult.getSetupMap();
        LinkedHashMap<String, FlowTaskResult> setupMapNew = new LinkedHashMap<>(setupMap.size());
        for (Map.Entry<String, FlowTaskResult> entry : setupMap.entrySet()) {
            if (entry.getValue().getSetup().intValue() > 0) {
                if (entry.getValue().getSetup().intValue() == 1) {
                    for (FlowFormWidgetResult f : entry.getValue().getFormProperty()) {
                        f.setReadable(true);
                        f.setWritable(false);
                    }
                }
                if (tfFlowApprove.getSetup().intValue() != 0 && tfFlowApprove.getSetup().intValue() < entry.getValue().getSetup().intValue()) {
                    break;
                } else {
                    setupMapNew.put(entry.getKey(), entry.getValue());
                }
            }
        }
        flowResultNew.setSetupMap(setupMapNew);
        return flowResultNew;
    }

    /**
     * sop保存
     *
     * @param sopSaveParam
     * @return
     */
    @Override
    @Transactional
    public Boolean sopSave(SopSaveParam sopSaveParam) {
        TBSopInfo tbSopInfo = this.getById(sopSaveParam.getId());
        Optional.ofNullable(tbSopInfo).orElseThrow(() -> ExceptionResultEnum.SOP_INFO_NO_DATA.exception());

        TFCustomFlowEntity tfCustomFlowEntity = tfCustomFlowEntityService.getOne(new QueryWrapper<TFCustomFlowEntity>().lambda().eq(TFCustomFlowEntity::getCode, tbSopInfo.getSopNo()));
        Optional.ofNullable(tfCustomFlowEntity).orElseThrow(() -> ExceptionResultEnum.FLOW_ENTITY_NO_DATA.exception());

        TFFlowApprove tfFlowApprove = tfFlowApproveService.getOne(new QueryWrapper<TFFlowApprove>().lambda().eq(TFFlowApprove::getFlowId, tfCustomFlowEntity.getFlowId()));
        Optional.ofNullable(tfFlowApprove).orElseThrow(() -> ExceptionResultEnum.FLOW_APPROVE_NO_DATA.exception());

        if (tfFlowApprove.getStatus() == FlowStatusEnum.FINISH || tfFlowApprove.getStatus() == FlowStatusEnum.END) {
            throw ExceptionResultEnum.ERROR.exception("已结束的流程不允许修改");
        }

        TFCustomFlow tfCustomFlow = tfCustomFlowService.getById(tfCustomFlowEntity.gettFCustomFlowId());
        Optional.ofNullable(tfCustomFlow).orElseThrow(() -> ExceptionResultEnum.FLOW_CUSTOM_NO_DATA.exception());

        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        FlowResult flowResultParam = JSONObject.parseObject(sopSaveParam.getFormProperties(), FlowResult.class);
        LinkedHashMap<String, FlowTaskResult> setupParamMap = flowResultParam.getSetupMap();
        for (Map.Entry<String, FlowTaskResult> entry : setupParamMap.entrySet()) {
            if (entry.getValue().getSetup() != 0 && entry.getValue().getSetup() > 1) {//更新动态表单字段和处理时限
                tbSopInfoService.saveDynamicSop(tfCustomFlow, tfCustomFlowEntity.getCode(), tfCustomFlowEntity.getFlowId(), entry.getValue());
            }
        }
        FlowResult flowResult = JSONObject.parseObject(tfCustomFlowEntity.getFlowProcessVar(), FlowResult.class);
        LinkedHashMap<String, FlowTaskResult> setupMap = flowResult.getSetupMap();
        for (Map.Entry<String, FlowTaskResult> entry : setupMap.entrySet()) {
            if (entry.getValue().getSetup().intValue() > 1) {
                if (Objects.nonNull(setupParamMap.get(entry.getKey()))) {
                    setupMap.put(entry.getKey(), setupParamMap.get(entry.getKey()));
                } else {
                    break;
                }
            }
        }
        flowResult.setSetupMap(setupMap);
        tfCustomFlowEntity.updateInfo(sysUser.getId());
        tfCustomFlowEntity.setFlowProcessVar(JacksonUtil.parseJson(flowResult));
        return tfCustomFlowEntityService.updateById(tfCustomFlowEntity);
    }

    /**
     * 获取表单内容
     *
     * @param tfCustomFlowEntity
     * @param setup
     * @return
     */
    public FlowTaskResult getFormProperties(TFCustomFlowEntity tfCustomFlowEntity, Integer setup) {
        FlowResult flowResult = JSONObject.parseObject(tfCustomFlowEntity.getFlowProcessVar(), FlowResult.class);
        LinkedHashMap<String, FlowTaskResult> setupMap = flowResult.getSetupMap();
        FlowTaskResult flowTaskResult = null;
        for (Map.Entry<String, FlowTaskResult> entry : setupMap.entrySet()) {
            if (entry.getValue().getSetup().intValue() == setup.intValue()) {
                flowTaskResult = entry.getValue();
                break;
            }
        }
        return flowTaskResult;
    }

    /**
     * 获取处理时限时间
     *
     * @param flowTaskResult
     * @param fieldId
     * @return
     */
    public Long getProcessLimitedTime(FlowTaskResult flowTaskResult, String fieldId) {
        Long processLimitedTime = null;
        List<FlowFormWidgetResult> formProperty = flowTaskResult.getFormProperty();
        for (FlowFormWidgetResult f : formProperty) {
            if (f.getFormId().contains(fieldId) && Objects.nonNull(f.getValue())) {
                processLimitedTime = Long.parseLong(f.getValue());
                break;
            }
        }
        Optional.ofNullable(processLimitedTime).orElseThrow(() -> ExceptionResultEnum.ERROR.exception(fieldId + "处理时限时间为空"));
        return processLimitedTime;
    }

    /**
     * 根据crmNo查询在途的sop信息
     *
     * @param crmNo
     * @return
     */
    @Override
    public List<String> findFlowPassageByCrmNo(String crmNo) {
        Optional.ofNullable(crmNo).orElseThrow(() -> ExceptionResultEnum.CRM_NO_NO_DATA.exception());
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        return this.baseMapper.findFlowPassageByCrmNo(crmNo, sysUser.getId());
    }
}
