USE sop_db;

-- ----------------------------
-- Table structure for basic_attachment
-- ----------------------------
DROP TABLE IF EXISTS `basic_attachment`;
CREATE TABLE `basic_attachment` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                    `name` varchar(100) NOT NULL COMMENT '文件名',
                                    `type` varchar(10) NOT NULL COMMENT '文件类型',
                                    `size` decimal(8,2) NOT NULL COMMENT '单位（KB）',
                                    `md5` varchar(32) NOT NULL COMMENT '文件md5值',
                                    `path` varchar(2000) NOT NULL COMMENT '存储路径',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    `obj_id` bigint DEFAULT NULL COMMENT '关联业务id',
                                    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='所有附件记录表';

-- ----------------------------
-- Table structure for basic_school
-- ----------------------------
DROP TABLE IF EXISTS `basic_school`;
CREATE TABLE `basic_school` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `code` varchar(20) NOT NULL COMMENT '学校编码',
                                `domain_name` varchar(20) DEFAULT NULL COMMENT '域名',
                                `name` varchar(100) DEFAULT NULL COMMENT '学校名称',
                                `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                                `access_key` varchar(50) DEFAULT NULL COMMENT '访问key',
                                `access_secret` varchar(50) DEFAULT NULL COMMENT '访问秘钥',
                                `remark` text COMMENT '备注',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                `logo` mediumtext COMMENT '学校logo',
                                PRIMARY KEY (`id`) USING BTREE,
                                UNIQUE KEY `code` (`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='学校表';

-- ----------------------------
-- Table structure for basic_sms_message
-- ----------------------------
DROP TABLE IF EXISTS `basic_sms_message`;
CREATE TABLE `basic_sms_message` (
                                     `id` bigint NOT NULL COMMENT '主键',
                                     `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                     `user_id` bigint NOT NULL COMMENT '消息接收人用户',
                                     `user_name` varchar(100) DEFAULT NULL COMMENT '用户名称',
                                     `mobile_number` varchar(11) DEFAULT NULL COMMENT '电话号码',
                                     `message_type` varchar(45) DEFAULT NULL COMMENT '消息类型',
                                     `business_operate` varchar(45) NOT NULL COMMENT '业务操作',
                                     `template_code` varchar(45) NOT NULL COMMENT '消息模板代码',
                                     `variable_params` text COMMENT '变量参数内容',
                                     `template_content` mediumtext COMMENT '模板内容',
                                     `send_status` varchar(45) DEFAULT NULL COMMENT '消息发送状态',
                                     `send_result` varchar(200) DEFAULT NULL COMMENT '消息发送结果',
                                     `remark` text COMMENT '备注',
                                     `resend_count` int DEFAULT NULL COMMENT '重试次数',
                                     `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                     `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                     `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                     `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='短信通知表';

-- ----------------------------
-- Table structure for basic_verify_code
-- ----------------------------
DROP TABLE IF EXISTS `basic_verify_code`;
CREATE TABLE `basic_verify_code` (
                                     `id` bigint NOT NULL COMMENT '主键',
                                     `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                     `user_id` bigint NOT NULL COMMENT '用户ID',
                                     `mobile_number` varchar(11) NOT NULL COMMENT '手机号',
                                     `expire_time` bigint NOT NULL COMMENT '到期时间',
                                     `valid_period` int NOT NULL COMMENT '单位（分）',
                                     `verify_code` varchar(4) NOT NULL COMMENT '4位数字',
                                     `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                     `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                     `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                     `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='短信验证码记录表';

-- ----------------------------
-- Table structure for qrtz_blob_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_blob_triggers`;
CREATE TABLE `qrtz_blob_triggers` (
                                      `SCHED_NAME` varchar(120) NOT NULL,
                                      `TRIGGER_NAME` varchar(200) NOT NULL,
                                      `TRIGGER_GROUP` varchar(200) NOT NULL,
                                      `BLOB_DATA` blob,
                                      PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
                                      KEY `SCHED_NAME` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_calendars
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_calendars`;
CREATE TABLE `qrtz_calendars` (
                                  `SCHED_NAME` varchar(120) NOT NULL,
                                  `CALENDAR_NAME` varchar(200) NOT NULL,
                                  `CALENDAR` blob NOT NULL,
                                  PRIMARY KEY (`SCHED_NAME`,`CALENDAR_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_cron_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_cron_triggers`;
CREATE TABLE `qrtz_cron_triggers` (
                                      `SCHED_NAME` varchar(120) NOT NULL,
                                      `TRIGGER_NAME` varchar(200) NOT NULL,
                                      `TRIGGER_GROUP` varchar(200) NOT NULL,
                                      `CRON_EXPRESSION` varchar(120) NOT NULL,
                                      `TIME_ZONE_ID` varchar(80) DEFAULT NULL,
                                      PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_fired_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_fired_triggers`;
CREATE TABLE `qrtz_fired_triggers` (
                                       `SCHED_NAME` varchar(120) NOT NULL,
                                       `ENTRY_ID` varchar(95) NOT NULL,
                                       `TRIGGER_NAME` varchar(200) NOT NULL,
                                       `TRIGGER_GROUP` varchar(200) NOT NULL,
                                       `INSTANCE_NAME` varchar(200) NOT NULL,
                                       `FIRED_TIME` bigint NOT NULL,
                                       `SCHED_TIME` bigint NOT NULL,
                                       `PRIORITY` int NOT NULL,
                                       `STATE` varchar(16) NOT NULL,
                                       `JOB_NAME` varchar(200) DEFAULT NULL,
                                       `JOB_GROUP` varchar(200) DEFAULT NULL,
                                       `IS_NONCONCURRENT` varchar(1) DEFAULT NULL,
                                       `REQUESTS_RECOVERY` varchar(1) DEFAULT NULL,
                                       PRIMARY KEY (`SCHED_NAME`,`ENTRY_ID`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_TRIG_INST_NAME` (`SCHED_NAME`,`INSTANCE_NAME`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_INST_JOB_REQ_RCVRY` (`SCHED_NAME`,`INSTANCE_NAME`,`REQUESTS_RECOVERY`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_J_G` (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_JG` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_T_G` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_TG` (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_job_details
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_job_details`;
CREATE TABLE `qrtz_job_details` (
                                    `SCHED_NAME` varchar(120) NOT NULL,
                                    `JOB_NAME` varchar(200) NOT NULL,
                                    `JOB_GROUP` varchar(200) NOT NULL,
                                    `DESCRIPTION` varchar(250) DEFAULT NULL,
                                    `JOB_CLASS_NAME` varchar(250) NOT NULL,
                                    `IS_DURABLE` varchar(1) NOT NULL,
                                    `IS_NONCONCURRENT` varchar(1) NOT NULL,
                                    `IS_UPDATE_DATA` varchar(1) NOT NULL,
                                    `REQUESTS_RECOVERY` varchar(1) NOT NULL,
                                    `JOB_DATA` blob,
                                    PRIMARY KEY (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
                                    KEY `IDX_QRTZ_J_REQ_RECOVERY` (`SCHED_NAME`,`REQUESTS_RECOVERY`) USING BTREE,
                                    KEY `IDX_QRTZ_J_GRP` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_locks
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_locks`;
CREATE TABLE `qrtz_locks` (
                              `SCHED_NAME` varchar(120) NOT NULL,
                              `LOCK_NAME` varchar(40) NOT NULL,
                              PRIMARY KEY (`SCHED_NAME`,`LOCK_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_paused_trigger_grps
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_paused_trigger_grps`;
CREATE TABLE `qrtz_paused_trigger_grps` (
                                            `SCHED_NAME` varchar(120) NOT NULL,
                                            `TRIGGER_GROUP` varchar(200) NOT NULL,
                                            PRIMARY KEY (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_scheduler_state
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_scheduler_state`;
CREATE TABLE `qrtz_scheduler_state` (
                                        `SCHED_NAME` varchar(120) NOT NULL,
                                        `INSTANCE_NAME` varchar(200) NOT NULL,
                                        `LAST_CHECKIN_TIME` bigint NOT NULL,
                                        `CHECKIN_INTERVAL` bigint NOT NULL,
                                        PRIMARY KEY (`SCHED_NAME`,`INSTANCE_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_simple_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_simple_triggers`;
CREATE TABLE `qrtz_simple_triggers` (
                                        `SCHED_NAME` varchar(120) NOT NULL,
                                        `TRIGGER_NAME` varchar(200) NOT NULL,
                                        `TRIGGER_GROUP` varchar(200) NOT NULL,
                                        `REPEAT_COUNT` bigint NOT NULL,
                                        `REPEAT_INTERVAL` bigint NOT NULL,
                                        `TIMES_TRIGGERED` bigint NOT NULL,
                                        PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_simprop_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_simprop_triggers`;
CREATE TABLE `qrtz_simprop_triggers` (
                                         `SCHED_NAME` varchar(120) NOT NULL,
                                         `TRIGGER_NAME` varchar(200) NOT NULL,
                                         `TRIGGER_GROUP` varchar(200) NOT NULL,
                                         `STR_PROP_1` varchar(512) DEFAULT NULL,
                                         `STR_PROP_2` varchar(512) DEFAULT NULL,
                                         `STR_PROP_3` varchar(512) DEFAULT NULL,
                                         `INT_PROP_1` int DEFAULT NULL,
                                         `INT_PROP_2` int DEFAULT NULL,
                                         `LONG_PROP_1` bigint DEFAULT NULL,
                                         `LONG_PROP_2` bigint DEFAULT NULL,
                                         `DEC_PROP_1` decimal(13,4) DEFAULT NULL,
                                         `DEC_PROP_2` decimal(13,4) DEFAULT NULL,
                                         `BOOL_PROP_1` varchar(1) DEFAULT NULL,
                                         `BOOL_PROP_2` varchar(1) DEFAULT NULL,
                                         PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for qrtz_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_triggers`;
CREATE TABLE `qrtz_triggers` (
                                 `SCHED_NAME` varchar(120) NOT NULL,
                                 `TRIGGER_NAME` varchar(200) NOT NULL,
                                 `TRIGGER_GROUP` varchar(200) NOT NULL,
                                 `JOB_NAME` varchar(200) NOT NULL,
                                 `JOB_GROUP` varchar(200) NOT NULL,
                                 `DESCRIPTION` varchar(250) DEFAULT NULL,
                                 `NEXT_FIRE_TIME` bigint DEFAULT NULL,
                                 `PREV_FIRE_TIME` bigint DEFAULT NULL,
                                 `PRIORITY` int DEFAULT NULL,
                                 `TRIGGER_STATE` varchar(16) NOT NULL,
                                 `TRIGGER_TYPE` varchar(8) NOT NULL,
                                 `START_TIME` bigint NOT NULL,
                                 `END_TIME` bigint DEFAULT NULL,
                                 `CALENDAR_NAME` varchar(200) DEFAULT NULL,
                                 `MISFIRE_INSTR` smallint DEFAULT NULL,
                                 `JOB_DATA` blob,
                                 PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
                                 KEY `IDX_QRTZ_T_J` (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
                                 KEY `IDX_QRTZ_T_JG` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE,
                                 KEY `IDX_QRTZ_T_C` (`SCHED_NAME`,`CALENDAR_NAME`) USING BTREE,
                                 KEY `IDX_QRTZ_T_G` (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE,
                                 KEY `IDX_QRTZ_T_STATE` (`SCHED_NAME`,`TRIGGER_STATE`) USING BTREE,
                                 KEY `IDX_QRTZ_T_N_STATE` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE,
                                 KEY `IDX_QRTZ_T_N_G_STATE` (`SCHED_NAME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NEXT_FIRE_TIME` (`SCHED_NAME`,`NEXT_FIRE_TIME`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NFT_ST` (`SCHED_NAME`,`TRIGGER_STATE`,`NEXT_FIRE_TIME`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NFT_MISFIRE` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NFT_ST_MISFIRE` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`,`TRIGGER_STATE`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NFT_ST_MISFIRE_GRP` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- ----------------------------
-- Table structure for sequence
-- ----------------------------
DROP TABLE IF EXISTS `sequence`;
CREATE TABLE `sequence` (
                            `name` varchar(50) CHARACTER SET utf8 NOT NULL COMMENT '名称',
                            `current_value` bigint NOT NULL DEFAULT '0' COMMENT '当前值',
                            `increment` int NOT NULL DEFAULT '1' COMMENT '增长值',
                            PRIMARY KEY (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='序列表';

-- ----------------------------
-- Table structure for sys_config
-- ----------------------------
DROP TABLE IF EXISTS `sys_config`;
CREATE TABLE `sys_config` (
                              `id` bigint NOT NULL COMMENT '主键',
                              `org_id` bigint DEFAULT NULL COMMENT '机构id',
                              `config_key` varchar(100) NOT NULL COMMENT '参数键名',
                              `config_name` varchar(100) NOT NULL COMMENT '参数名称',
                              `config_value` varchar(100) DEFAULT NULL COMMENT '参数键值',
                              `remark` varchar(100) DEFAULT NULL COMMENT '备注',
                              `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                              `sort` int DEFAULT '1' COMMENT '排序',
                              `create_id` bigint DEFAULT NULL COMMENT '创建人',
                              `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                              `update_id` bigint DEFAULT NULL COMMENT '更新人',
                              `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                              PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='参数表';

-- ----------------------------
-- Table structure for sys_custom
-- ----------------------------
DROP TABLE IF EXISTS `sys_custom`;
CREATE TABLE `sys_custom` (
                              `id` bigint NOT NULL COMMENT '主键',
                              `name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '名称',
                              `code` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '编码',
                              `type` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '类型，OFFICE：教务处，CLOUD_MARK：研究生',
                              `province` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '省份',
                              `city` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '城市',
                              `area` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '县区',
                              `address` varchar(150) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '地址',
                              `manager_id` bigint DEFAULT NULL COMMENT '客户经理id',
                              `level_id` bigint DEFAULT NULL COMMENT '档位id',
                              `peoper_day` int DEFAULT NULL COMMENT '标准人天',
                              `sync` tinyint NOT NULL DEFAULT '0' COMMENT '是否crm同步，0：否，1：是',
                              `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                              `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                              `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                              `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                              `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                              PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='客户表';

-- ----------------------------
-- Table structure for sys_custom_addr
-- ----------------------------
DROP TABLE IF EXISTS `sys_custom_addr`;
CREATE TABLE `sys_custom_addr` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `custom_id` bigint NOT NULL COMMENT '客户ID',
                                   `province` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '省份',
                                   `city` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '城市',
                                   `area` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '县区',
                                   `address` varchar(150) CHARACTER SET utf8mb4 NOT NULL COMMENT '地址',
                                   `longitude` varchar(255) CHARACTER SET utf8mb4 NOT NULL COMMENT '经度',
                                   `latitude` varchar(255) CHARACTER SET utf8mb4 NOT NULL COMMENT '纬度',
                                   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='客户地址表';

-- ----------------------------
-- Table structure for sys_device
-- ----------------------------
DROP TABLE IF EXISTS `sys_device`;
CREATE TABLE `sys_device` (
                              `id` bigint NOT NULL COMMENT '主键',
                              `device_code` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '设备编号',
                              `serial_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '序列号',
                              `brand` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '品牌',
                              `model` varchar(255) CHARACTER SET utf8mb4 NOT NULL COMMENT '型号',
                              `buy_time` bigint NOT NULL COMMENT '购买时间',
                              `supplier_id` bigint DEFAULT NULL COMMENT '供应商id',
                              `status` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '状态，NORMAL：正常，BREAK_DOWN：故障',
                              `location` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '当前所在地',
                              `scan_count` bigint DEFAULT NULL COMMENT '总扫描量',
                              `bound` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '出库/入库',
                              `sync` tinyint NOT NULL DEFAULT '0' COMMENT '是否crm同步，0：否，1：是',
                              `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                              `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                              `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                              `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                              `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                              PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='设备配置表';

-- ----------------------------
-- Table structure for sys_device_brand
-- ----------------------------
DROP TABLE IF EXISTS `sys_device_brand`;
CREATE TABLE `sys_device_brand` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `brand` varchar(100) NOT NULL COMMENT '品牌',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='设备品牌表';

-- ----------------------------
-- Table structure for sys_device_model
-- ----------------------------
DROP TABLE IF EXISTS `sys_device_model`;
CREATE TABLE `sys_device_model` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `brand_id` bigint NOT NULL COMMENT '品牌ID',
                                    `model` varchar(255) NOT NULL COMMENT '型号',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='设备品牌型号表';

-- ----------------------------
-- Table structure for sys_ding_date
-- ----------------------------
DROP TABLE IF EXISTS `sys_ding_date`;
CREATE TABLE `sys_ding_date` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `year` bigint NOT NULL COMMENT '年',
                                 `month` bigint NOT NULL COMMENT '月',
                                 `day` bigint NOT NULL COMMENT '日',
                                 `type` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '日期类型：WEEKDAY("工作日"),WEEKEND("周末"),LEGAL_HOLIDAYS("法定节假日")',
                                 PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='考勤特殊日期';

-- ----------------------------
-- Table structure for sys_ding_group
-- ----------------------------
DROP TABLE IF EXISTS `sys_ding_group`;
CREATE TABLE `sys_ding_group` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `service_id` bigint NOT NULL COMMENT '服务单元id',
                                  `name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '名称',
                                  `supplier_id` bigint NOT NULL COMMENT '供应商id',
                                  `sign_in_time` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '签到时段',
                                  `sign_out_time` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '签退时段',
                                  `face_open` tinyint NOT NULL DEFAULT '1' COMMENT '是否开启人脸，0：不开启，1：开启',
                                  `reissue_card_count` int DEFAULT NULL COMMENT '允许补卡次数',
                                  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='考勤组表';

-- ----------------------------
-- Table structure for sys_ding_obj
-- ----------------------------
DROP TABLE IF EXISTS `sys_ding_obj`;
CREATE TABLE `sys_ding_obj` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `ding_group_id` bigint NOT NULL COMMENT '考勤组id',
                                `role_id` bigint NOT NULL COMMENT '角色id',
                                `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，DING：考勤，APPROVE：审核',
                                PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='考勤组对象表';

-- ----------------------------
-- Table structure for sys_job
-- ----------------------------
DROP TABLE IF EXISTS `sys_job`;
CREATE TABLE `sys_job` (
                           `id` bigint NOT NULL COMMENT '主键',
                           `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                           `sop_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'sop单号',
                           `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                           `user_id` bigint NOT NULL COMMENT '责任人id',
                           `job_time` bigint NOT NULL COMMENT '任务时间',
                           `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，BEFORE：任务前提醒，AFTER：任务后提醒',
                           `unit` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '单位，HOUR：小时，MINUTE：分钟',
                           `status` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '状态，NOT_EXEC：未执行，EXEC：已执行',
                           `exec_time` bigint NOT NULL COMMENT '执行时间',
                           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                           PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='系统任务表';

-- ----------------------------
-- Table structure for sys_level
-- ----------------------------
DROP TABLE IF EXISTS `sys_level`;
CREATE TABLE `sys_level` (
                             `id` bigint NOT NULL COMMENT '主键',
                             `level` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '档位',
                             `devices` bigint DEFAULT NULL COMMENT '设备数量',
                             `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，OFFICE：教务处，CLOUD_MARK：研究生',
                             `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                             `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                             PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='档位表';

-- ----------------------------
-- Table structure for sys_level_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_level_role`;
CREATE TABLE `sys_level_role` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `level_id` bigint NOT NULL COMMENT '服务档位id',
                                  `role_id` bigint NOT NULL COMMENT '角色id',
                                  `quota` bigint NOT NULL COMMENT '配额',
                                  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='服务档位角色配置表';

-- ----------------------------
-- Table structure for sys_log
-- ----------------------------
DROP TABLE IF EXISTS `sys_log`;
CREATE TABLE `sys_log` (
                           `id` bigint NOT NULL COMMENT '主键',
                           `user_id` bigint NOT NULL COMMENT '用户id',
                           `user_name` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '用户名称',
                           `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类别，LOGIN：登录，LOGOUT：退出以及数据库DDL和DML操作',
                           `obj_name` varchar(1000) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '实体名称',
                           `obj_id` bigint DEFAULT NULL COMMENT '实体id',
                           `content` varchar(200) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '内容',
                           `url` varchar(64) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '请求的url',
                           `args` mediumtext CHARACTER SET utf8mb4 COMMENT '请求的参数',
                           `update_before_obj` mediumtext CHARACTER SET utf8mb4 COMMENT '更改前内容',
                           `update_after_obj` mediumtext CHARACTER SET utf8mb4 COMMENT '更改后内容',
                           `create_time` bigint NOT NULL COMMENT '创建时间',
                           `run_time` bigint DEFAULT NULL COMMENT '请求的响应时间',
                           `run_status` varchar(64) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '请求的结果',
                           PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='系统日志';

-- ----------------------------
-- Table structure for sys_message
-- ----------------------------
DROP TABLE IF EXISTS `sys_message`;
CREATE TABLE `sys_message` (
                               `id` bigint NOT NULL COMMENT '主键',
                               `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                               `code` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '编号',
                               `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '消息类型，BEFORE：提前提醒，AFTER：延期提醒，OFFICE_SOP：教务处SOP，CLOUD_MARK_SOP：研究生SOP，QUALITY：质量问题提醒，EXCEPTION_APPROVE：异常审核提醒，VIOLATION：违规提醒，SYSTEM_PLAN_CHANGE：系统计划变更提醒，SYSTEM：系统公告',
                               `obj_type` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '实体业务类型',
                               `notice_id` bigint DEFAULT NULL COMMENT '公告id',
                               `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                               `supplier_id` bigint DEFAULT NULL COMMENT '供应商ID',
                               `form_user_id` bigint DEFAULT NULL COMMENT '发送人id',
                               `receive_user_id` bigint NOT NULL COMMENT '接收人id',
                               `content` varchar(1000) CHARACTER SET utf8mb4 NOT NULL COMMENT '消息内容',
                               `send_time` bigint NOT NULL COMMENT '发送时间',
                               `receive_time` bigint DEFAULT NULL COMMENT '接收时间',
                               `status` tinyint NOT NULL DEFAULT '0' COMMENT '是否已阅，0：未阅，1：已阅',
                               PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='系统消息';

-- ----------------------------
-- Table structure for sys_notice
-- ----------------------------
DROP TABLE IF EXISTS `sys_notice`;
CREATE TABLE `sys_notice` (
                              `id` bigint NOT NULL COMMENT '主键',
                              `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                              `supplier_id` bigint DEFAULT NULL COMMENT '供应商ID',
                              `title` varchar(200) CHARACTER SET utf8mb4 NOT NULL COMMENT '标题',
                              `content` varchar(1000) CHARACTER SET utf8mb4 NOT NULL COMMENT '内容',
                              `type` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '类型，SYSTEM：公告，SUPPLIER：供应商，SERVICE：服务单元',
                              `status` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '状态，PUBLISH：已发布，UN_PUBLISH：未发布',
                              `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                              `publish_time` bigint DEFAULT NULL COMMENT '发布日期',
                              `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                              `create_time` bigint DEFAULT NULL COMMENT '创建人时间',
                              `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                              `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                              PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='公告表';

-- ----------------------------
-- Table structure for sys_org
-- ----------------------------
DROP TABLE IF EXISTS `sys_org`;
CREATE TABLE `sys_org` (
                           `id` bigint NOT NULL COMMENT '主键',
                           `type` varchar(50) DEFAULT NULL COMMENT '类型',
                           `code` varchar(20) DEFAULT NULL COMMENT '机构代码',
                           `name` varchar(100) NOT NULL COMMENT '机构名称',
                           `parent_id` bigint DEFAULT NULL COMMENT '上级机构id',
                           `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                           `create_id` bigint DEFAULT NULL COMMENT '创建人',
                           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                           `update_id` bigint DEFAULT NULL COMMENT '修改人',
                           `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                           PRIMARY KEY (`id`) USING BTREE,
                           UNIQUE KEY `sys_org_UN_name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='组织架构表';

-- ----------------------------
-- Table structure for sys_privilege
-- ----------------------------
DROP TABLE IF EXISTS `sys_privilege`;
CREATE TABLE `sys_privilege` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `name` varchar(100) NOT NULL COMMENT '菜单名称',
                                 `url` varchar(100) NOT NULL COMMENT 'URL地址',
                                 `type` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，MENU：菜单，BUTTON：按钮，LINK：链接，URL：接口地址，LIST：列表，CONDITION：查询条件',
                                 `parent_id` bigint DEFAULT NULL COMMENT '上级菜单',
                                 `sequence` int NOT NULL COMMENT '序号',
                                 `property` varchar(30) DEFAULT NULL COMMENT '属性，NO_AUTH：无需鉴权，AUTH：鉴权，SYS：系统公用',
                                 `related` text COMMENT '关联属性，type为URL且property为AUTH才有',
                                 `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                 `default_auth` tinyint DEFAULT '1' COMMENT '默认权限，0：否，1：是',
                                 `front_display` tinyint(1) DEFAULT '1' COMMENT '是否前端展示',
                                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='菜单权限表';

-- ----------------------------
-- Table structure for sys_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_role`;
CREATE TABLE `sys_role` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `org_id` bigint DEFAULT NULL COMMENT '机构id',
                            `name` varchar(50) NOT NULL COMMENT '角色名称',
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                            `type` varchar(20) DEFAULT NULL COMMENT '角色类别，ADMIN：超级管理员，PMO：总负责人，BUSSINESS：业务线负责人，REGION_MANAGER：大区经理，REGION_COORDINATOR：区域协调人，EFFECT_ENGINEER：实施工程师，ASSISTANT_ENGINEER：助理工程师，QA：QA，CUSTOM：技术客服',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '修改人',
                            `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                            `default_role` tinyint NOT NULL DEFAULT '0' COMMENT '是否系统内置角色，1：是，0：不是',
                            `interpret` varchar(1000) DEFAULT NULL COMMENT '角色说明',
                            PRIMARY KEY (`id`) USING BTREE,
                            UNIQUE KEY `sys_role_UN_type` (`name`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='角色表';

-- ----------------------------
-- Table structure for sys_role_privilege
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_privilege`;
CREATE TABLE `sys_role_privilege` (
                                      `id` bigint NOT NULL COMMENT '主键',
                                      `role_id` bigint NOT NULL COMMENT '角色id',
                                      `privilege_id` bigint NOT NULL COMMENT '菜单id',
                                      `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                      PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='角色和菜单关联表';

-- ----------------------------
-- Table structure for sys_supplier
-- ----------------------------
DROP TABLE IF EXISTS `sys_supplier`;
CREATE TABLE `sys_supplier` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '名称',
                                `code` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '编码',
                                `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，HUMAN：人力，DEVICE：设备',
                                `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                `remark` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '备注',
                                `sync` tinyint NOT NULL DEFAULT '0' COMMENT '是否crm同步，0：否，1：是',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='供应商表';

-- ----------------------------
-- Table structure for sys_user
-- ----------------------------
DROP TABLE IF EXISTS `sys_user`;
CREATE TABLE `sys_user` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `login_name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '用户名',
                            `real_name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '姓名',
                            `code` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '工号',
                            `password` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '密码',
                            `mobile_number` varchar(30) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '手机号',
                            `org_id` bigint DEFAULT NULL COMMENT '机构id',
                            `gender` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '性别，MAN：男，WOMAN：女',
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                            `pwd_count` tinyint DEFAULT '0' COMMENT '密码修改次数，默认为0',
                            `pwd_update_time` bigint DEFAULT NULL COMMENT '密码修改时间',
                            `remark` varchar(200) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '备注',
                            `source` varchar(20) CHARACTER SET utf8mb4 DEFAULT 'SYSTEM' COMMENT '来源，SYSTEM：系统自带，ARCHIVES：档案',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '修改人',
                            `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                            PRIMARY KEY (`id`) USING BTREE,
                            UNIQUE KEY `sys_user_UN_login_name` (`org_id`,`login_name`),
                            UNIQUE KEY `sys_user_UN_moblie_number` (`org_id`,`mobile_number`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='用户表';

-- ----------------------------
-- Table structure for sys_user_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_user_role`;
CREATE TABLE `sys_user_role` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `user_id` bigint NOT NULL COMMENT '用户id',
                                 `role_id` bigint NOT NULL COMMENT '角色id',
                                 `privilege_id` bigint DEFAULT NULL COMMENT '权限id',
                                 `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='用户和角色关联表';

-- ----------------------------
-- Table structure for t_b_crm
-- ----------------------------
DROP TABLE IF EXISTS `t_b_crm`;
CREATE TABLE `t_b_crm` (
                           `id` bigint NOT NULL COMMENT '主键',
                           `crm_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '项目单号',
                           `name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '项目名称',
                           `begin_time` bigint NOT NULL COMMENT '派单时间',
                           `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                           `crm_user_id` bigint NOT NULL COMMENT '派单人id',
                           `custom_id` bigint NOT NULL COMMENT '客户id',
                           `exam_start_time` bigint DEFAULT NULL COMMENT '考试开始时间',
                           `exam_end_time` bigint DEFAULT NULL COMMENT '考试结束时间',
                           `product_id` bigint NOT NULL COMMENT '产品id',
                           `lead_id` bigint DEFAULT NULL COMMENT '大区经理id',
                           `region_coordinator_id` bigint DEFAULT NULL COMMENT '区域协调人id',
                           `sync` tinyint NOT NULL DEFAULT '0' COMMENT '是否crm同步，false：否，true：是',
                           `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                           `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                           `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                           `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                           `status` varchar(20) NOT NULL COMMENT '派单状态(UN_PUBLISH("未发布"),PUBLISH("已发布"),FINISH("已完成");)',
                           PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='派单信息表';

-- ----------------------------
-- Table structure for t_b_delay_warn
-- ----------------------------
DROP TABLE IF EXISTS `t_b_delay_warn`;
CREATE TABLE `t_b_delay_warn` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                                  `sop_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'sop单号',
                                  `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                                  `message_id` bigint DEFAULT NULL COMMENT '消息id',
                                  `code` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '编号',
                                  `warn_time` bigint DEFAULT NULL COMMENT '预警时间',
                                  `user_id` bigint DEFAULT NULL COMMENT '负责人id',
                                  `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，PLAN：关键信息及计划，TIME：处理时限',
                                  `field_obj` mediumtext CHARACTER SET utf8mb4 COMMENT '预警字段',
                                  `status` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '状态，NOT_START：未跟进，FOLLOW：跟进，CLOSE：关闭，RESTART：重启',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='延期预警跟进表';

-- ----------------------------
-- Table structure for t_b_delay_warn_detail
-- ----------------------------
DROP TABLE IF EXISTS `t_b_delay_warn_detail`;
CREATE TABLE `t_b_delay_warn_detail` (
                                         `id` bigint NOT NULL COMMENT '主键',
                                         `delay_warn_id` bigint NOT NULL COMMENT '延期预警id',
                                         `remark` varchar(500) CHARACTER SET utf8mb4 NOT NULL COMMENT '跟进说明',
                                         `attachment_ids` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '附件ids',
                                         `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                         `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                         PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='延期预警明细表';

-- ----------------------------
-- Table structure for t_b_device_in_out
-- ----------------------------
DROP TABLE IF EXISTS `t_b_device_in_out`;
CREATE TABLE `t_b_device_in_out` (
                                     `id` bigint NOT NULL COMMENT '主键',
                                     `serial_no` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '出入库流水号',
                                     `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                                     `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                                     `sop_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'sop单号',
                                     `in_out_time` bigint NOT NULL COMMENT '出/入库时间',
                                     `user_id` bigint NOT NULL COMMENT '登记人id',
                                     `custom_name` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '客户名称',
                                     `type` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '类型，IN：入库，OUT：出库',
                                     `device_no` varchar(50) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '设备编号',
                                     `supplier_name` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '供应商名称',
                                     `location` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '当前所在地',
                                     `address` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '发往地',
                                     `status` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '状态，NORMAL：正常，BREAK_DOWN：故障',
                                     `usage_type` varchar(45) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '用途类型（项目、其他）',
                                     `base_photo_path` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '快递单拍照',
                                     `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                     `create_time` bigint DEFAULT NULL COMMENT '创建人时间',
                                     PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='设备出入库登记';

-- ----------------------------
-- Table structure for t_b_ding
-- ----------------------------
DROP TABLE IF EXISTS `t_b_ding`;
CREATE TABLE `t_b_ding` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `sop_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT 'sop单号',
                            `ding_sop_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '实际打卡对应的sop单号',
                            `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                            `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                            `user_id` bigint NOT NULL COMMENT '用户id',
                            `user_archives_id` bigint NOT NULL COMMENT '人员档案id',
                            `role_type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '项目角色',
                            `flow_id` bigint DEFAULT NULL COMMENT '流程id',
                            `task_id` bigint DEFAULT NULL COMMENT '流程任务id',
                            `sign_date` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '签到日期',
                            `date_type` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '日期类型：WEEKDAY("工作日"),WEEKEND("周末"),LEGAL_HOLIDAYS("法定节假日")',
                            `sign_in_time` bigint DEFAULT NULL COMMENT '签到时间',
                            `sign_in_address` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '签到地址',
                            `axis_in_x` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '坐标轴X',
                            `axis_in_y` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '坐标轴Y',
                            `face_in_pass` tinyint DEFAULT NULL COMMENT '人脸识别是否通过，0：未通过，1：通过',
                            `sign_out_time` bigint DEFAULT NULL COMMENT '签退时间',
                            `sign_out_address` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '签退地址',
                            `axis_out_x` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '坐标轴X',
                            `axis_out_Y` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '坐标轴Y',
                            `face_out_pass` tinyint DEFAULT NULL COMMENT '人脸识别是否通过，0：未通过，1：通过',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                            PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='考勤打卡表';

-- ----------------------------
-- Table structure for t_b_ding_apply
-- ----------------------------
DROP TABLE IF EXISTS `t_b_ding_apply`;
CREATE TABLE `t_b_ding_apply` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `ding_id` bigint NOT NULL COMMENT '考勤id',
                                  `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，IN：签到，OUT：签退',
                                  `apply_time` bigint NOT NULL COMMENT '补卡时间',
                                  `reason` varchar(500) CHARACTER SET utf8mb4 NOT NULL COMMENT '补卡原因',
                                  `attachment_ids` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '附件id数组',
                                  `ding_exception_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '考勤异常编号',
                                  `approve` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '审批操作，PASS：通过，NO_PASS：不通过',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  PRIMARY KEY (`id`),
                                  UNIQUE KEY `t_b_ding_apply_UN_ding_exception_no` (`ding_exception_no`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='考勤补卡申请表';

-- ----------------------------
-- Table structure for t_b_ding_history
-- ----------------------------
DROP TABLE IF EXISTS `t_b_ding_history`;
CREATE TABLE `t_b_ding_history` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `ding_id` bigint NOT NULL COMMENT '考勤id',
                                    `sign_date` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '签到日期',
                                    `date_type` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '日期类型：WEEKDAY("工作日"),WEEKEND("周末"),LEGAL_HOLIDAYS("法定节假日")',
                                    `sign_in_time` bigint DEFAULT NULL COMMENT '签到时间',
                                    `axis_in_x` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '坐标轴X',
                                    `axis_in_y` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '坐标轴Y',
                                    `face_in_error` tinyint DEFAULT NULL COMMENT '人脸识别是否通过，0：未通过，1：通过',
                                    `sign_out_time` bigint DEFAULT NULL COMMENT '签退时间',
                                    `axis_out_x` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '坐标轴X',
                                    `axis_out_Y` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '坐标轴Y',
                                    `face_out_error` tinyint DEFAULT NULL COMMENT '人脸识别是否通过，0：未通过，1：通过',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='考勤打卡表';

-- ----------------------------
-- Table structure for t_b_ding_submit
-- ----------------------------
DROP TABLE IF EXISTS `t_b_ding_submit`;
CREATE TABLE `t_b_ding_submit` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `service_id` bigint NOT NULL COMMENT '服务单元id',
                                   `sop_no` varchar(100) NOT NULL COMMENT 'sop单号',
                                   `crm_no` varchar(100) NOT NULL COMMENT 'crm单号',
                                   `user_archives_id` bigint NOT NULL COMMENT '人员档案id',
                                   `approach_time` bigint NOT NULL COMMENT '进场时间',
                                   `departure_time` bigint NOT NULL COMMENT '出场时间',
                                   `role_type` varchar(20) NOT NULL COMMENT '项目角色类型',
                                   `actual_days` int DEFAULT NULL COMMENT '实际出勤（天）',
                                   `weekdays` int DEFAULT NULL COMMENT '工作日（天）',
                                   `weekends` int DEFAULT NULL COMMENT '周末（天）',
                                   `legal_holidays` int DEFAULT NULL COMMENT '法定节假日（天）',
                                   `work_hours` decimal(8,2) DEFAULT NULL COMMENT '累计工时（小时）',
                                   `violation_days` decimal(8,2) DEFAULT NULL COMMENT '违规工时',
                                   `submit_user_id` bigint NOT NULL COMMENT '提交人id',
                                   `submit_time` bigint NOT NULL COMMENT '提交时间',
                                   `submit_status` varchar(20) NOT NULL COMMENT '提交状态',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                   `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                   PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='考勤提交审核表';

-- ----------------------------
-- Table structure for t_b_engineer_allocation
-- ----------------------------
DROP TABLE IF EXISTS `t_b_engineer_allocation`;
CREATE TABLE `t_b_engineer_allocation` (
                                           `id` bigint NOT NULL COMMENT '主键',
                                           `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                                           `sop_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'sop单号',
                                           `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                                           `engineer_user_id` bigint NOT NULL COMMENT '用户id',
                                           `role_id` bigint NOT NULL COMMENT '角色id',
                                           PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='sop工程师分配表';

-- ----------------------------
-- Table structure for t_b_product
-- ----------------------------
DROP TABLE IF EXISTS `t_b_product`;
CREATE TABLE `t_b_product` (
                               `id` bigint NOT NULL COMMENT '主键',
                               `name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '名称',
                               `code` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '编码，OFFICE：教务处，CLOUD_MARK：研究生',
                               `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                               `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                               `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                               PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='产品表';

-- ----------------------------
-- Table structure for t_b_project_exchange
-- ----------------------------
DROP TABLE IF EXISTS `t_b_project_exchange`;
CREATE TABLE `t_b_project_exchange` (
                                        `id` bigint NOT NULL COMMENT '主键',
                                        `sop_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'sop单号',
                                        `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                                        `exchange_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '变更编号',
                                        `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                                        `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '变更类型，PLAN：项目信息及计划，CANCEL：项目取消',
                                        `reason` varchar(500) CHARACTER SET utf8mb4 NOT NULL COMMENT '变更原因',
                                        `content_json` mediumtext CHARACTER SET utf8mb4 COMMENT '变更内容json',
                                        `result` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '处理结果，FINISH：已完成，NOT_UPDATE：经沟通，取消变更，PARTIAL_UPDATE：经沟通，部分变更',
                                        `remark` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '变更备注',
                                        `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                        `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                        `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                        PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='项目变更计划表';

-- ----------------------------
-- Table structure for t_b_quality_problem_apply
-- ----------------------------
DROP TABLE IF EXISTS `t_b_quality_problem_apply`;
CREATE TABLE `t_b_quality_problem_apply` (
                                             `id` bigint NOT NULL COMMENT '主键',
                                             `sop_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT 'sop单号',
                                             `crm_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT 'crm单号',
                                             `problem_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '问题编号',
                                             `service_id` bigint NOT NULL COMMENT '服务单元id',
                                             `summary` varchar(1000) CHARACTER SET utf8mb4 NOT NULL COMMENT '问题简要',
                                             `remark` varchar(500) CHARACTER SET utf8mb4 NOT NULL COMMENT '问题情况说明',
                                             `user_ids` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '责任人id数组',
                                             `type` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '问题类型，UPDATE：修正类，OPTIMIZE：优化类，NO_PROBLEM：不是问题',
                                             `reason` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '问题原因类型，EXEC：执行类，MANAGER：管理协调类，FLOW：流程制度类，PRODUCT_PROBLEM：产品缺陷类，PRODUCT_MANAGER：产品运维类，OTHER：其它',
                                             `attachment_ids` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '附件id数组',
                                             `Influence_degree` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '影响度：A，B，C，D',
                                             `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                             `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                             `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                             PRIMARY KEY (`id`),
                                             UNIQUE KEY `t_b_quality_problem_apply_UN_probem_no` (`problem_no`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='质量问题反馈表';

-- ----------------------------
-- Table structure for t_b_service
-- ----------------------------
DROP TABLE IF EXISTS `t_b_service`;
CREATE TABLE `t_b_service` (
                               `id` bigint NOT NULL COMMENT '主键',
                               `name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '名称',
                               `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，OFFICE：教务处，CLOUD_MARK：研究生',
                               `start_time` bigint NOT NULL COMMENT '开始时间',
                               `end_time` bigint NOT NULL COMMENT '结束时间',
                               `region_people_count` int NOT NULL COMMENT '区域协调人数量',
                               `region_project_count` int NOT NULL COMMENT '区域项目数量',
                               `service_lead_id` bigint NOT NULL COMMENT '服务单元负责人id',
                               `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                               `status` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '状态，NEW：新建，PUBLISH：已发布，FINISH：已完结，CANCEL：已作废',
                               `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                               `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                               `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                               `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                               PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='服务单元表';

-- ----------------------------
-- Table structure for t_b_service_region
-- ----------------------------
DROP TABLE IF EXISTS `t_b_service_region`;
CREATE TABLE `t_b_service_region` (
                                      `id` bigint NOT NULL COMMENT '主键',
                                      `service_id` bigint NOT NULL COMMENT '服务单元id',
                                      `lead_id` bigint NOT NULL COMMENT '大区经理id',
                                      `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                      `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                      `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                      `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                      `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                      PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='服务区域规划表';

-- ----------------------------
-- Table structure for t_b_service_region_detail
-- ----------------------------
DROP TABLE IF EXISTS `t_b_service_region_detail`;
CREATE TABLE `t_b_service_region_detail` (
                                             `id` bigint NOT NULL COMMENT '主键',
                                             `service_region_id` bigint NOT NULL COMMENT '服务区域规划id',
                                             `country` varchar(100) CHARACTER SET utf8mb4 NOT NULL DEFAULT '中国' COMMENT '国家',
                                             `province` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '省份',
                                             `city` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '城市',
                                             `area` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '县区',
                                             `address` varchar(150) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '地址',
                                             PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='服务区域规划明细表';

-- ----------------------------
-- Table structure for t_b_service_scope
-- ----------------------------
DROP TABLE IF EXISTS `t_b_service_scope`;
CREATE TABLE `t_b_service_scope` (
                                     `id` bigint NOT NULL COMMENT '主键',
                                     `service_id` bigint NOT NULL COMMENT '服务单元id',
                                     `crm_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT 'crm单号',
                                     `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                     `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                     PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='服务单元范围管理表';

-- ----------------------------
-- Table structure for t_b_session
-- ----------------------------
DROP TABLE IF EXISTS `t_b_session`;
CREATE TABLE `t_b_session` (
                               `id` varchar(100) NOT NULL COMMENT '主键',
                               `org_id` bigint DEFAULT NULL COMMENT '机构id',
                               `identity` varchar(100) NOT NULL COMMENT '用户标识',
                               `type` varchar(500) CHARACTER SET utf8mb4 NOT NULL COMMENT '用户类型',
                               `source` varchar(50) NOT NULL COMMENT '访问来源',
                               `platform` varchar(50) NOT NULL COMMENT '设备分类',
                               `device_id` varchar(100) NOT NULL COMMENT '设备标识',
                               `address` varchar(100) NOT NULL COMMENT '登录IP地址',
                               `access_token` varchar(50) NOT NULL COMMENT '访问令牌',
                               `last_access_time` bigint DEFAULT NULL COMMENT '最近访问时间',
                               `last_access_ip` varchar(100) DEFAULT NULL COMMENT '最近访问IP地址',
                               `update_time` bigint DEFAULT NULL COMMENT '令牌更新时间',
                               `expire_time` bigint DEFAULT NULL COMMENT '令牌强制失效时间',
                               `app_source` varchar(50) DEFAULT NULL COMMENT '应用来源',
                               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='会话表';

-- ----------------------------
-- Table structure for t_b_sop_dynamic_cloud_mark_1
-- ----------------------------
DROP TABLE IF EXISTS `t_b_sop_dynamic_cloud_mark_1`;
CREATE TABLE `t_b_sop_dynamic_cloud_mark_1` (
                                                `type` varchar(20) NOT NULL COMMENT '流程类型，OFFICE_SOP_FLOW：教务处SOP，CLOUD_MARK_SOP_FLOW：研究生SOP，DING_EXCEPTION_FLOW：考勤异常审核流程，PROJECT_EXCHANGE_FLOW：项目计划变更流程，QUALITY_PROBLEM_FLOW：质量问题反馈流程',
                                                `flow_deployment_id` varchar(50) NOT NULL COMMENT '流程部署id',
                                                `version` int NOT NULL DEFAULT '1' COMMENT '版本号',
                                                `code` varchar(30) DEFAULT NULL COMMENT '流程编号',
                                                `flow_id` bigint DEFAULT NULL COMMENT '流程id',
                                                `crm_child_no_1` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_1` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_1` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_1` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_1` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_1` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_1` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_1` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_1` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_1` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_1` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_1` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_1` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_2` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_2` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_2` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_2` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_2` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_2` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_2` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_2` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_2` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_2` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_2` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_2` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_2` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_3` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_3` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_3` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_3` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_3` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_3` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_3` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_3` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_3` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_3` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_3` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_3` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_3` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_4` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_4` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_4` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_4` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_4` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_4` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_4` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_4` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_4` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_4` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_4` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_4` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_4` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_5` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_5` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_5` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_5` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_5` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_5` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_5` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_5` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_5` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_5` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_5` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_5` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_5` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_6` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_6` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_6` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_6` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_6` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_6` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_6` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_6` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_6` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_6` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_6` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_6` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_6` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_7` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_7` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_7` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_7` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_7` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_7` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_7` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_7` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_7` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_7` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_7` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_7` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_7` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_8` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_8` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_8` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_8` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_8` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_8` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_8` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_8` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_8` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_8` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_8` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_8` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_8` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_9` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_9` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_9` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_9` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_9` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_9` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_9` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_9` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_9` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_9` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_9` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_9` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_9` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_10` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_10` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_10` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_10` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_10` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_10` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_10` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_10` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_10` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_10` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_10` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_10` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_10` varchar(100) DEFAULT NULL COMMENT '项目类型',
                                                `crm_child_no_11` varchar(100) DEFAULT NULL COMMENT '项目子单编号',
                                                `custom_type_11` varchar(100) DEFAULT NULL COMMENT '客户类型',
                                                `crm_manager_11` varchar(100) DEFAULT NULL COMMENT '派单客户经理',
                                                `custom_name_11` varchar(100) DEFAULT NULL COMMENT '客户名称',
                                                `crm_parent_no_11` varchar(100) DEFAULT NULL COMMENT '项目母单编号',
                                                `crm_name_11` varchar(100) DEFAULT NULL COMMENT '项目名称',
                                                `org_name_11` varchar(100) DEFAULT NULL COMMENT '学院分(子)机构',
                                                `product_11` varchar(100) DEFAULT NULL COMMENT '实施产品',
                                                `child_manager_11` varchar(100) DEFAULT NULL COMMENT '子项目经理',
                                                `exam_start_time_11` varchar(100) DEFAULT NULL COMMENT '考试开始时间',
                                                `exam_end_time_11` varchar(100) DEFAULT NULL COMMENT '考试结束时间',
                                                `remark_11` varchar(100) DEFAULT NULL COMMENT '特殊要求及备注',
                                                `project_type_11` varchar(100) DEFAULT NULL COMMENT '项目类型'
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='sop动态字段表';

-- ----------------------------
-- Table structure for t_b_sop_dynamic_office_1
-- ----------------------------
DROP TABLE IF EXISTS `t_b_sop_dynamic_office_1`;
CREATE TABLE `t_b_sop_dynamic_office_1` (
                                            `type` varchar(20) NOT NULL COMMENT '流程类型，OFFICE_SOP_FLOW：教务处SOP，CLOUD_MARK_SOP_FLOW：研究生SOP，DING_EXCEPTION_FLOW：考勤异常审核流程，PROJECT_EXCHANGE_FLOW：项目计划变更流程，QUALITY_PROBLEM_FLOW：质量问题反馈流程',
                                            `flow_deployment_id` varchar(50) NOT NULL COMMENT '流程部署id',
                                            `version` int NOT NULL DEFAULT '1' COMMENT '版本号',
                                            `code` varchar(30) DEFAULT NULL COMMENT '流程编号',
                                            `flow_id` bigint DEFAULT NULL COMMENT '流程id',
                                            `course_count_1` int DEFAULT NULL COMMENT '科目数量',
                                            `exam_student_course_count_1` int DEFAULT NULL COMMENT '考生科次',
                                            `scan_count_1` int DEFAULT NULL COMMENT '扫描仪数量(台)',
                                            `week_people_day_1` int DEFAULT NULL COMMENT '现场标准服务周期（人天）',
                                            `exam_student_Internal_date_1` varchar(100) DEFAULT NULL COMMENT '考生数据内部交接时间',
                                            `exam_plan_date_1` varchar(100) DEFAULT NULL COMMENT '考试时间安排表获取时间',
                                            `project_key_info_date_1` varchar(100) DEFAULT NULL COMMENT '项目关键信息提交截止时间',
                                            `service_finish_plan_date_1` varchar(100) DEFAULT NULL COMMENT '现场服务完成撤场计划时间',
                                            `region_user_id_1` varchar(100) DEFAULT NULL COMMENT '区域协调人',
                                            `engineer_user_id_1` varchar(100) DEFAULT NULL COMMENT '实施工程师',
                                            `assistant_engineer_user_id_1` varchar(100) DEFAULT NULL COMMENT '助理实施工程师',
                                            `delay_rish_cb_1` varchar(100) DEFAULT NULL COMMENT '延期风险',
                                            `engineer_rish_cb_1` varchar(100) DEFAULT NULL COMMENT '实施难度',
                                            `other_remark_1` varchar(500) DEFAULT NULL COMMENT '其它备注（建议关注的其它方面）',
                                            `project_contacts_table_1` mediumtext CHARACTER SET utf8mb4 COMMENT '项目联系人表格',
                                            `deploy_way_radio_2` varchar(100) DEFAULT NULL COMMENT '部署方式',
                                            `mark_way_radio_2` varchar(100) DEFAULT NULL COMMENT '阅卷方式',
                                            `scan_net_radio_2` varchar(100) DEFAULT NULL COMMENT '扫描场地网络情况',
                                            `scan_start_time_2` varchar(100) DEFAULT NULL COMMENT '扫描开始时间',
                                            `scan_end_time_2` varchar(100) DEFAULT NULL COMMENT '扫描结束时间',
                                            `mark_start_time_2` varchar(100) DEFAULT NULL COMMENT '评卷开始时间',
                                            `mark_end_time_2` varchar(100) DEFAULT NULL COMMENT '评卷结束时间',
                                            `remark_2` varchar(500) DEFAULT NULL COMMENT '其它特殊要求',
                                            `exam_plan_photos_2` varchar(100) DEFAULT NULL COMMENT '考试时间安排表拍照上传',
                                            `approve_radio_3` varchar(100) DEFAULT NULL COMMENT '我对以上项目关键信息已审核，确认内容无误：',
                                            `approve_remark_3` varchar(500) DEFAULT NULL COMMENT '审批意见',
                                            `approve_radio_4` varchar(100) DEFAULT NULL COMMENT '我对以上项目关键信息已审核，确认内容无误：',
                                            `approve_remark_4` varchar(500) DEFAULT NULL COMMENT '审批意见',
                                            `device_in_time_5` varchar(100) DEFAULT NULL COMMENT '设备入库时间',
                                            `device_in_table_5` varchar(100) DEFAULT NULL COMMENT '设备入库表格',
                                            `data_same_6` varchar(100) DEFAULT NULL COMMENT '导入数据',
                                            `import_exam_student_count_6` varchar(100) DEFAULT NULL COMMENT '导入考生数量',
                                            `scan_set_cb_6` varchar(100) DEFAULT NULL COMMENT '扫描仪设置',
                                            `card_format_cb_6` varchar(100) DEFAULT NULL COMMENT '卡格式制作',
                                            `scan_test_cb_7` varchar(100) DEFAULT NULL COMMENT '试扫检查',
                                            `un_upload_exam_student_cb_8` varchar(100) DEFAULT NULL COMMENT '未上传考生核对',
                                            `finish_count_8` varchar(100) DEFAULT NULL COMMENT '完成数量',
                                            `upload_file_un_upload_exam_student_photo_8` varchar(100) DEFAULT NULL COMMENT '上传学校未上传考生沟通确认截图',
                                            `Identify_cb_8` varchar(100) DEFAULT NULL COMMENT '识别对照',
                                            `absent_exam_student_cb_8` varchar(100) DEFAULT NULL COMMENT '缺考名单比对',
                                            `absent_count_8` varchar(100) DEFAULT NULL COMMENT '缺考科次数量',
                                            `manual_code_cb_8` varchar(100) DEFAULT NULL COMMENT '手工输入条码确认',
                                            `mark_model_radio_9` varchar(100) DEFAULT NULL COMMENT '评卷模式',
                                            `mark_params_cb_9` varchar(100) DEFAULT NULL COMMENT '评卷参数核对',
                                            `mark_submit_cb_10` varchar(100) DEFAULT NULL COMMENT '成绩提交核查',
                                            `upload_success_photos_10` varchar(100) DEFAULT NULL COMMENT '上传验收报告(纸质)拍照',
                                            `device_in_time_11` varchar(100) DEFAULT NULL COMMENT '设备入库时间',
                                            `device_in_table_11` varchar(100) DEFAULT NULL COMMENT '设备入库表格'
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='sop动态字段表';

-- ----------------------------
-- Table structure for t_b_sop_info
-- ----------------------------
DROP TABLE IF EXISTS `t_b_sop_info`;
CREATE TABLE `t_b_sop_info` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `crm_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT 'crm单号',
                                `sop_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT 'sop单号',
                                `service_id` bigint NOT NULL COMMENT '服务单元id',
                                `custom_id` bigint NOT NULL COMMENT '客户id',
                                `product_id` bigint NOT NULL COMMENT '产品id',
                                `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '流程类型，OFFICE_SOP_FLOW：教务处SOP，CLOUD_MARK_SOP_FLOW：研究生SOP',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='sop表';

-- ----------------------------
-- Table structure for t_b_sop_info_detail
-- ----------------------------
DROP TABLE IF EXISTS `t_b_sop_info_detail`;
CREATE TABLE `t_b_sop_info_detail` (
                                       `id` bigint NOT NULL COMMENT '主键',
                                       `sop_info_id` bigint NOT NULL COMMENT 'sop信息id',
                                       `lead_id` bigint NOT NULL COMMENT '大区经理id',
                                       `region_user_id` bigint DEFAULT NULL COMMENT '区域负责人id',
                                       `engineer_user_id` bigint DEFAULT NULL COMMENT '实施工程师id',
                                       `assistant_engineer_user_ids` varchar(500) DEFAULT NULL COMMENT '助理实施工程师id数组',
                                       PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='sop明细表';

-- ----------------------------
-- Table structure for t_b_task
-- ----------------------------
DROP TABLE IF EXISTS `t_b_task`;
CREATE TABLE `t_b_task` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `type` varchar(50) NOT NULL COMMENT '任务类型，USER_ARCHIVES_IMPORT：人员档案导入，USER_ARCHIVES_EXPORT：人员档案导出，CUSTOM_IMPORT：客户导入',
                            `entity_id` bigint DEFAULT NULL COMMENT '关联业务对象id',
                            `status` varchar(30) NOT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
                            `summary` text COMMENT '实时摘要信息',
                            `progress` double DEFAULT NULL COMMENT '执行进度',
                            `result` varchar(30) DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                            `import_file_name` varchar(100) DEFAULT NULL COMMENT '导入文件名',
                            `import_file_path` varchar(500) DEFAULT NULL COMMENT '导入文件路径',
                            `result_file_path` varchar(500) DEFAULT NULL COMMENT '导出文件路径',
                            `report_file_path` varchar(500) DEFAULT NULL COMMENT '报告路径',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '更新人',
                            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `org_id` bigint DEFAULT NULL COMMENT '机构id',
                            `remark` mediumtext COMMENT '备注',
                            `obj_name` varchar(500) DEFAULT NULL COMMENT '实体名称',
                            `reset_count` int DEFAULT '0' COMMENT '重试次数',
                            `version` int DEFAULT '0' COMMENT '更新版本号',
                            `error_message` varchar(500) DEFAULT NULL COMMENT '人工错误原因',
                            PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='导入导出任务表';

-- ----------------------------
-- Table structure for t_b_user_archives
-- ----------------------------
DROP TABLE IF EXISTS `t_b_user_archives`;
CREATE TABLE `t_b_user_archives` (
                                     `id` bigint NOT NULL COMMENT '主键',
                                     `code` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '编号',
                                     `name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '姓名',
                                     `country` varchar(100) CHARACTER SET utf8mb4 NOT NULL DEFAULT '中国' COMMENT '国家',
                                     `province` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '省份',
                                     `city` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '城市',
                                     `area` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '县区',
                                     `address` varchar(150) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '地址',
                                     `identity` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '身份证号',
                                     `gender` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '性别，MAN：男，WOMAN：女',
                                     `education` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '学历',
                                     `mobile_number` varchar(30) CHARACTER SET utf8mb4 NOT NULL COMMENT '手机号',
                                     `email` varchar(30) CHARACTER SET utf8mb4 NOT NULL COMMENT '邮箱',
                                     `base_photo_path` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '底照保存地址',
                                     `status` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '人力资源状态（FREE("空闲"),NON_EXECUTION_SOP("未执行SOP"),EXECUTION_SOP("执行SOP");）',
                                     `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                     `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                     `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                     `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                     PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='人员档案表';

-- ----------------------------
-- Table structure for t_b_user_archives_allocation
-- ----------------------------
DROP TABLE IF EXISTS `t_b_user_archives_allocation`;
CREATE TABLE `t_b_user_archives_allocation` (
                                                `id` bigint NOT NULL COMMENT '主键',
                                                `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                                                `sop_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'sop单号',
                                                `crm_no` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT 'crm单号',
                                                `region_user_id` bigint DEFAULT NULL COMMENT '区域协调人id',
                                                `user_id` bigint NOT NULL COMMENT '工程师id',
                                                `role_id` bigint NOT NULL COMMENT '角色id',
                                                `archives_id` bigint NOT NULL COMMENT '人员档案id',
                                                PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='人员分配表';

-- ----------------------------
-- Table structure for t_b_user_archives_supplier
-- ----------------------------
DROP TABLE IF EXISTS `t_b_user_archives_supplier`;
CREATE TABLE `t_b_user_archives_supplier` (
                                              `id` bigint NOT NULL COMMENT '主键',
                                              `user_archives_id` bigint NOT NULL COMMENT '人员档案id',
                                              `supplier_id` bigint DEFAULT NULL COMMENT '供应商ID',
                                              `archives_time` bigint NOT NULL COMMENT '入档时间',
                                              `authentication_time` bigint DEFAULT NULL COMMENT '认证时间',
                                              `authentication_score` double DEFAULT NULL COMMENT '认证成绩',
                                              `authentication_valid_time` bigint DEFAULT NULL COMMENT '认证有效时间',
                                              `remark` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '备注',
                                              PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='人员档案与供应商表';

-- ----------------------------
-- Table structure for t_b_violation
-- ----------------------------
DROP TABLE IF EXISTS `t_b_violation`;
CREATE TABLE `t_b_violation` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                                 `sop_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'sop单号',
                                 `code` varchar(200) CHARACTER SET utf8mb4 NOT NULL COMMENT '编号',
                                 `service_id` bigint DEFAULT NULL COMMENT '服务单元id',
                                 `user_id` bigint NOT NULL COMMENT '负责人id',
                                 `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，CONTENT_ERROR：内容错误虚假，LOGIC_ERROR：逻辑不合理，OTHER：其它',
                                 `content` varchar(500) CHARACTER SET utf8mb4 NOT NULL COMMENT '违规情况',
                                 `status` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '状态，NOT_START：未跟进，FOLLOW：跟进，CLOSE：关闭，RESTART：重启',
                                 `attachment_ids` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '附件ids',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                 `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                 PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='sop违规登记表';

-- ----------------------------
-- Table structure for t_b_violation_detail
-- ----------------------------
DROP TABLE IF EXISTS `t_b_violation_detail`;
CREATE TABLE `t_b_violation_detail` (
                                        `id` bigint NOT NULL COMMENT '主键',
                                        `violation_id` bigint NOT NULL COMMENT '违规id',
                                        `remark` varchar(500) CHARACTER SET utf8mb4 NOT NULL COMMENT '跟进说明',
                                        `attachment_ids` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '附件ids',
                                        `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                        `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                        PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='违规明细表';

-- ----------------------------
-- Table structure for t_d_form_widget
-- ----------------------------
DROP TABLE IF EXISTS `t_d_form_widget`;
CREATE TABLE `t_d_form_widget` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `code` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '编码，TEXT：文本，NUMBER：数字文本，TEXTAREA：文本域，SINGLE_SELECT：单选下拉框，MULTIPLE_SELECT：多选下拉框，RADIO：单选框，CHECKBOX：复选框，DATE：日期，BUTTON：按钮，IMG：图片，VIDEO：视频，AUDIO：音频，FILE：文件，POP_SELECT：弹出选择框，LABEL：标签，TABLE：表格，SIGN：签名，CASCADE_ADDRESS：城市选择控件，OTHER：其它，FORM_GROUP_TITLE：带虚线分割线的标题，ONLE_TITLE：普通标题，独占一行，RADIO_WITH_INPUT：带1个输入框的单选框，DEVICE_IN_TABLE：设备入库表格，DEVICE_OUT_TABLE：设备出库表格',
                                   `type` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '类型，FORM：表单，TABLE：表格，OTHER：其它',
                                   `form_id` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '表单id',
                                   `form_name` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '表单名称',
                                   `title` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '标题',
                                   `input_type` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '输入类型，STRING：字符串，INT：整型，LONG：长整型，DOUBLE：浮点型，ENUM：枚举，DATE：日期，BOOL：布尔，BIGDECIMAL：精确浮点，FILE：文件，ARRAY：数组',
                                   `required` tinyint DEFAULT '1' COMMENT '是否必填，0：非必填，1：必填',
                                   `readable` tinyint DEFAULT '0' COMMENT '是否只读，0：非只读，1：只读',
                                   `writable` tinyint DEFAULT '1' COMMENT '是否可写，0：非可写，1：可写',
                                   `visable` tinyint DEFAULT '1' COMMENT '是否可见，0：不可见，1：可见',
                                   `scale` int DEFAULT NULL COMMENT '保留小数点几位',
                                   `length` int DEFAULT NULL COMMENT '长度',
                                   `binding` varchar(30) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '绑定字段',
                                   `data_grid` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '数据来源',
                                   `tips` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '提示',
                                   `format` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '格式',
                                   `span` int DEFAULT '6' COMMENT '占宽符',
                                   `sub_title` varchar(1000) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '子标题',
                                   `options` varchar(500) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '选项值，RADIO或CHECKBOX填此值',
                                   `flow_type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '流程类型，OFFICE_SOP_FLOW：教务处SOP，CLOUD_MARK_SOP_FLOW：研究生SOP，DING_EXCEPTION_FLOW：考勤异常审核流程，PROJECT_EXCHANGE_FLOW：项目计划变更流程，QUALITY_PROBLEM_FLOW：质量问题反馈流程',
                                   `form_setup` int NOT NULL COMMENT '表单步骤',
                                   `handle_time` tinyint NOT NULL DEFAULT '0' COMMENT '处理时限，0：不处理，1：可处理',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='动态表单控件表';

-- ----------------------------
-- Table structure for t_d_form_widget_metadata
-- ----------------------------
DROP TABLE IF EXISTS `t_d_form_widget_metadata`;
CREATE TABLE `t_d_form_widget_metadata` (
                                            `id` bigint NOT NULL COMMENT '主键',
                                            `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '流程类型，OFFICE_SOP_FLOW：教务处SOP，CLOUD_MARK_SOP_FLOW：研究生SOP，DING_EXCEPTION_FLOW：考勤异常审核流程，PROJECT_EXCHANGE_FLOW：项目计划变更流程，QUALITY_PROBLEM_FLOW：质量问题反馈流程',
                                            `flow_deployment_id` varchar(50) CHARACTER SET utf8mb4 NOT NULL COMMENT '流程部署id',
                                            `version` int NOT NULL DEFAULT '1' COMMENT '版本号',
                                            `code` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '编码，TEXT：文本，NUMBER：数字文本，TEXTAREA：文本域，编码，TEXT：文本，TEXTAREA：文本域，SINGLE_SELECT：单选下拉框，MULTIPLE_SELECT：多选下拉框，RADIO：单选框，CHECKBOX：复选框，DATE：日期，BUTTON：按钮，IMG：图片，VIDEO：视频，AUDIO：音频，FILE：文件，POP_SELECT：弹出选择框，LABEL：标签，TABLE：表格，SIGN：签名，CASCADE_ADDRESS：城市选择控件，OTHER：其它，FORM_GROUP_TITLE：带虚线分割线的标题，ONLE_TITLE：普通标题，独占一行，RADIO_WITH_INPUT：带1个输入框的单选框，DEVICE_IN_TABLE：设备入库表格，DEVICE_OUT_TABLE：设备出库表格，RADIO：单选框，CHECKBOX：复选框，DATE：日期，BUTTON：按钮，IMG：图片，VIDEO：视频，AUDIO：音频，FILE：文件，POP_SELECT：弹出选择框，LABEL：标签，TABLE：表格，SIGN：签名，CASCADE_ADDRESS：城市选择控件，OTHER：其它，FORM_GROUP_TITLE：带虚线分割线的标题，ONLE_TITLE：普通标题，独占一行，RADIO_WITH_INPUT：带1个输入框的单选框，DEVICE_IN_TABLE：设备入库表格，DEVICE_OUT_TABLE：设备出库表格',
                                            `field_id` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '字段id',
                                            `field_name` varchar(100) CHARACTER SET utf8mb4 NOT NULL COMMENT '字段名称',
                                            `field_title` varchar(50) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '字段标题',
                                            `field_check` tinyint NOT NULL DEFAULT '0' COMMENT '是否勾选，0：未勾选，1：勾选',
                                            `setup` int NOT NULL COMMENT '流程步骤',
                                            `change_join` tinyint DEFAULT NULL COMMENT '是否是项目计划变更关联字段，0：不是，1：是',
                                            `create_time` bigint NOT NULL COMMENT '创建时间'
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='动态表单元数据表';

-- ----------------------------
-- Table structure for t_d_table_prop
-- ----------------------------
DROP TABLE IF EXISTS `t_d_table_prop`;
CREATE TABLE `t_d_table_prop` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `widget_id` bigint DEFAULT NULL COMMENT '控件id',
                                  `td_index` int DEFAULT NULL COMMENT '序号',
                                  `td_id` varchar(50) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '列id',
                                  `td_name` varchar(50) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '列名称',
                                  `title` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '标题',
                                  `width` double DEFAULT NULL COMMENT '宽度',
                                  `height` double DEFAULT NULL COMMENT '高度',
                                  `color` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '颜色',
                                  `rowspan` int DEFAULT NULL COMMENT '跨行',
                                  `colspan` int DEFAULT NULL COMMENT '跨列',
                                  `sub_title` varchar(1000) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '子标题',
                                  `tips` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '提示',
                                  `td_order` tinyint DEFAULT '1' COMMENT '是否排序，0：不排序，1：排序',
                                  `td_search` tinyint DEFAULT '1' COMMENT '是否搜索，0：不搜索，1：搜索',
                                  `edit_widget_id` bigint DEFAULT NULL COMMENT '编辑控件id',
                                  `obj` mediumtext CHARACTER SET utf8mb4 COMMENT '实体内容',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='表格属性表';

-- ----------------------------
-- Table structure for t_f_custom_flow
-- ----------------------------
DROP TABLE IF EXISTS `t_f_custom_flow`;
CREATE TABLE `t_f_custom_flow` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                   `name` varchar(100) NOT NULL COMMENT '流程名称',
                                   `model_type` varchar(50) NOT NULL COMMENT '流程模式类型，USER_FIXED：指定人员，APPROVE_SET：发起人指定',
                                   `type` varchar(100) NOT NULL COMMENT '流程类型，OFFICE_SOP_FLOW：教务处SOP，CLOUD_MARK_SOP_FLOW：研究生SOP，DING_EXCEPTION_FLOW：考勤异常审核流程，PROJECT_EXCHANGE_FLOW：项目计划变更流程，QUALITY_PROBLEM_FLOW：质量问题反馈流程',
                                   `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                   `publish` tinyint NOT NULL DEFAULT '1' COMMENT '是否发布，0：否，1：是',
                                   `object_data` mediumtext COMMENT '自定义流程源数据',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                   `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                   `version` int NOT NULL DEFAULT '1' COMMENT '版本号',
                                   `flow_definition_id` varchar(50) DEFAULT NULL COMMENT '流程定义id',
                                   `flow_deployment_id` varchar(50) DEFAULT NULL COMMENT '流程部署id',
                                   `flow_process_var` mediumtext COMMENT '流程过程变量数据',
                                   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='自定义流程表';

-- ----------------------------
-- Table structure for t_f_custom_flow_entity
-- ----------------------------
DROP TABLE IF EXISTS `t_f_custom_flow_entity`;
CREATE TABLE `t_f_custom_flow_entity` (
                                          `id` bigint NOT NULL COMMENT '主键',
                                          `t_f_custom_flow_id` bigint NOT NULL COMMENT '自定义流程id',
                                          `crm_no` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT 'crm单号',
                                          `code` varchar(30) CHARACTER SET utf8mb4 NOT NULL COMMENT '编号',
                                          `obj_id` bigint DEFAULT NULL COMMENT '实体id',
                                          `flow_id` bigint DEFAULT NULL COMMENT '流程id',
                                          `flow_process_var` mediumtext CHARACTER SET utf8mb4 NOT NULL COMMENT '流程过程变量',
                                          `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                          `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                          `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                          `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                          PRIMARY KEY (`id`) USING BTREE,
                                          UNIQUE KEY `t_f_custom_flow_entity_UN_code` (`code`,`flow_id`),
                                          KEY `flow_entity_flowId_idx` (`flow_id`),
                                          KEY `flow_entity_custom_flowId_idx` (`t_f_custom_flow_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='自定义流程实体数据';

-- ----------------------------
-- Table structure for t_f_flow_approve
-- ----------------------------
DROP TABLE IF EXISTS `t_f_flow_approve`;
CREATE TABLE `t_f_flow_approve` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                    `flow_id` bigint NOT NULL COMMENT '流程id',
                                    `approve_id` bigint DEFAULT NULL COMMENT '审核id',
                                    `status` varchar(50) NOT NULL COMMENT '状态，START：已开始，AUDITING：审核中，REJECT：已驳回，END：已终止，FINISH：已结束',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    `setup` tinyint NOT NULL COMMENT '计划步骤',
                                    `approve_setup` int DEFAULT NULL COMMENT '审批步骤',
                                    `approve_max_setup` int DEFAULT NULL COMMENT '最大审批步骤',
                                    `transfer_assignee` mediumtext COMMENT '流程转办',
                                    `all_assignee` mediumtext COMMENT '会签审批人',
                                    `reject_link` mediumtext COMMENT '驳回路线',
                                    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='流程审核表';

-- ----------------------------
-- Table structure for t_f_flow_log
-- ----------------------------
DROP TABLE IF EXISTS `t_f_flow_log`;
CREATE TABLE `t_f_flow_log` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                `flow_id` bigint NOT NULL COMMENT '流程id',
                                `object_table` varchar(100) DEFAULT NULL COMMENT '实体表',
                                `object_id` bigint NOT NULL COMMENT '实体id',
                                `approve_id` bigint DEFAULT NULL COMMENT '审核人id',
                                `approve_setup` tinyint DEFAULT NULL COMMENT '审核步骤',
                                `approve_remark` mediumtext COMMENT '审核意见',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                `approve_operation` varchar(50) NOT NULL COMMENT '审批操作，START：提交，DRAFT：草稿，APPROVE：审批，REJECT：驳回，END：终止，CANCEL：撤销，EXCHANGE：转他人审批，FINISH：结束',
                                `pend_approve_id` mediumtext COMMENT '待审核人id',
                                `attachment_ids` mediumtext COMMENT '附件id集合',
                                `approve_multi_setup` int DEFAULT NULL COMMENT '审批步骤',
                                `approve_user_approve_type` varchar(30) DEFAULT NULL COMMENT '审批用户类别，ORDER：依次审批，ALL：会签（所有人必须审批），SOME：或签（一名审批人同意或拒绝即可）',
                                `task_id` bigint DEFAULT NULL COMMENT '流程节点id',
                                PRIMARY KEY (`id`) USING BTREE,
                                KEY `flow_log_objectId_idx` (`object_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='流程流水表';

-- ----------------------------
-- Table structure for t_g_error
-- ----------------------------
DROP TABLE IF EXISTS `t_g_error`;
CREATE TABLE `t_g_error` (
                             `id` bigint NOT NULL COMMENT '主键',
                             `org_id` bigint DEFAULT NULL COMMENT '机构id',
                             `obj_id` bigint DEFAULT NULL COMMENT '实体id',
                             `summary` mediumtext COMMENT '实时摘要信息',
                             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='全局异常错误信息表';

-- ----------------------------
-- Table structure for t_s_auth
-- ----------------------------
DROP TABLE IF EXISTS `t_s_auth`;
CREATE TABLE `t_s_auth` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `school_id` bigint DEFAULT NULL COMMENT '学校id',
                            `access_key` varchar(255) DEFAULT NULL COMMENT 'accessKey',
                            `access_secret` varchar(255) DEFAULT NULL COMMENT 'accessSecret',
                            `description` text COMMENT '离线授权证书',
                            `type` varchar(16) NOT NULL COMMENT '授权类型',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '更新人',
                            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                            `expire_time` bigint DEFAULT NULL COMMENT '过期时间',
                            `file` mediumblob COMMENT '文件数据',
                            PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='激活授权配置表';

-- ----------------------------
-- Table structure for t_s_job_log
-- ----------------------------
DROP TABLE IF EXISTS `t_s_job_log`;
CREATE TABLE `t_s_job_log` (
                               `id` bigint NOT NULL COMMENT '主键',
                               `job_remind_id` bigint NOT NULL COMMENT '任务提醒id',
                               `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，FLOW：流程，NOTICE：公告',
                               `code` varchar(100) CHARACTER SET utf8 DEFAULT NULL COMMENT '编码',
                               `obj_id` bigint NOT NULL COMMENT '实体id',
                               `obj_name` varchar(100) CHARACTER SET utf8 DEFAULT NULL COMMENT '实体名称',
                               `remind_type` varchar(20) CHARACTER SET utf8 NOT NULL COMMENT '提醒类别，BEFORE：提前，AFTER：超时',
                               `create_id` bigint NOT NULL COMMENT '创建人id',
                               `create_time` bigint NOT NULL COMMENT '创建时间',
                               PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='任务日志表';

-- ----------------------------
-- Table structure for t_s_job_remind
-- ----------------------------
DROP TABLE IF EXISTS `t_s_job_remind`;
CREATE TABLE `t_s_job_remind` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '类型，FLOW：流程，NOTICE：公告',
                                  `code` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '编码',
                                  `obj_id` bigint NOT NULL COMMENT '实体id',
                                  `obj_name` varchar(100) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '实体名称',
                                  `remind_type` varchar(20) CHARACTER SET utf8mb4 NOT NULL COMMENT '提醒类别，BEFORE：提前，AFTER：超时',
                                  `exec_time` bigint DEFAULT NULL COMMENT '执行时间',
                                  `exec_field` varchar(50) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '执行字段',
                                  `receive_user_id` bigint DEFAULT NULL COMMENT '接收人id',
                                  `approve_operation` varchar(20) CHARACTER SET utf8mb4 DEFAULT NULL COMMENT '审批操作，START：提交，DRAFT：草稿，APPROVE：审批，REJECT：驳回，END：终止，CANCEL：撤销，EXCHANGE：转他人审批，FINISH：结束',
                                  `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                  `create_id` bigint NOT NULL COMMENT '创建人id',
                                  `create_time` bigint NOT NULL COMMENT '创建时间',
                                  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='任务提醒表';

-- ----------------------------
-- Function structure for currval
-- ----------------------------
DROP FUNCTION IF EXISTS `currval`;
delimiter ;;
CREATE DEFINER=`root`@`%` FUNCTION `currval`(seq_name VARCHAR(50)) RETURNS int
    DETERMINISTIC
BEGIN
	DECLARE value LONG;
	SET value = 0;
SELECT current_value INTO value
FROM sequence
WHERE name = seq_name;
RETURN value;
END;
;;
delimiter ;

-- ----------------------------
-- Function structure for nextval
-- ----------------------------
DROP FUNCTION IF EXISTS `nextval`;
delimiter ;;
CREATE DEFINER=`root`@`%` FUNCTION `nextval`(seq_name VARCHAR(50)) RETURNS int
    DETERMINISTIC
BEGIN
UPDATE sequence
SET current_value = current_value + increment
WHERE name = seq_name;
RETURN currval(seq_name);
END;
;;
delimiter ;

INSERT INTO `sequence` VALUES ('cloudMarkSopFlow', 0, 1);
INSERT INTO `sequence` VALUES ('deviceInOutCode', 0, 1);
INSERT INTO `sequence` VALUES ('dingExceptionFlow', 0, 1);
INSERT INTO `sequence` VALUES ('officeSopFlow', 0, 1);
INSERT INTO `sequence` VALUES ('projectExchangeFlow', 0, 1);
INSERT INTO `sequence` VALUES ('qualityProblemFlow', 0, 1);
INSERT INTO `sequence` VALUES ('userArchivesCode', 0, 1);
INSERT INTO `sequence` VALUES ('violationWarn', 0, 1);

INSERT INTO `sys_config` VALUES (1, NULL, 'sys.user.initPassword', '初始密码', '123456', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (2, NULL, 'sys.warning.days', '预警天数', '3', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (3, NULL, 'sys.code.enable', '是否启用短信验证码', 'true', 'true-启用，false-禁用', 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (4, NULL, 'sys.message.enable', '是否启用短信消息提示', 'true', 'true-启用，false-禁用', 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (5, NULL, 'sys.message.resendCount', '失败短信重试次数', '3', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (6, NULL, 'attachment.type', '附件类型', '[.xlsx,.xls,.doc,.docx,.pdf,.jpg,.jpeg,.png,.html,.zip,.mp3,.wav,.dll,.exe,.ftl,.bpmn,.xml]', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (7, NULL, 'attachment.length', '附件名称长度', '100', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (8, NULL, 'attachment.size', '附件大小 ', '200', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (9, NULL, 'thread.pool.core.size', '自定义线程池大小', '200', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (10, NULL, 'custom.thread.pool.core.size', '是否自定义线程池大小', 'true', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (11, NULL, 'session.active', 'session会话时长', '6h', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (12, NULL, 'sms.normal.code', '万能短信验证码', 'qmth', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (13, NULL, 'code.expired.time', '短信验证码有效时间', '2', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (14, NULL, 'code.send.interval', '短信验证码发送间隔', '60', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (15, NULL, 'sys.txt.charset', 'txt文件编码', 'UTF-8', NULL, 1, 1, 1, NULL, NULL, 1684994975313);
INSERT INTO `sys_config` VALUES (16, NULL, 'admin.logo.url', '超级管理员logo', 'http://qmth-test.oss-cn-shenzhen.aliyuncs.com/frontend/wx_logo.png', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (17, NULL, 'sms.sign.name', '短信签名', '启明泰和', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (18, NULL, 'sms.tpl.code', '登录短信验证码', 'SMS_147416565', NULL, 1, 2, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (19, NULL, 'flow.code.length', '流程编码长度', '3', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (20, NULL, 'flow.job.before.time', '流程提前提醒任务时间（单位：分）', '2', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (21, NULL, 'flow.job.after.time', '流程超时提醒任务时间（单位：分）', '2', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (22, NULL, 'notice.job.after.time', '公告超时提醒任务时间（单位：分）', '30', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (23, NULL, 'remind.job.poll.time', '任务提醒轮询时间', '0 0/1 * * * ?', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (24, NULL, 'remind.job.db.limit', '任务提醒查询条数', 'limit 0,100000', NULL, 1, 2, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (25, NULL, 'sms.notice.code', '系统通知公告', 'SMS_462685325', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (26, NULL, 'sms.sop.before.remind.code', '教务处/研究生SOP提前提醒通知', 'SMS_462805277', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (27, NULL, 'sms.sop.done.code', '教务处/研究生SOP节点负责人通知', 'SMS_462730333', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (28, NULL, 'sms.flow.project.exchange.finish.code', '系统计划变更审核通知', 'SMS_462680680', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (29, NULL, 'sms.flow.ding.exception.finish.code', '异常审核通知', 'SMS_462700329', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (30, NULL, 'sms.sop.after.remind.code', '延期提醒通知', 'SMS_462700328', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (31, NULL, 'sms.violation.remind.code', '违规提醒通知', 'SMS_462805303', NULL, 1, 1, 1, NULL, NULL, NULL);

INSERT INTO `sys_privilege` VALUES (1, '系统管理', 'systemManage', 'MENU', NULL, 8, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (2, '配置管理', 'configureManage', 'MENU', 1, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (3, '客户配置', 'custom', 'MENU', 2, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (4, '供应商配置', 'supplier', 'MENU', 2, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (5, '设备配置', 'device', 'MENU', 2, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (6, '服务档位配置', 'level', 'MENU', 2, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (7, '考勤配置', 'dingConfigure', 'MENU', 2, 5, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (8, '系统日志', 'logManage', 'MENU', 1, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (9, '通知公告管理', 'noticeManage', 'MENU', 8, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (10, '日志查询', 'log', 'MENU', 8, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (11, '用户管理', 'userManage', 'MENU', NULL, 7, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (12, '组织架构管理', 'orgManage', 'MENU', 11, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (13, '组织架构管理', 'org', 'MENU', 12, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (14, '用户权限管理', 'userPrivilegeManage', 'MENU', 11, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (15, '用户管理', 'user', 'MENU', 14, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (16, '角色管理', 'role', 'MENU', 14, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (17, '修改密码', 'UpdatePwd', 'LINK', 15, 3, NULL, '18', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (18, '用户修改密码', '/api/admin/user/update_password', 'URL', 15, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (19, '项目质量管理', 'projectQualityManage', 'MENU', NULL, 6, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (20, '项目质量管理', 'projectChildQualityManage', 'MENU', 19, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (21, '质量问题反馈', 'qualityProblem', 'MENU', 20, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (23, '质量监控分析', 'qualityProblemControl', 'MENU', 20, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (24, '工时管理', 'hoursManage', 'MENU', NULL, 5, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (25, '工时管理', 'hoursChildManage', 'MENU', 24, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (26, '考勤打卡', 'ding', 'MENU', 25, 1, NULL, '3017,2044,2045,2046', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (27, '异常审核', 'exception', 'MENU', 25, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (28, '考勤提交', 'dingSubmit', 'MENU', 25, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (29, '工时统计', 'hourSubmit', 'MENU', 25, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (30, '考勤监控预警', 'dingWarn', 'MENU', 25, 5, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (31, '资源保障', 'resourceManage', 'MENU', NULL, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (32, '人资保障', 'humanManage', 'MENU', 31, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (33, '人员档案管理', 'userArchives', 'MENU', 32, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (34, '人员调配', 'userAllocate', 'MENU', 32, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (35, '人资监控', 'userArchivesControl', 'MENU', 32, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (36, '设备保障', 'deviceManage', 'MENU', 31, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (37, '出入库登记查询', 'deviceInOut', 'MENU', 36, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (38, '设备资源监控', 'deviceControl', 'MENU', 36, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (39, 'SOP管理', 'sopManage', 'MENU', NULL, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (40, 'SOP管理', 'sopChildManage', 'MENU', 39, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (41, '教务处SOP管理', 'office', 'MENU', 40, 1, NULL, '3034,3035', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (42, '云阅卷SOP管理', 'cloudMark', 'MENU', 40, 2, NULL, '3034,3035', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (43, '设备出入库登记', 'deviceInOutSop', 'MENU', 40, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (44, '项目计划变更报备', 'projectExchange', 'MENU', 40, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (45, 'SOP监控', 'sopControlManage', 'MENU', 39, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (46, 'SOP监控台', 'sopControl', 'MENU', 45, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (47, '延期预警', 'delayWarn', 'MENU', 45, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (48, '违规登记', 'violation', 'MENU', 45, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (49, '服务单元管理', 'serviceManage', 'MENU', NULL, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (50, '派单管理', 'crmManage', 'MENU', 49, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (51, '派单管理', 'crm', 'MENU', 50, 1, 'AUTH', '1032, 1033,1035,1036,1037,1038', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (52, '统计查询', 'crmCount', 'MENU', 50, 2, 'AUTH', '1034', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (53, '服务单元管理', 'serviceChildManage', 'MENU', 49, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (54, '服务单元管理', 'service', 'MENU', 53, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (55, '服务范围管理', 'serviceScope', 'MENU', 53, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (56, '服务区域规划', 'serviceRegion', 'MENU', 53, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (57, '统计查询', 'serviceCount', 'MENU', 53, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (58, '我的工作台', 'workManage', 'MENU', NULL, 1, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (59, '工作台', 'workChildManage', 'MENU', 58, 1, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (60, '消息提醒', 'message', 'MENU', 59, 1, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (61, '待办任务', 'work', 'MENU', 59, 2, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (62, '通知公告', 'notice', 'MENU', 59, 3, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (63, '公共接口', 'common', 'MENU', NULL, 9, NULL, NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (64, '权限管理', 'menuManage', 'MENU', 63, 1, NULL, NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (65, '用户登录', '/api/admin/common/login', 'URL', 64, 1, 'NO_AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (66, '用户登出', '/api/admin/common/logout', 'URL', 64, 2, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (67, '文件上传', '/api/admin/common/file/upload', 'URL', 64, 3, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (68, '文件下载', '/api/admin/common/file/download', 'URL', 64, 4, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (69, '文件预览', '/api/admin/common/file/preview', 'URL', 64, 5, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (72, '任务管理查询', '/api/admin/task/query', 'URL', 240, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (73, '下载导入模板', '/api/admin/common/download_import_template', 'URL', 64, 6, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (74, '列表', 'List', 'LIST', 3, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (75, '查询', 'Select', 'BUTTON', 3, 3, 'AUTH', '262', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (76, '查询条件', 'Condition', 'CONDITION', 3, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (77, '修改', 'Update', 'LINK', 3, 1, 'AUTH', '260,263', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (78, '删除', 'Delete', 'LINK', 3, 2, 'AUTH', '259,260', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (79, '新增', 'Add', 'BUTTON', 3, 1, 'AUTH', '258', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (80, '批量导入', 'BatchImport', 'BUTTON', 3, 2, 'AUTH', '261', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (81, '新增', 'Add', 'BUTTON', 4, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (82, '列表', 'List', 'LIST', 4, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (83, '修改', 'Update', 'LINK', 4, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (84, '启用/禁用', 'Enable', 'LINK', 4, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (85, '列表', 'List', 'LIST', 5, 1, 'AUTH', '275', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (86, '查询条件', 'Condition', 'CONDITION', 5, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (87, '新增', 'Add', 'BUTTON', 5, 1, 'AUTH', '270', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (88, '作废', 'Cancel', 'BUTTON', 5, 2, 'AUTH', '271', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (89, '列表', 'List', 'LIST', 6, 1, 'AUTH', '256', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (90, '新增', 'Add', 'BUTTON', 6, 1, 'AUTH', '254', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (91, '修改', 'Update', 'LINK', 6, 1, 'AUTH', '254,257', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (92, '删除', 'Delete', 'LINK', 6, 2, 'AUTH', '253', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (93, '列表', 'List', 'LIST', 7, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (94, '新增', 'Add', 'BUTTON', 7, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (95, '修改', 'Update', 'LINK', 7, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (96, '删除', 'Delete', 'LINK', 7, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (97, '查询条件', 'Condition', 'CONDITION', 7, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (98, '列表', 'List', 'LIST', 9, 1, 'AUTH', '1004', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (99, '新增', 'Add', 'BUTTON', 9, 1, 'AUTH', '1005', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (100, '撤销', 'Cancel', 'LINK', 9, 2, 'AUTH', '1003', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (101, '回执查询', 'Select', 'LINK', 9, 2, 'AUTH', '1006,1007,1008', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (102, '查询条件', 'Condition', 'CONDITION', 9, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (103, '修改', 'Update', 'LINK', 9, 3, 'AUTH', '1002,1005', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (104, '发布', 'Publish', 'LINK', 9, 1, 'AUTH', '1003', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (105, '查询', 'Select', 'BUTTON', 5, 3, 'AUTH', '275', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (106, '查询', 'Select', 'BUTTON', 7, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (107, '查询', 'Select', 'BUTTON', 9, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (108, '列表', 'List', 'LIST', 10, 1, 'AUTH', '2014', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (109, '查询条件', 'Condition', 'CONDITION', 10, 1, 'AUTH', '2014', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (110, '查询', 'Select', 'BUTTON', 10, 2, 'AUTH', '2014', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (111, '列表', 'List', 'LIST', 13, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (112, '新增', 'Add', 'BUTTON', 13, 1, 'AUTH', '249', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (113, '查询条件', 'Condition', 'CONDITION', 13, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (114, '修改', 'Update', 'LINK', 13, 1, 'AUTH', '249', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (115, '启用/禁用', 'Enable', 'LINK', 13, 2, 'AUTH', '250', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (116, '查询', 'Select', 'BUTTON', 13, 2, 'AUTH', '248', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (117, '列表', 'List', 'LIST', 15, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (118, '新增', 'Add', 'BUTTON', 15, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (119, '查询条件', 'Condition', 'CONDITION', 15, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (120, '修改', 'Update', 'LINK', 15, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (121, '启用/禁用', 'Enable', 'LINK', 15, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (122, '查询', 'Select', 'BUTTON', 15, 2, 'AUTH', '252', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (123, '列表', 'List', 'LIST', 16, 1, 'AUTH', '288', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (124, '新增', 'Add', 'BUTTON', 16, 1, 'AUTH', '289,3016', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (125, '修改', 'Update', 'LINK', 16, 1, 'AUTH', '289,3016', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (126, '删除', 'Delete', 'LINK', 16, 2, 'AUTH', '290', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (127, '列表', 'List', 'LIST', 21, 1, 'AUTH', '1031,3044', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (128, '作废', 'Cancel', 'BUTTON', 21, 1, 'AUTH', '1029,3044', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (129, '查询条件', 'Condition', 'CONDITION', 21, 1, 'AUTH', '3044', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (130, '查询', 'Select', 'BUTTON', 21, 2, 'AUTH', '1030,3044', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (131, '待审核-列表', 'List', 'LIST', 27, 1, 'AUTH', '3017,3019', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (132, '待审核-批量通过', 'BatchPass', 'BUTTON', 27, 1, 'AUTH', '3017,3022', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (133, '待审核-查询条件', 'Condition', 'CONDITION', 27, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (134, '待审核-查询', 'Select', 'BUTTON', 27, 3, 'AUTH', '3017,3019', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (135, '待审核-批量不通过', 'BatchNoPass', 'BUTTON', 27, 2, 'AUTH', '3017,3022', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (136, '待审核-通过', 'Pass', 'LINK', 27, 1, 'AUTH', '3017,3021', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (137, '待审核-不通过', 'NoPass', 'LINK', 27, 2, 'AUTH', '3017,3021', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (138, '已审核-列表', 'List', 'LIST', 27, 1, 'AUTH', '3017,3020', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (139, '已审核-查询条件', 'Condition', 'CONDITION', 27, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (140, '已审核-查询', 'Select', 'BUTTON', 27, 3, 'AUTH', '3017,3020', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (141, '列表', 'List', 'LIST', 28, 1, 'AUTH', '2037,2038', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (142, '批量提交', 'BatchSubmit', 'BUTTON', 28, 1, 'AUTH', '2039', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (143, '查询条件', 'Condition', 'CONDITION', 28, 1, 'AUTH', '2037,2038', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (144, '查询', 'Select', 'BUTTON', 28, 3, 'AUTH', '2037,2038', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (145, '批量导出', 'BatchExport', 'BUTTON', 28, 2, 'AUTH', '2042', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (146, '提交', 'Submit', 'LINK', 28, 1, 'AUTH', '2039', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (147, '撤回/取消撤回', 'Reject', 'LINK', 28, 2, 'AUTH', '2040,2041', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (148, '列表', 'List', 'LIST', 29, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (149, '导出', 'Export', 'BUTTON', 29, 1, 'AUTH', '1027', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (150, '查询条件', 'Condition', 'CONDITION', 29, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (151, '查询', 'Select', 'BUTTON', 29, 2, 'AUTH', '1026, 1028', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (152, '撤回/取消撤回', 'Reject', 'LINK', 29, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (153, '列表', 'List', 'LIST', 33, 1, 'AUTH', '2016,2017', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (154, '新增', 'Add', 'BUTTON', 33, 1, 'AUTH', '2018,2027', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (155, '批量导入', 'BatchImport', 'BUTTON', 33, 2, 'AUTH', '2019', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (156, '查询条件', 'Condition', 'CONDITION', 33, 1, 'AUTH', '2016,2017', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (157, '查询', 'Select', 'BUTTON', 33, 5, 'AUTH', '2016,2017', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (158, '批量导出', 'BatchExport', 'BUTTON', 33, 3, 'AUTH', '2020', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (159, '作废', 'Cancel', 'BUTTON', 33, 4, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (160, '修改', 'Update', 'LINK', 33, 1, 'AUTH', '2018', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (161, '列表', 'List', 'LIST', 34, 1, 'AUTH', '2021,2022,2023', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (162, '查询条件', 'Condition', 'CONDITION', 34, 1, 'AUTH', '2021,2022', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (163, '查询', 'Select', 'BUTTON', 34, 1, 'AUTH', '2021,2022', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (164, '调配', 'Allocate', 'LINK', 34, 1, 'AUTH', '2024,2030,2031', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (165, '发布SOP', 'Publish', 'LINK', 34, 2, 'AUTH', '2028', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (166, '撤销发布', 'UnPublish', 'LINK', 34, 3, 'AUTH', '2029', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (167, '列表', 'List', 'LIST', 37, 1, 'AUTH', '2036', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (168, '查询条件', 'Condition', 'CONDITION', 37, 1, 'AUTH', '2036', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (169, '查询', 'Select', 'BUTTON', 37, 1, 'AUTH', '2036', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (170, '列表', 'List', 'LIST', 38, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (171, '列表', 'List', 'LIST', 41, 1, 'AUTH', '3034,3035,3043', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (172, '查询条件', 'Condition', 'CONDITION', 41, 1, 'AUTH', '3034,3035,3043', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (173, '作废', 'Cancel', 'BUTTON', 41, 1, 'AUTH', '3046', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (174, '查询', 'Select', 'BUTTON', 41, 2, 'AUTH', '3034,3035,3043', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (175, '填报', 'Fill', 'LINK', 41, 1, 'AUTH', '3042', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (176, '计划变更报备', 'ProjectExchange', 'LINK', 41, 2, 'AUTH', '3025', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (177, '新增SOP', 'AddSop', 'LINK', 41, 3, 'AUTH', '3041', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (178, '新增违规 ', 'AddViolation', 'LINK', 41, 4, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (179, '上报质量问题', 'ProblemSubmit', 'LINK', 41, 5, 'AUTH', '1031', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (180, '列表', 'List', 'LIST', 42, 1, 'AUTH', '3034,3035,3043', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (181, '查询条件', 'Condition', 'CONDITION', 42, 1, 'AUTH', '3034,3035,3043', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (182, '作废', 'Cancel', 'BUTTON', 42, 1, 'AUTH', '3046', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (183, '查询', 'Select', 'BUTTON', 42, 2, 'AUTH', '3034,3035,3043', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (184, '填报', 'Fill', 'LINK', 42, 1, 'AUTH', '3042', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (185, '计划变更报备', 'ProjectExchange', 'LINK', 42, 2, 'AUTH', '3025', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (186, '新增违规 ', 'AddViolation', 'LINK', 42, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (187, '上报质量问题', 'ProblemSubmit', 'LINK', 42, 4, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (188, '列表', 'List', 'LIST', 43, 1, 'AUTH', '2032', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (189, '查询条件', 'Condition', 'CONDITION', 43, 1, 'AUTH', '2032', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (190, '新增', 'Add', 'BUTTON', 43, 1, 'AUTH', '2033,2034,2035', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (191, '作废', 'Cancel', 'BUTTON', 43, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (192, '查询', 'Select', 'BUTTON', 43, 3, 'AUTH', '2032', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (193, '列表', 'List', 'LIST', 44, 1, 'AUTH', '3026', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (194, '查询条件', 'Condition', 'CONDITION', 44, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (196, '查询', 'Select', 'BUTTON', 44, 2, 'AUTH', '3026', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (197, '列表', 'List', 'LIST', 47, 1, 'AUTH', '1015', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (198, '查询条件', 'Condition', 'CONDITION', 47, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (199, '查询', 'Select', 'BUTTON', 47, 1, 'AUTH', '1015', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (200, '跟进', 'Follow', 'LINK', 47, 1, 'AUTH', '1014,1017,1018', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (201, '关闭', 'Close', 'LINK', 47, 2, 'AUTH', '1013', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (202, '重启', 'Restart', 'LINK', 47, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (203, '列表', 'List', 'LIST', 48, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (204, '查询条件', 'Condition', 'CONDITION', 48, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (205, '查询', 'Select', 'BUTTON', 48, 1, 'AUTH', '1023', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (206, '跟进', 'Follow', 'LINK', 48, 1, 'AUTH', '1019,1020,1022', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (207, '关闭', 'Close', 'LINK', 48, 2, 'AUTH', '1021', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (208, '重启', 'Restart', 'LINK', 48, 3, 'AUTH', '1024', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (209, '列表', 'List', 'LIST', 51, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (210, '查询条件', 'Condition', 'CONDITION', 51, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (211, '新增', 'Add', 'BUTTON', 51, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (212, '作废', 'Cancel', 'BUTTON', 51, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (213, '批量划定', 'BatchDelimit', 'BUTTON', 51, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (214, '查询', 'Select', 'BUTTON', 51, 4, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (215, '划定', 'Delimit', 'LINK', 51, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (216, '修改', 'Update', 'LINK', 51, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (217, '重新划定', 'ReDelimit', 'LINK', 51, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (218, '列表', 'List', 'LIST', 54, 1, 'AUTH', '2001', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (219, '查询条件', 'Condition', 'CONDITION', 54, 1, 'AUTH', '2001', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (220, '新增', 'Add', 'BUTTON', 54, 1, 'AUTH', '2000', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (221, '查询', 'Select', 'BUTTON', 54, 2, 'AUTH', '2001', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (222, '修改', 'Update', 'LINK', 54, 1, 'AUTH', '2000', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (223, '作废', 'Cancel', 'LINK', 54, 2, 'AUTH', '2005', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (224, '设置考勤组', 'Set', 'LINK', 54, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (225, '发布', 'Publish', 'LINK', 54, 4, 'AUTH', '2002', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (226, '重启', 'Restart', 'LINK', 54, 5, 'AUTH', '2004', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (227, '关闭', 'Close', 'LINK', 54, 6, 'AUTH', '2003', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (228, '列表', 'List', 'LIST', 55, 1, 'AUTH', '2006', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (229, '查询条件', 'Condition', 'CONDITION', 55, 1, 'AUTH', '2006', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (230, '新增服务范围', 'Add', 'BUTTON', 55, 1, 'AUTH', '2008,2009', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (231, '查询', 'Select', 'BUTTON', 55, 2, 'AUTH', '2006', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (232, '移除', 'Delete', 'LINK', 55, 1, 'AUTH', '2010', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (233, '列表', 'List', 'LIST', 56, 1, 'AUTH', '2011', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (234, '查询条件', 'Condition', 'CONDITION', 56, 1, 'AUTH', '2011', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (235, '新增', 'Add', 'BUTTON', 56, 1, 'AUTH', '2012', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (236, '查询', 'Select', 'BUTTON', 56, 2, 'AUTH', '2011', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (237, '修改', 'Update', 'LINK', 56, 1, 'AUTH', '2012', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (238, '删除', 'Delete', 'LINK', 56, 2, 'AUTH', '2013', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (239, '任务管理', 'taskManage', 'MENU', 1, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (240, '任务管理', 'task', 'MENU', 239, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (241, '列表', 'List', 'LIST', 240, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (242, '查询条件', 'Condition', 'CONDITION', 240, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (243, '查询', 'Select', 'BUTTON', 240, 2, 'AUTH', '72', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (244, '导出日志', 'Export', 'LINK', 240, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (245, '下载文件', 'Download', 'LINK', 240, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (246, '获取菜单权限', '/api/admin/sys/privilege/list', 'URL', 64, 7, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (247, '获取用户权限', '/api/admin/common/get_menu', 'URL', 64, 8, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (248, '组织架构查询', '/api/admin/org/list', 'URL', 13, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (249, '组织架构保存/修改', '/api/admin/org/save', 'URL', 13, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (250, '组织架构启用/禁用', '/api/admin/org/enable', 'URL', 13, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (251, '获取机构下所有用户', '/api/admin/common/get_org_user_list', 'URL', 64, 9, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (252, '用户查询', '/api/admin/user/list', 'URL', 15, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (253, '服务档位删除', '/api/sys/level/delete', 'URL', 6, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (254, '服务档位', '/api/sys/level/get', 'URL', 6, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (255, '服务档位列表', '/api/sys/level/list', 'URL', 6, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (256, '服务档位列表', '/api/sys/level/query', 'URL', 6, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (257, '服务档位修改', '/api/sys/level/update', 'URL', 6, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (258, '客户新增', '/api/sys/custom/add', 'URL', 3, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (259, '客户删除', '/api/sys/custom/delete', 'URL', 3, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (260, '客户查询', '/api/sys/custom/get', 'URL', 3, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (261, '客户批量导入', '/api/sys/custom/import', 'URL', 3, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (262, '客户查询条件', '/api/sys/custom/query', 'URL', 3, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (263, '客户修改', '/api/sys/custom/update', 'URL', 3, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (264, '供应商新增', '/api/sys/supplier/add', 'URL', 4, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (265, '供应商启用/禁用', '/api/sys/supplier/enable', 'URL', 4, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (266, '供应商列表', '/api/sys/supplier/get', 'URL', 4, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (267, '供应商列表', '/api/sys/supplier/list', 'URL', 64, 27, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (268, '供应商列表', '/api/sys/supplier/query', 'URL', 4, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (269, '供应商修改', '/api/sys/supplier/update', 'URL', 4, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (270, '设备新增修改', '/api/sys/device/save', 'URL', 5, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (271, '设备作废', '/api/sys/device/delete', 'URL', 5, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (272, '设备禁用', '/api/sys/device/disable', 'URL', 5, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (273, '设备查询条件', '/api/sys/device/get', 'URL', 5, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (274, '设备列表', '/api/sys/device/list', 'URL', 5, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (275, '设备查询条件', '/api/sys/device/query', 'URL', 5, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (276, '设备新增', '/api/sys/device/update', 'URL', 5, 7, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (277, '考勤新增', '/api/sys/ding/group/add', 'URL', 7, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (278, '考勤删除', '/api/sys/ding/group/delete', 'URL', 7, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (279, '考勤查询', '/api/sys/ding/group/get', 'URL', 7, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (280, '考勤查询', '/api/sys/ding/group/list', 'URL', 7, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (281, '考勤查询条件', '/api/sys/ding/group/query', 'URL', 7, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (282, '考勤修改', '/api/sys/ding/group/update', 'URL', 7, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (283, '用户新增/修改', '/api/admin/user/save', 'URL', 15, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (284, '用户启用/禁用', '/api/admin/user/enable', 'URL', 15, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (285, '获取所有角色', '/api/admin/common/get_role_list', 'URL', 64, 10, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (286, '获取所有用户', '/api/admin/common/get_user_list', 'URL', 64, 11, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (287, '获取所有机构', '/api/admin/common/get_org_list', 'URL', 64, 12, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (288, '角色查询', '/api/admin/role/list', 'URL', 16, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (289, '角色新增/修改', '/api/admin/role/save', 'URL', 16, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (290, '角色删除', '/api/admin/role/delete', 'URL', 16, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1000, '通知公告', '/api/sys/notice/delete', 'URL', 9, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1001, '通知公告', '/api/sys/notice/disable', 'URL', 9, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1002, '通知公告', '/api/sys/notice/get', 'URL', 9, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1003, '通知公告发布撤销', '/api/sys/notice/publishOrUnpublish', 'URL', 9, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1004, '通知公告列表', '/api/sys/notice/query', 'URL', 9, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1005, '通知公告新增修改', '/api/sys/notice/save', 'URL', 9, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1006, '回执查询统计', '/api/sys/message/count', 'URL', 9, 7, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1007, '回执查询到出', '/api/sys/message/export', 'URL', 9, 8, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1008, '回执查询', '/api/sys/message/query', 'URL', 9, 9, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1009, '按多个类型统计当前用户未读消息', '/api/sys/message/countByTypes', 'URL', 59, 1, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1010, '查看消息详细', '/api/sys/message/get', 'URL', 59, 2, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1011, '按多个类型查询当前用户未读消息', '/api/sys/message/pageByTypes', 'URL', 59, 3, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1012, '标记消息已阅读', '/api/sys/message/read', 'URL', 59, 4, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1013, '延期预警关闭', '/api/admin/tb/delay/warn/close', 'URL', 47, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1014, '延期预警跟进', '/api/admin/tb/delay/warn/get', 'URL', 47, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1015, '延期预警查询', '/api/admin/tb/delay/warn/query', 'URL', 47, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1016, '延期预警重启', '/api/admin/tb/delay/warn/restart', 'URL', 47, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1017, '延期预警跟进', '/api/admin/tb/delay/warn/detail/list', 'URL', 47, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1018, '延期预警跟进', '/api/admin/tb/delay/warn/detail/save', 'URL', 47, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1019, '违规登记跟进', '/api/admin/tb/violation/detail/query', 'URL', 48, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1020, '违规登记跟进', '/api/admin/tb/violation/detail/save', 'URL', 48, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1021, '违规登记关闭', '/api/admin/tb/violation/close', 'URL', 48, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1022, '违规登记跟进', '/api/admin/tb/violation/get', 'URL', 48, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1023, '违规登记查询', '/api/admin/tb/violation/query', 'URL', 48, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1024, '违规登记重启', '/api/admin/tb/violation/restart', 'URL', 48, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1025, '违规登记保存', '/api/admin/tb/violation/save', 'URL', 48, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1026, '工时统计', '/api/admin/tb/ding/count', 'URL', 29, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1027, '工时统计', '/api/admin/tb/ding/export', 'URL', 29, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1028, '工时统计', '/api/admin/tb/ding/query', 'URL', 29, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1029, '质量问题反馈', '/api/admin/tb/quality/problem/apply/delete', 'URL', 21, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1030, '质量问题反馈', '/api/admin/tb/quality/problem/apply/query', 'URL', 21, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1031, '质量问题反馈', '/api/admin/tb/quality/problem/apply/save', 'URL', 21, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1032, '派单管理', '/api/admin/tb/crm/batchDisable', 'URL', 50, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1033, '派单管理', '/api/admin/tb/crm/batchZone', 'URL', 50, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1034, '派单管理', '/api/admin/tb/crm/countWaitZone', 'URL', 50, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1035, '派单管理', '/api/admin/tb/crm/delete', 'URL', 50, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1036, '派单管理', '/api/admin/tb/crm/get', 'URL', 50, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1037, '派单管理', '/api/admin/tb/crm/query', 'URL', 50, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1038, '派单管理', '/api/admin/tb/crm/save', 'URL', 50, 7, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1039, '客户表查询', '/api/sys/custom/list', 'URL', 64, 25, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1040, '获取产品信息列表接口', '/api/admin/tb/product/list', 'URL', 64, 26, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1041, '考勤明细查询', '/api/admin/tb/ding/attendance/count', 'URL', 1044, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1042, '考勤明细查询', '/api/admin/tb/ding/attendance/export', 'URL', 1044, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1043, '考勤明细查询', '/api/admin/tb/ding/attendance/query', 'URL', 1044, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1044, '考勤明细查询', 'dingDetail', 'MENU', 24, 1, NULL, '1041,1042,1043', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (1045, '设备品牌表列表接口', '/api/sys/device/brand/list', 'URL', 64, 25, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1046, '设备启用', '/api/sys/device/enable', 'URL', 5, 7, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1047, '设备导入', '/api/sys/device/import', 'URL', 5, 8, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (1048, '启用', 'Select', 'BUTTON', 5, 4, 'AUTH', '1045', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (1049, '禁用', 'Select', 'BUTTON', 5, 5, 'AUTH', '272', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (1050, '导入', 'Select', 'BUTTON', 5, 6, 'AUTH', '1046', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (2000, '服务单元管理-编辑', '/api/service/service/unit/edit', 'URL', 54, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2001, '服务单元管理-分页查询', '/api/service/service/unit/page', 'URL', 54, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2002, '服务单元管理-发布', '/api/service/service/unit/publish', 'URL', 54, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2003, '服务单元管理-关闭', '/api/service/service/unit/cloze', 'URL', 54, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2004, '服务单元管理-重启', '/api/service/service/unit/restart', 'URL', 54, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2005, '服务单元管理-作废', '/api/service/service/unit/cancel', 'URL', 54, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2006, '服务范围管理-分页查询', '/api/service/service/scope/page', 'URL', 55, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2007, '服务范围管理-派单小计', '/api/service/service/scope/subTotal', 'URL', 55, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2008, '服务范围管理-新增服务范围-未绑定派单分页查询', '/api/service/service/scope/unbind/page', 'URL', 55, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2009, '服务范围管理-批量划定派单和服务单元关系', '/api/service/service/scope/bind_batch', 'URL', 55, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2010, '服务范围管理-移出', '/api/service/service/scope/unbind', 'URL', 55, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2011, '服务区域规划-分页查询', '/api/service/service/region/page', 'URL', 56, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2012, '服务区域规划-编辑', '/api/service/service/region/edit', 'URL', 56, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2013, '服务区域规划-删除', '/api/service/service/region/remove', 'URL', 56, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2014, '日志管理-查询', '/api/sys/log/page', 'URL', 10, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2015, '公共接口-查询服务单元列表', '/api/admin/common/query_service_unit', 'URL', 64, 25, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2016, '人员档案管理-分页查询', '/api/admin/user/archives/page', 'URL', 33, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2017, '人员档案管理-小计', '/api/admin/user/archives/sub_total', 'URL', 33, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2018, '人员档案管理-编辑', '/api/admin/user/archives/edit', 'URL', 33, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2019, '人员档案管理-导入', '/api/admin/user/archives/import', 'URL', 33, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2020, '人员档案管理-导出', '/api/admin/user/archives/export', 'URL', 33, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2021, '人员调配管理-分页查询', '/api/admin/user/archives/allocation/page', 'URL', 34, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2022, '人员调配管理-小计查询', '/api/admin/user/archives/allocation/sub_total', 'URL', 34, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2023, '人员调配管理-根据派单号查询派单分配信息', '/api/admin/user/archives/allocation/detail_by_crm_no', 'URL', 34, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2024, '人员调配管理-调配', '/api/admin/user/archives/allocation/edit', 'URL', 34, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2025, '人员调配管理—自动调配', '/api/admin/user/archives/allocation/auto_edit', 'URL', 34, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2026, '批量调配', 'AllocateBatch', 'BUTTON', 34, 4, 'AUTH', '2025', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (2027, '人员档案管理-生成编号', '/api/admin/user/archives/create_code', 'URL', 33, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2028, '人员调配管理-发布', '/api/admin/user/archives/allocation/publish', 'URL', 34, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2029, '人员调配管理-撤销发布', '/api/admin/user/archives/allocation/un_publish', 'URL', 34, 7, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2030, '人员调配管理-查询空闲工程师', '/api/admin/user/archives/allocation/free_engineer', 'URL', 34, 8, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2031, '人员调配管理-查询空闲区域协调人', '/api/admin/user/archives/allocation/free_coordinator', 'URL', 34, 9, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2032, 'sop管理 - 设备出入库登记查询', '/api/admin/device/in/out/sop_page', 'URL', 43, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2033, '查询可出库的设备信息', '/api/admin/device/in/out/can_out_info', 'URL', 43, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2034, '查询可入库的设备信息', '/api/admin/device/in/out/can_in_info', 'URL', 43, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2035, '设备出入库提交', '/api/admin/device/in/out/submit', 'URL', 43, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2036, '资源保障-设备保障-出入库登记查询', '/api/admin/device/in/out/source_page', 'URL', 37, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2037, '考勤提交-分页查询', '/api/admin/tb/ding/submit/page', 'URL', 28, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2038, '考勤提交-小计', '/api/admin/tb/ding/submit/sub_total', 'URL', 28, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2039, '考勤提交-批量提交', '/api/admin/tb/ding/submit/submit_batch', 'URL', 28, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2040, '考勤提交-考勤撤回', '/api/admin/tb/ding/submit/apply_withdraw', 'URL', 28, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2041, '考勤提交-取消撤回', '/api/admin/tb/ding/submit/cancel_withdraw', 'URL', 28, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2042, '考勤提交-批量导出', '/api/admin/tb/ding/submit/export', 'URL', 28, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2043, '查询项目派单信息', '/api/admin/tb/crm/crm_project_info', 'URL', 64, 32, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2044, '考勤打卡信息', '/api/admin/tb/ding/ding_info', 'URL', 26, 1, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2045, '考勤结果统计', '/api/admin/tb/ding/ding_statistic', 'URL', 26, 2, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (2046, '考勤打卡保存', '/api/admin/tb/ding/ding_save', 'URL', 26, 3, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3000, '修改密码', '/api/admin/common/update_password', 'URL', 64, 13, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3001, '流程审批接口', '/api/admin/flow/approve', 'URL', 64, 14, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3002, '创建流程接口', '/api/admin/flow/createDeployment', 'URL', 64, 15, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3003, '结束流程接口', '/api/admin/flow/delete', 'URL', 64, 16, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3004, '获取流程部署信息接口', '/api/admin/flow/deployment/data', 'URL', 64, 17, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3005, '获取流程表单属性接口', '/api/admin/flow/form_properties/get', 'URL', 64, 18, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3006, '获取流程待办', '/api/admin/flow/task/list', 'URL', 64, 19, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3007, '流程转办接口', '/api/admin/flow/task/approver/exchange', 'URL', 64, 20, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3008, '上传流程接口', '/api/admin/flow/upload', 'URL', 64, 21, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3009, '获取流程详细信息接口', '/api/admin/flow/view', 'URL', 64, 22, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3010, '清除缓存接口', '/api/admin/common/cache_clear', 'URL', 3012, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3011, '超管菜单', 'adminManage', 'MENU', NULL, 10, NULL, NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3012, '清除缓存', 'cacheManage', 'MENU', 3011, 1, NULL, NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3013, '消息提醒规则', 'messageRuleManage', 'MENU', 3011, 2, NULL, NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3014, '清除缓存', 'Clear', 'BUTTON', 3012, 1, 'AUTH', '3010', 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3015, '查询枚举接口', '/api/admin/common/query_enum', 'URL', 64, 23, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3016, '角色权限查询接口', '/api/admin/role/privilege/list', 'URL', 16, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3017, '考勤异常申请接口', '/api/admin/ding/exception/apply/save', 'URL', 26, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3018, '根据角色类型获取所有用户', '/api/admin/common/get_user_list_by_role_type', 'URL', 64, 24, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3019, '考勤异常待审核接口', '/api/admin/ding/exception/apply/flow/task/un_done/list', 'URL', 26, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3020, '考勤异常已审核接口', '/api/admin/ding/exception/apply/flow/task/done/list', 'URL', 26, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3021, '考勤异常审核接口', '/api/admin/ding/exception/apply/flow/approve', 'URL', 26, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3022, '考勤异常批量审核接口', '/api/admin/ding/exception/apply/flow/batch/approve', 'URL', 26, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3023, '获取违规延期预警待办接口', '/api/admin/my/work_bench/warn/list', 'URL', 64, 25, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3024, '处理申请', 'Finish', 'LINK', 44, 1, 'AUTH', '3030,3031', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (3025, '项目变更计划申请接口', '/api/admin/project/exchange/save', 'URL', 40, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3026, '项目变更计划列表接口', '/api/admin/project/exchange/list', 'URL', 40, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3027, '流程控件查询接口', '/api/admin/widget/flow/select', 'URL', 64, 26, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3028, '控件查询列表接口', '/api/admin/widget/list', 'URL', 64, 27, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3029, '批量结束流程接口', '/api/admin/flow/batch/delete', 'URL', 64, 28, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3030, '项目变更计划审核接口', '/api/admin/project/exchange/flow/approve', 'URL', 40, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3031, '项目变更计划详情接口', '/api/admin/project/exchange/view', 'URL', 40, 4, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3032, '获取流程待办计数接口', '/api/admin/flow/task/list/count', 'URL', 64, 29, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3033, '获取违规/延期预警待办计数接口', '/api/admin/my/work_bench/warn/list/count', 'URL', 64, 30, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3034, 'sop元数据查询接口', '/api/admin/sop/metadata/list', 'URL', 40, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3035, 'sop元数据修改接口', '/api/admin/sop/metadata/save', 'URL', 40, 5, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3036, '获取流程版本信息接口', '/api/admin/flow/version/list', 'URL', 64, 31, 'SYS', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3037, '编辑', 'Edit', 'LINK', 41, 6, 'AUTH', '3047,3048', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (3038, '作废', 'Cancel', 'LINK', 41, 7, 'AUTH', '3045', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (3039, '编辑', 'Edit', 'LINK', 42, 6, 'AUTH', '3047,3048', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (3040, '作废', 'Cancel', 'LINK', 42, 7, 'AUTH', '3045', 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (3041, 'sop申请接口', '/api/admin/sop/apply', 'URL', 40, 6, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3042, 'sop填报接口', '/api/admin/sop/approve', 'URL', 40, 7, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3043, 'sop列表接口', '/api/admin/sop/list', 'URL', 40, 8, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3044, '质量问题反馈审核', '/api/admin/tb/quality/problem/apply/approve', 'URL', 21, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3045, 'sop作废', '/api/admin/sop/cancel', 'URL', 40, 9, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3046, 'sop批量作废', '/api/admin/sop/batch/cancel', 'URL', 40, 10, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3047, 'sop编辑', '/api/admin/sop/edit', 'URL', 40, 11, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (3048, 'sop保存 ', '/api/admin/sop/save', 'URL', 40, 12, 'AUTH', NULL, 1, 1, 0);

INSERT INTO `sys_role` VALUES (1, NULL, '系统管理员', 1, 'ADMIN', NULL, NULL, NULL, NULL, 1, '系统角色');
INSERT INTO `sys_role` VALUES (2, NULL, '总负责人', 1, 'PMO', NULL, NULL, NULL, NULL, 1, '系统角色');
INSERT INTO `sys_role` VALUES (3, NULL, '业务线负责人', 1, 'BUSSINESS', NULL, NULL, NULL, NULL, 1, '系统角色');
INSERT INTO `sys_role` VALUES (4, NULL, '大区经理', 1, 'REGION_MANAGER', NULL, NULL, NULL, NULL, 1, '系统角色');
INSERT INTO `sys_role` VALUES (5, NULL, '区域协调人', 1, 'REGION_COORDINATOR', NULL, NULL, NULL, NULL, 1, '外包角色');
INSERT INTO `sys_role` VALUES (6, NULL, '实施工程师', 1, 'EFFECT_ENGINEER', NULL, NULL, NULL, NULL, 1, '外包角色');
INSERT INTO `sys_role` VALUES (7, NULL, '助理工程师', 1, 'ASSISTANT_ENGINEER', NULL, NULL, NULL, NULL, 1, '外包角色');
INSERT INTO `sys_role` VALUES (8, NULL, 'QA', 1, 'QA', NULL, NULL, NULL, NULL, 1, '系统角色');
INSERT INTO `sys_role` VALUES (9, NULL, '技术客服', 1, 'CUSTOM', NULL, NULL, NULL, NULL, 1, '系统角色');
INSERT INTO `sys_role` VALUES (10, NULL, '客户经理', 1, 'ACCOUNT_MANAGER', NULL, NULL, NULL, NULL, 1, '系统角色');

INSERT INTO `sys_role_privilege` VALUES (1, 2, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (2, 2, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (3, 2, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (4, 2, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (5, 3, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (6, 3, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (7, 3, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (8, 3, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (9, 4, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (10, 4, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (11, 4, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (12, 4, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (13, 5, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (14, 5, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (15, 5, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (16, 5, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (17, 6, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (18, 6, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (19, 6, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (20, 6, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (21, 7, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (22, 7, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (23, 7, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (24, 7, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (25, 8, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (26, 8, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (27, 8, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (28, 8, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (29, 9, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (30, 9, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (31, 9, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (32, 9, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (33, 1, 11, 1);
INSERT INTO `sys_role_privilege` VALUES (34, 1, 12, 1);
INSERT INTO `sys_role_privilege` VALUES (35, 1, 13, 1);
INSERT INTO `sys_role_privilege` VALUES (36, 1, 14, 1);
INSERT INTO `sys_role_privilege` VALUES (37, 1, 15, 1);
INSERT INTO `sys_role_privilege` VALUES (38, 1, 16, 1);
INSERT INTO `sys_role_privilege` VALUES (39, 1, 17, 1);
INSERT INTO `sys_role_privilege` VALUES (40, 1, 18, 1);
INSERT INTO `sys_role_privilege` VALUES (41, 1, 1, 1);
INSERT INTO `sys_role_privilege` VALUES (42, 1, 2, 1);
INSERT INTO `sys_role_privilege` VALUES (43, 1, 3, 1);
INSERT INTO `sys_role_privilege` VALUES (44, 1, 4, 1);
INSERT INTO `sys_role_privilege` VALUES (45, 1, 5, 1);
INSERT INTO `sys_role_privilege` VALUES (46, 1, 6, 1);
INSERT INTO `sys_role_privilege` VALUES (47, 1, 7, 1);
INSERT INTO `sys_role_privilege` VALUES (48, 1, 8, 1);
INSERT INTO `sys_role_privilege` VALUES (49, 1, 9, 1);
INSERT INTO `sys_role_privilege` VALUES (50, 1, 10, 1);
INSERT INTO `sys_role_privilege` VALUES (51, 1, 49, 1);
INSERT INTO `sys_role_privilege` VALUES (52, 1, 50, 1);
INSERT INTO `sys_role_privilege` VALUES (53, 1, 51, 1);
INSERT INTO `sys_role_privilege` VALUES (54, 1, 52, 1);
INSERT INTO `sys_role_privilege` VALUES (55, 1, 53, 1);
INSERT INTO `sys_role_privilege` VALUES (56, 1, 54, 1);
INSERT INTO `sys_role_privilege` VALUES (57, 1, 55, 1);
INSERT INTO `sys_role_privilege` VALUES (58, 1, 56, 1);
INSERT INTO `sys_role_privilege` VALUES (59, 1, 57, 1);
INSERT INTO `sys_role_privilege` VALUES (60, 1, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (61, 1, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (62, 1, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (63, 1, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (64, 1, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (65, 1, 30, 1);
INSERT INTO `sys_role_privilege` VALUES (66, 1, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (67, 1, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (68, 1, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (69, 1, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (70, 1, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (71, 1, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (72, 1, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (73, 1, 46, 1);
INSERT INTO `sys_role_privilege` VALUES (74, 1, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (75, 1, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (76, 2, 49, 1);
INSERT INTO `sys_role_privilege` VALUES (77, 2, 50, 1);
INSERT INTO `sys_role_privilege` VALUES (78, 2, 51, 1);
INSERT INTO `sys_role_privilege` VALUES (79, 3, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (80, 2, 53, 1);
INSERT INTO `sys_role_privilege` VALUES (81, 2, 54, 1);
INSERT INTO `sys_role_privilege` VALUES (82, 2, 55, 1);
INSERT INTO `sys_role_privilege` VALUES (83, 2, 56, 1);
INSERT INTO `sys_role_privilege` VALUES (84, 3, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (85, 2, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (86, 2, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (87, 2, 33, 1);
INSERT INTO `sys_role_privilege` VALUES (88, 2, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (89, 3, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (90, 2, 36, 1);
INSERT INTO `sys_role_privilege` VALUES (91, 2, 37, 1);
INSERT INTO `sys_role_privilege` VALUES (92, 2, 38, 1);
INSERT INTO `sys_role_privilege` VALUES (93, 1, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (94, 1, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (95, 1, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (96, 1, 22, 1);
INSERT INTO `sys_role_privilege` VALUES (97, 1, 23, 1);
INSERT INTO `sys_role_privilege` VALUES (98, 2, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (99, 2, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (100, 2, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (101, 3, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (102, 3, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (103, 3, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (104, 2, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (105, 2, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (106, 2, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (107, 2, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (108, 2, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (109, 2, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (110, 2, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (111, 2, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (112, 2, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (113, 2, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (114, 2, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (115, 2, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (116, 3, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (117, 3, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (118, 3, 49, 1);
INSERT INTO `sys_role_privilege` VALUES (119, 3, 50, 1);
INSERT INTO `sys_role_privilege` VALUES (120, 3, 51, 1);
INSERT INTO `sys_role_privilege` VALUES (121, 3, 53, 1);
INSERT INTO `sys_role_privilege` VALUES (122, 3, 55, 1);
INSERT INTO `sys_role_privilege` VALUES (123, 3, 56, 1);
INSERT INTO `sys_role_privilege` VALUES (124, 3, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (125, 3, 33, 1);
INSERT INTO `sys_role_privilege` VALUES (126, 3, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (127, 3, 36, 1);
INSERT INTO `sys_role_privilege` VALUES (128, 3, 37, 1);
INSERT INTO `sys_role_privilege` VALUES (129, 3, 38, 1);
INSERT INTO `sys_role_privilege` VALUES (130, 2, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (131, 2, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (132, 3, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (133, 3, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (134, 3, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (135, 3, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (136, 3, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (137, 3, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (138, 3, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (139, 3, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (140, 3, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (141, 3, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (142, 4, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (143, 4, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (144, 4, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (145, 4, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (146, 4, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (147, 4, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (148, 4, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (149, 4, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (150, 4, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (151, 4, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (152, 4, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (153, 4, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (154, 4, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (155, 4, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (156, 4, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (157, 4, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (158, 4, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (159, 4, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (160, 4, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (161, 4, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (162, 5, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (163, 5, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (164, 5, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (165, 5, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (166, 5, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (167, 5, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (168, 5, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (169, 5, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (170, 5, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (171, 5, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (172, 5, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (173, 5, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (174, 5, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (175, 5, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (176, 5, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (177, 5, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (178, 5, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (179, 8, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (180, 8, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (181, 8, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (182, 8, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (183, 8, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (184, 8, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (185, 8, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (186, 8, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (187, 8, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (188, 8, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (189, 8, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (190, 8, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (191, 6, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (192, 6, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (193, 6, 26, 1);
INSERT INTO `sys_role_privilege` VALUES (194, 6, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (195, 6, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (196, 6, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (197, 6, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (198, 6, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (199, 6, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (200, 6, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (201, 9, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (202, 9, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (203, 9, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (10001, 1, 248, 1);
INSERT INTO `sys_role_privilege` VALUES (10002, 2, 248, 1);
INSERT INTO `sys_role_privilege` VALUES (10003, 2, 249, 1);
INSERT INTO `sys_role_privilege` VALUES (10004, 2, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (10005, 2, 252, 1);
INSERT INTO `sys_role_privilege` VALUES (10006, 2, 283, 1);
INSERT INTO `sys_role_privilege` VALUES (10007, 2, 284, 1);
INSERT INTO `sys_role_privilege` VALUES (10008, 2, 288, 1);
INSERT INTO `sys_role_privilege` VALUES (10009, 2, 289, 1);
INSERT INTO `sys_role_privilege` VALUES (10010, 2, 290, 1);
INSERT INTO `sys_role_privilege` VALUES (10011, 2, 18, 1);
INSERT INTO `sys_role_privilege` VALUES (10012, 1, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (10013, 1, 33, 1);
INSERT INTO `sys_role_privilege` VALUES (10014, 1, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (10015, 1, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (10016, 2, 3016, 1);
INSERT INTO `sys_role_privilege` VALUES (10017, 2, 1031, 1);
INSERT INTO `sys_role_privilege` VALUES (10018, 2, 3010, 1);
INSERT INTO `sys_role_privilege` VALUES (10019, 2, 3017, 1);
INSERT INTO `sys_role_privilege` VALUES (10020, 2, 3019, 1);
INSERT INTO `sys_role_privilege` VALUES (10021, 2, 3020, 1);
INSERT INTO `sys_role_privilege` VALUES (10022, 2, 3021, 1);
INSERT INTO `sys_role_privilege` VALUES (10023, 2, 3022, 1);
INSERT INTO `sys_role_privilege` VALUES (10024, 2, 3025, 1);
INSERT INTO `sys_role_privilege` VALUES (10025, 2, 3026, 1);
INSERT INTO `sys_role_privilege` VALUES (10026, 2, 3030, 1);
INSERT INTO `sys_role_privilege` VALUES (10027, 2, 3031, 1);
INSERT INTO `sys_role_privilege` VALUES (10028, 2, 3034, 1);
INSERT INTO `sys_role_privilege` VALUES (10029, 2, 3035, 1);
INSERT INTO `sys_role_privilege` VALUES (10030, 2, 3037, 1);
INSERT INTO `sys_role_privilege` VALUES (10031, 2, 3038, 1);
INSERT INTO `sys_role_privilege` VALUES (10032, 2, 3039, 1);
INSERT INTO `sys_role_privilege` VALUES (10033, 2, 3040, 1);
INSERT INTO `sys_role_privilege` VALUES (10034, 2, 3041, 1);
INSERT INTO `sys_role_privilege` VALUES (10035, 2, 3042, 1);
INSERT INTO `sys_role_privilege` VALUES (10036, 2, 3043, 1);
INSERT INTO `sys_role_privilege` VALUES (10037, 2, 3044, 1);
INSERT INTO `sys_role_privilege` VALUES (10038, 4, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (10039, 4, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (10040, 4, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (10041, 4, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (10042, 4, 49, 1);
INSERT INTO `sys_role_privilege` VALUES (10043, 4, 50, 1);
INSERT INTO `sys_role_privilege` VALUES (10044, 4, 51, 1);
INSERT INTO `sys_role_privilege` VALUES (10045, 4, 53, 1);
INSERT INTO `sys_role_privilege` VALUES (10046, 4, 54, 1);
INSERT INTO `sys_role_privilege` VALUES (10047, 4, 55, 1);
INSERT INTO `sys_role_privilege` VALUES (10048, 4, 56, 1);
INSERT INTO `sys_role_privilege` VALUES (10049, 4, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (10050, 4, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (10051, 4, 33, 1);
INSERT INTO `sys_role_privilege` VALUES (10052, 4, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (10053, 4, 36, 1);
INSERT INTO `sys_role_privilege` VALUES (10054, 4, 37, 1);
INSERT INTO `sys_role_privilege` VALUES (10055, 4, 38, 1);
INSERT INTO `sys_role_privilege` VALUES (10056, 4, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (10057, 4, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (10058, 4, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (10059, 4, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (10060, 4, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (10061, 4, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (10062, 4, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (10063, 4, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (10064, 4, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (10065, 4, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (10066, 4, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (10067, 4, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (10068, 4, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (10069, 4, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (10070, 4, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (10071, 4, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (10072, 4, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (10073, 4, 248, 1);
INSERT INTO `sys_role_privilege` VALUES (10074, 4, 249, 1);
INSERT INTO `sys_role_privilege` VALUES (10075, 4, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (10076, 4, 252, 1);
INSERT INTO `sys_role_privilege` VALUES (10077, 4, 283, 1);
INSERT INTO `sys_role_privilege` VALUES (10078, 4, 284, 1);
INSERT INTO `sys_role_privilege` VALUES (10079, 4, 288, 1);
INSERT INTO `sys_role_privilege` VALUES (10080, 4, 289, 1);
INSERT INTO `sys_role_privilege` VALUES (10081, 4, 290, 1);
INSERT INTO `sys_role_privilege` VALUES (10082, 4, 18, 1);
INSERT INTO `sys_role_privilege` VALUES (10083, 4, 3016, 1);
INSERT INTO `sys_role_privilege` VALUES (10084, 4, 1031, 1);
INSERT INTO `sys_role_privilege` VALUES (10085, 4, 3010, 1);
INSERT INTO `sys_role_privilege` VALUES (10086, 4, 3017, 1);
INSERT INTO `sys_role_privilege` VALUES (10087, 4, 3019, 1);
INSERT INTO `sys_role_privilege` VALUES (10088, 4, 3020, 1);
INSERT INTO `sys_role_privilege` VALUES (10089, 4, 3021, 1);
INSERT INTO `sys_role_privilege` VALUES (10090, 4, 3022, 1);
INSERT INTO `sys_role_privilege` VALUES (10091, 4, 3025, 1);
INSERT INTO `sys_role_privilege` VALUES (10092, 4, 3026, 1);
INSERT INTO `sys_role_privilege` VALUES (10093, 4, 3030, 1);
INSERT INTO `sys_role_privilege` VALUES (10094, 4, 3031, 1);
INSERT INTO `sys_role_privilege` VALUES (10095, 4, 3034, 1);
INSERT INTO `sys_role_privilege` VALUES (10096, 4, 3035, 1);
INSERT INTO `sys_role_privilege` VALUES (10097, 4, 3037, 1);
INSERT INTO `sys_role_privilege` VALUES (10098, 4, 3038, 1);
INSERT INTO `sys_role_privilege` VALUES (10099, 4, 3039, 1);
INSERT INTO `sys_role_privilege` VALUES (10100, 4, 3040, 1);
INSERT INTO `sys_role_privilege` VALUES (10101, 4, 3041, 1);
INSERT INTO `sys_role_privilege` VALUES (10102, 4, 3042, 1);
INSERT INTO `sys_role_privilege` VALUES (10103, 4, 3043, 1);
INSERT INTO `sys_role_privilege` VALUES (10104, 4, 3044, 1);
INSERT INTO `sys_role_privilege` VALUES (10105, 5, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (10106, 5, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (10107, 5, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (10108, 5, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (10109, 5, 49, 1);
INSERT INTO `sys_role_privilege` VALUES (10110, 5, 50, 1);
INSERT INTO `sys_role_privilege` VALUES (10111, 5, 51, 1);
INSERT INTO `sys_role_privilege` VALUES (10112, 5, 53, 1);
INSERT INTO `sys_role_privilege` VALUES (10113, 5, 54, 1);
INSERT INTO `sys_role_privilege` VALUES (10114, 5, 55, 1);
INSERT INTO `sys_role_privilege` VALUES (10115, 5, 56, 1);
INSERT INTO `sys_role_privilege` VALUES (10116, 5, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (10117, 5, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (10118, 5, 33, 1);
INSERT INTO `sys_role_privilege` VALUES (10119, 5, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (10120, 5, 36, 1);
INSERT INTO `sys_role_privilege` VALUES (10121, 5, 37, 1);
INSERT INTO `sys_role_privilege` VALUES (10122, 5, 38, 1);
INSERT INTO `sys_role_privilege` VALUES (10123, 5, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (10124, 5, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (10125, 5, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (10126, 5, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (10127, 5, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (10128, 5, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (10129, 5, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (10130, 5, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (10131, 5, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (10132, 5, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (10133, 5, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (10134, 5, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (10135, 5, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (10136, 5, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (10137, 5, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (10138, 5, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (10139, 5, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (10140, 5, 248, 1);
INSERT INTO `sys_role_privilege` VALUES (10141, 5, 249, 1);
INSERT INTO `sys_role_privilege` VALUES (10142, 5, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (10143, 5, 252, 1);
INSERT INTO `sys_role_privilege` VALUES (10144, 5, 283, 1);
INSERT INTO `sys_role_privilege` VALUES (10145, 5, 284, 1);
INSERT INTO `sys_role_privilege` VALUES (10146, 5, 288, 1);
INSERT INTO `sys_role_privilege` VALUES (10147, 5, 289, 1);
INSERT INTO `sys_role_privilege` VALUES (10148, 5, 290, 1);
INSERT INTO `sys_role_privilege` VALUES (10149, 5, 18, 1);
INSERT INTO `sys_role_privilege` VALUES (10150, 5, 3016, 1);
INSERT INTO `sys_role_privilege` VALUES (10151, 5, 1031, 1);
INSERT INTO `sys_role_privilege` VALUES (10152, 5, 3010, 1);
INSERT INTO `sys_role_privilege` VALUES (10153, 5, 3017, 1);
INSERT INTO `sys_role_privilege` VALUES (10154, 5, 3019, 1);
INSERT INTO `sys_role_privilege` VALUES (10155, 5, 3020, 1);
INSERT INTO `sys_role_privilege` VALUES (10156, 5, 3021, 1);
INSERT INTO `sys_role_privilege` VALUES (10157, 5, 3022, 1);
INSERT INTO `sys_role_privilege` VALUES (10158, 5, 3025, 1);
INSERT INTO `sys_role_privilege` VALUES (10159, 5, 3026, 1);
INSERT INTO `sys_role_privilege` VALUES (10160, 5, 3030, 1);
INSERT INTO `sys_role_privilege` VALUES (10161, 5, 3031, 1);
INSERT INTO `sys_role_privilege` VALUES (10162, 5, 3034, 1);
INSERT INTO `sys_role_privilege` VALUES (10163, 5, 3035, 1);
INSERT INTO `sys_role_privilege` VALUES (10164, 5, 3037, 1);
INSERT INTO `sys_role_privilege` VALUES (10165, 5, 3038, 1);
INSERT INTO `sys_role_privilege` VALUES (10166, 5, 3039, 1);
INSERT INTO `sys_role_privilege` VALUES (10167, 5, 3040, 1);
INSERT INTO `sys_role_privilege` VALUES (10168, 5, 3041, 1);
INSERT INTO `sys_role_privilege` VALUES (10169, 5, 3042, 1);
INSERT INTO `sys_role_privilege` VALUES (10170, 5, 3043, 1);
INSERT INTO `sys_role_privilege` VALUES (10171, 5, 3044, 1);
INSERT INTO `sys_role_privilege` VALUES (10172, 6, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (10173, 6, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (10174, 6, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (10175, 6, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (10176, 6, 49, 1);
INSERT INTO `sys_role_privilege` VALUES (10177, 6, 50, 1);
INSERT INTO `sys_role_privilege` VALUES (10178, 6, 51, 1);
INSERT INTO `sys_role_privilege` VALUES (10179, 6, 53, 1);
INSERT INTO `sys_role_privilege` VALUES (10180, 6, 54, 1);
INSERT INTO `sys_role_privilege` VALUES (10181, 6, 55, 1);
INSERT INTO `sys_role_privilege` VALUES (10182, 6, 56, 1);
INSERT INTO `sys_role_privilege` VALUES (10183, 6, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (10184, 6, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (10185, 6, 33, 1);
INSERT INTO `sys_role_privilege` VALUES (10186, 6, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (10187, 6, 36, 1);
INSERT INTO `sys_role_privilege` VALUES (10188, 6, 37, 1);
INSERT INTO `sys_role_privilege` VALUES (10189, 6, 38, 1);
INSERT INTO `sys_role_privilege` VALUES (10190, 6, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (10191, 6, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (10192, 6, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (10193, 6, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (10194, 6, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (10195, 6, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (10196, 6, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (10197, 6, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (10198, 6, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (10199, 6, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (10200, 6, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (10201, 6, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (10202, 6, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (10203, 6, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (10204, 6, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (10205, 6, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (10206, 6, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (10207, 6, 248, 1);
INSERT INTO `sys_role_privilege` VALUES (10208, 6, 249, 1);
INSERT INTO `sys_role_privilege` VALUES (10209, 6, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (10210, 6, 252, 1);
INSERT INTO `sys_role_privilege` VALUES (10211, 6, 283, 1);
INSERT INTO `sys_role_privilege` VALUES (10212, 6, 284, 1);
INSERT INTO `sys_role_privilege` VALUES (10213, 6, 288, 1);
INSERT INTO `sys_role_privilege` VALUES (10214, 6, 289, 1);
INSERT INTO `sys_role_privilege` VALUES (10215, 6, 290, 1);
INSERT INTO `sys_role_privilege` VALUES (10216, 6, 18, 1);
INSERT INTO `sys_role_privilege` VALUES (10217, 6, 3016, 1);
INSERT INTO `sys_role_privilege` VALUES (10218, 6, 1031, 1);
INSERT INTO `sys_role_privilege` VALUES (10219, 6, 3010, 1);
INSERT INTO `sys_role_privilege` VALUES (10220, 6, 3017, 1);
INSERT INTO `sys_role_privilege` VALUES (10221, 6, 3019, 1);
INSERT INTO `sys_role_privilege` VALUES (10222, 6, 3020, 1);
INSERT INTO `sys_role_privilege` VALUES (10223, 6, 3021, 1);
INSERT INTO `sys_role_privilege` VALUES (10224, 6, 3022, 1);
INSERT INTO `sys_role_privilege` VALUES (10225, 6, 3025, 1);
INSERT INTO `sys_role_privilege` VALUES (10226, 6, 3026, 1);
INSERT INTO `sys_role_privilege` VALUES (10227, 6, 3030, 1);
INSERT INTO `sys_role_privilege` VALUES (10228, 6, 3031, 1);
INSERT INTO `sys_role_privilege` VALUES (10229, 6, 3034, 1);
INSERT INTO `sys_role_privilege` VALUES (10230, 6, 3035, 1);
INSERT INTO `sys_role_privilege` VALUES (10231, 6, 3037, 1);
INSERT INTO `sys_role_privilege` VALUES (10232, 6, 3038, 1);
INSERT INTO `sys_role_privilege` VALUES (10233, 6, 3039, 1);
INSERT INTO `sys_role_privilege` VALUES (10234, 6, 3040, 1);
INSERT INTO `sys_role_privilege` VALUES (10235, 6, 3041, 1);
INSERT INTO `sys_role_privilege` VALUES (10236, 6, 3042, 1);
INSERT INTO `sys_role_privilege` VALUES (10237, 6, 3043, 1);
INSERT INTO `sys_role_privilege` VALUES (10238, 6, 3044, 1);
INSERT INTO `sys_role_privilege` VALUES (10239, 7, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (10240, 7, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (10241, 7, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (10242, 7, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (10243, 7, 49, 1);
INSERT INTO `sys_role_privilege` VALUES (10244, 7, 50, 1);
INSERT INTO `sys_role_privilege` VALUES (10245, 7, 51, 1);
INSERT INTO `sys_role_privilege` VALUES (10246, 7, 53, 1);
INSERT INTO `sys_role_privilege` VALUES (10247, 7, 54, 1);
INSERT INTO `sys_role_privilege` VALUES (10248, 7, 55, 1);
INSERT INTO `sys_role_privilege` VALUES (10249, 7, 56, 1);
INSERT INTO `sys_role_privilege` VALUES (10250, 7, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (10251, 7, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (10252, 7, 33, 1);
INSERT INTO `sys_role_privilege` VALUES (10253, 7, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (10254, 7, 36, 1);
INSERT INTO `sys_role_privilege` VALUES (10255, 7, 37, 1);
INSERT INTO `sys_role_privilege` VALUES (10256, 7, 38, 1);
INSERT INTO `sys_role_privilege` VALUES (10257, 7, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (10258, 7, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (10259, 7, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (10260, 7, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (10261, 7, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (10262, 7, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (10263, 7, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (10264, 7, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (10265, 7, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (10266, 7, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (10267, 7, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (10268, 7, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (10269, 7, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (10270, 7, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (10271, 7, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (10272, 7, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (10273, 7, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (10274, 7, 248, 1);
INSERT INTO `sys_role_privilege` VALUES (10275, 7, 249, 1);
INSERT INTO `sys_role_privilege` VALUES (10276, 7, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (10277, 7, 252, 1);
INSERT INTO `sys_role_privilege` VALUES (10278, 7, 283, 1);
INSERT INTO `sys_role_privilege` VALUES (10279, 7, 284, 1);
INSERT INTO `sys_role_privilege` VALUES (10280, 7, 288, 1);
INSERT INTO `sys_role_privilege` VALUES (10281, 7, 289, 1);
INSERT INTO `sys_role_privilege` VALUES (10282, 7, 290, 1);
INSERT INTO `sys_role_privilege` VALUES (10283, 7, 18, 1);
INSERT INTO `sys_role_privilege` VALUES (10284, 7, 3016, 1);
INSERT INTO `sys_role_privilege` VALUES (10285, 7, 1031, 1);
INSERT INTO `sys_role_privilege` VALUES (10286, 7, 3010, 1);
INSERT INTO `sys_role_privilege` VALUES (10287, 7, 3017, 1);
INSERT INTO `sys_role_privilege` VALUES (10288, 7, 3019, 1);
INSERT INTO `sys_role_privilege` VALUES (10289, 7, 3020, 1);
INSERT INTO `sys_role_privilege` VALUES (10290, 7, 3021, 1);
INSERT INTO `sys_role_privilege` VALUES (10291, 7, 3022, 1);
INSERT INTO `sys_role_privilege` VALUES (10292, 7, 3025, 1);
INSERT INTO `sys_role_privilege` VALUES (10293, 7, 3026, 1);
INSERT INTO `sys_role_privilege` VALUES (10294, 7, 3030, 1);
INSERT INTO `sys_role_privilege` VALUES (10295, 7, 3031, 1);
INSERT INTO `sys_role_privilege` VALUES (10296, 7, 3034, 1);
INSERT INTO `sys_role_privilege` VALUES (10297, 7, 3035, 1);
INSERT INTO `sys_role_privilege` VALUES (10298, 7, 3037, 1);
INSERT INTO `sys_role_privilege` VALUES (10299, 7, 3038, 1);
INSERT INTO `sys_role_privilege` VALUES (10300, 7, 3039, 1);
INSERT INTO `sys_role_privilege` VALUES (10301, 7, 3040, 1);
INSERT INTO `sys_role_privilege` VALUES (10302, 7, 3041, 1);
INSERT INTO `sys_role_privilege` VALUES (10303, 7, 3042, 1);
INSERT INTO `sys_role_privilege` VALUES (10304, 7, 3043, 1);
INSERT INTO `sys_role_privilege` VALUES (10305, 7, 3044, 1);
INSERT INTO `sys_role_privilege` VALUES (10306, 8, 58, 1);
INSERT INTO `sys_role_privilege` VALUES (10307, 8, 59, 1);
INSERT INTO `sys_role_privilege` VALUES (10308, 8, 60, 1);
INSERT INTO `sys_role_privilege` VALUES (10309, 8, 61, 1);
INSERT INTO `sys_role_privilege` VALUES (10310, 8, 49, 1);
INSERT INTO `sys_role_privilege` VALUES (10311, 8, 50, 1);
INSERT INTO `sys_role_privilege` VALUES (10312, 8, 51, 1);
INSERT INTO `sys_role_privilege` VALUES (10313, 8, 53, 1);
INSERT INTO `sys_role_privilege` VALUES (10314, 8, 54, 1);
INSERT INTO `sys_role_privilege` VALUES (10315, 8, 55, 1);
INSERT INTO `sys_role_privilege` VALUES (10316, 8, 56, 1);
INSERT INTO `sys_role_privilege` VALUES (10317, 8, 31, 1);
INSERT INTO `sys_role_privilege` VALUES (10318, 8, 32, 1);
INSERT INTO `sys_role_privilege` VALUES (10319, 8, 33, 1);
INSERT INTO `sys_role_privilege` VALUES (10320, 8, 34, 1);
INSERT INTO `sys_role_privilege` VALUES (10321, 8, 36, 1);
INSERT INTO `sys_role_privilege` VALUES (10322, 8, 37, 1);
INSERT INTO `sys_role_privilege` VALUES (10323, 8, 38, 1);
INSERT INTO `sys_role_privilege` VALUES (10324, 8, 24, 1);
INSERT INTO `sys_role_privilege` VALUES (10325, 8, 25, 1);
INSERT INTO `sys_role_privilege` VALUES (10326, 8, 27, 1);
INSERT INTO `sys_role_privilege` VALUES (10327, 8, 39, 1);
INSERT INTO `sys_role_privilege` VALUES (10328, 8, 40, 1);
INSERT INTO `sys_role_privilege` VALUES (10329, 8, 41, 1);
INSERT INTO `sys_role_privilege` VALUES (10330, 8, 42, 1);
INSERT INTO `sys_role_privilege` VALUES (10331, 8, 43, 1);
INSERT INTO `sys_role_privilege` VALUES (10332, 8, 44, 1);
INSERT INTO `sys_role_privilege` VALUES (10333, 8, 45, 1);
INSERT INTO `sys_role_privilege` VALUES (10334, 8, 47, 1);
INSERT INTO `sys_role_privilege` VALUES (10335, 8, 48, 1);
INSERT INTO `sys_role_privilege` VALUES (10336, 8, 19, 1);
INSERT INTO `sys_role_privilege` VALUES (10337, 8, 20, 1);
INSERT INTO `sys_role_privilege` VALUES (10338, 8, 21, 1);
INSERT INTO `sys_role_privilege` VALUES (10339, 8, 28, 1);
INSERT INTO `sys_role_privilege` VALUES (10340, 8, 29, 1);
INSERT INTO `sys_role_privilege` VALUES (10341, 8, 248, 1);
INSERT INTO `sys_role_privilege` VALUES (10342, 8, 249, 1);
INSERT INTO `sys_role_privilege` VALUES (10343, 8, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (10344, 8, 252, 1);
INSERT INTO `sys_role_privilege` VALUES (10345, 8, 283, 1);
INSERT INTO `sys_role_privilege` VALUES (10346, 8, 284, 1);
INSERT INTO `sys_role_privilege` VALUES (10347, 8, 288, 1);
INSERT INTO `sys_role_privilege` VALUES (10348, 8, 289, 1);
INSERT INTO `sys_role_privilege` VALUES (10349, 8, 290, 1);
INSERT INTO `sys_role_privilege` VALUES (10350, 8, 18, 1);
INSERT INTO `sys_role_privilege` VALUES (10351, 8, 3016, 1);
INSERT INTO `sys_role_privilege` VALUES (10352, 8, 1031, 1);
INSERT INTO `sys_role_privilege` VALUES (10353, 8, 3010, 1);
INSERT INTO `sys_role_privilege` VALUES (10354, 8, 3017, 1);
INSERT INTO `sys_role_privilege` VALUES (10355, 8, 3019, 1);
INSERT INTO `sys_role_privilege` VALUES (10356, 8, 3020, 1);
INSERT INTO `sys_role_privilege` VALUES (10357, 8, 3021, 1);
INSERT INTO `sys_role_privilege` VALUES (10358, 8, 3022, 1);
INSERT INTO `sys_role_privilege` VALUES (10359, 8, 3025, 1);
INSERT INTO `sys_role_privilege` VALUES (10360, 8, 3026, 1);
INSERT INTO `sys_role_privilege` VALUES (10361, 8, 3030, 1);
INSERT INTO `sys_role_privilege` VALUES (10362, 8, 3031, 1);
INSERT INTO `sys_role_privilege` VALUES (10363, 8, 3034, 1);
INSERT INTO `sys_role_privilege` VALUES (10364, 8, 3035, 1);
INSERT INTO `sys_role_privilege` VALUES (10365, 8, 3037, 1);
INSERT INTO `sys_role_privilege` VALUES (10366, 8, 3038, 1);
INSERT INTO `sys_role_privilege` VALUES (10367, 8, 3039, 1);
INSERT INTO `sys_role_privilege` VALUES (10368, 8, 3040, 1);
INSERT INTO `sys_role_privilege` VALUES (10369, 8, 3041, 1);
INSERT INTO `sys_role_privilege` VALUES (10370, 8, 3042, 1);
INSERT INTO `sys_role_privilege` VALUES (10371, 8, 3043, 1);
INSERT INTO `sys_role_privilege` VALUES (10372, 8, 3044, 1);
INSERT INTO `sys_role_privilege` VALUES (10373, 2, 3045, 1);
INSERT INTO `sys_role_privilege` VALUES (10374, 4, 3045, 1);
INSERT INTO `sys_role_privilege` VALUES (10375, 5, 3045, 1);
INSERT INTO `sys_role_privilege` VALUES (10376, 6, 3045, 1);
INSERT INTO `sys_role_privilege` VALUES (10377, 7, 3045, 1);
INSERT INTO `sys_role_privilege` VALUES (10378, 8, 3045, 1);
INSERT INTO `sys_role_privilege` VALUES (10379, 2, 3045, 1);
INSERT INTO `sys_role_privilege` VALUES (10380, 2, 3046, 1);
INSERT INTO `sys_role_privilege` VALUES (10381, 2, 3047, 1);
INSERT INTO `sys_role_privilege` VALUES (10382, 2, 3048, 1);

INSERT INTO `sys_user` VALUES (1, 'sysadmin', 'sysadmin', NULL, 'MTIzNDU2', NULL, NULL, NULL, 1, 1, 1629353956868, NULL, 'SYSTEM', NULL, NULL, 1, 1692077912643);
INSERT INTO `sys_user` VALUES (2, 'admin1', 'admin-test1', NULL, 'MTIzNDU2', '18008659246', 419897427273711616, 'MAN', 1, 1, 1629353956868, NULL, 'SYSTEM', NULL, NULL, 2, 1691483491942);

INSERT INTO `sys_user_role` VALUES (1, 1, 1, NULL, 1);
INSERT INTO `sys_user_role` VALUES (2, 2, 2, NULL, 1);

INSERT INTO `t_d_form_widget` VALUES (1, 'TEXT', 'FORM', 'problem_point', 'problem_point', '问题简要', 'STRING', 1, 0, 1, 1, NULL, 30, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (2, 'TEXTAREA', 'FORM', 'problem_remark', 'problem_remark', '问题情况说明', 'STRING', 1, 0, 1, 1, NULL, 300, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (3, 'FILE', 'FORM', 'attachments_info', 'attachments_info', '附件说明', 'FILE', 0, 0, 1, 1, NULL, 3, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (4, 'TEXT', 'FORM', 'verify_point', 'verify_point', '核实情况简要', 'STRING', 1, 0, 1, 1, NULL, 50, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (5, 'TEXTAREA', 'FORM', 'verify_remark', 'verify_remark', '核实情况备注', 'STRING', 1, 0, 1, 1, NULL, 500, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (6, 'RADIO', 'FORM', 'problem_type', 'problem_type', '质量问题类型', 'ENUM', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"UPDATE\",\"label\":\"修正类\"},{\"value\":\"OPTIMIZE\",\"label\":\"优化类\"},{\"value\":\"NO_PROBLEM\",\"label\":\"不是问题\"}]', 'QUALITY_PROBLEM_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (7, 'RADIO', 'FORM', 'problem_reason_radio', 'problem_reason_radio', '问题归因', 'ENUM', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"EXEC\",\"label\":\"执行类\"},{\"value\":\"MANAGER\",\"label\":\"管理协调类\"},{\"value\":\"PRODUCT_PROBLEM\",\"label\":\"产品缺陷类\"},{\"value\":\"PRODUCT_MANAGER\",\"label\":\"产品运维类\"},{\"value\":\"FLOW\",\"label\":\"流程制度类\"},{\"value\":\"OTHER\",\"label\":\"其它\"}]', 'QUALITY_PROBLEM_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (8, 'RADIO', 'FORM', 'problem_degree_radio', 'problem_degree_radio', '影响度', 'ENUM', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"A\",\"label\":\"A级\"},{\"value\":\"B\",\"label\":\"B级\"},{\"value\":\"C\",\"label\":\"C级\"},{\"value\":\"D\",\"label\":\"D级\"}]', 'QUALITY_PROBLEM_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (9, 'POP_SELECT', 'FORM', 'problem_users', 'problem_users', '责任人', 'ARRAY', 0, 0, 1, 1, NULL, NULL, NULL, '/api/admin/common/get_user_list', NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (10, 'POP_SELECT', 'FORM', 'approve_check_users', 'approve_check_users', '甲方复审人员', 'ARRAY', 1, 0, 1, 1, NULL, NULL, NULL, '/api/admin/common/get_user_list', NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (11, 'POP_SELECT', 'FORM', 'approve_check_third_users', 'approve_check_third_users', '乙方复审人员', 'ARRAY', 0, 0, 1, 1, NULL, NULL, NULL, '/api/admin/common/get_user_list', NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (12, 'RADIO', 'FORM', 'approve_radio', 'approve_radio', '审批意见', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"同意\"},{\"value\":\"0\",\"label\":\"不同意\"}]', 'QUALITY_PROBLEM_FLOW', 3, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (13, 'SIGN', 'FORM', 'sign', 'sign', '添加签名', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 3, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (14, 'TEXTAREA', 'FORM', 'approve_remark', 'approve_remark', '备注', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 3, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (15, 'RADIO', 'FORM', 'approve_radio', 'approve_radio', '审批意见', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"同意\"},{\"value\":\"0\",\"label\":\"不同意\"}]', 'QUALITY_PROBLEM_FLOW', 4, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (16, 'SIGN', 'FORM', 'sign', 'sign', '添加签名', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 4, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (17, 'TEXTAREA', 'FORM', 'approve_remark', 'approve_remark', '备注', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'QUALITY_PROBLEM_FLOW', 4, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (18, 'FORM_GROUP_TITLE', 'FORM', 'project_basic_info_title', 'project_basic_info_title', '项目基本信息', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (19, 'NUMBER', 'FORM', 'course_count', 'course_count', '科目数量', 'INT', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (20, 'NUMBER', 'FORM', 'exam_student_course_count', 'exam_student_course_count', '考生科次', 'INT', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (21, 'NUMBER', 'FORM', 'scan_count', 'scan_count', '扫描仪数量(台)', 'INT', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (22, 'NUMBER', 'FORM', 'week_people_day', 'week_people_day', '现场标准服务周期（人天）', 'INT', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (23, 'DATE', 'FORM', 'exam_student_Internal_date', 'exam_student_Internal_date', '考生数据内部交接时间', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (24, 'DATE', 'FORM', 'exam_plan_date', 'exam_plan_date', '考试时间安排表获取时间', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (25, 'DATE', 'FORM', 'project_key_info_date', 'project_key_info_date', '项目关键信息提交截止时间', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (26, 'DATE', 'FORM', 'service_finish_plan_date', 'service_finish_plan_date', '现场服务完成撤场计划时间', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (27, 'FORM_GROUP_TITLE', 'FORM', 'project_people_plan_title', 'project_people_plan_title', '项目人员安排及风险预估', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (28, 'TEXT', 'FORM', 'region_user_id', 'region_user_id', '区域协调人', 'STRING', 1, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (29, 'SINGLE_SELECT', 'FORM', 'engineer_user_id', 'engineer_user_id', '实施工程师', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (30, 'MULTIPLE_SELECT', 'FORM', 'assistant_engineer_user_id', 'assistant_engineer_user_id', '助理实施工程师', 'ARRAY', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (31, 'ONLE_TITLE', 'FORM', 'project_rish_title', 'project_rish_title', '项目风险预估（仅供参考）', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (32, 'CHECKBOX', 'FORM', 'delay_rish_cb', 'delay_rish_cb', '延期风险', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"LOW\",\"label\":\"低\"},{\"value\":\"MIDDLE\",\"label\":\"中\"},{\"value\":\"HIGH\",\"label\":\"高\"}]', 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (33, 'CHECKBOX', 'FORM', 'engineer_rish_cb', 'engineer_rish_cb', '实施难度', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"LOW\",\"label\":\"低\"},{\"value\":\"MIDDLE\",\"label\":\"中\"},{\"value\":\"HIGH\",\"label\":\"高\"}]', 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (34, 'TEXTAREA', 'FORM', 'other_remark', 'other_remark', '其它备注（建议关注的其它方面）', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (35, 'FORM_GROUP_TITLE', 'FORM', 'project_contacts_title', 'project_contacts_title', '项目联系人', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (36, 'TABLE', 'FORM', 'project_contacts_table', 'project_contacts_table', '项目联系人表格', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (37, 'TEXT', 'TABLE', 'school_college', 'school_college', '项目联系人表格_机构输入框', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (38, 'TEXT', 'TABLE', 'school_name', 'school_name', '项目联系人表格_姓名输入框', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (39, 'TEXT', 'TABLE', 'school_job', 'school_job', '项目联系人表格_职务输入框', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (40, 'TEXT', 'TABLE', 'school_tel', 'school_tel', '项目联系人表格_电话输入框', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 1, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (41, 'FORM_GROUP_TITLE', 'FORM', 'cloud_mark_title', 'cloud_mark_title', '云阅卷（填写前请先认真查阅移交的项目初审及项目基本信息）', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (42, 'RADIO', 'FORM', 'deploy_way_radio', 'deploy_way_radio', '部署方式', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"ONLINE\",\"label\":\"线上部署\"},{\"value\":\"LOCAL\",\"label\":\"本地部署\"}]', 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (43, 'RADIO', 'FORM', 'mark_way_radio', 'mark_way_radio', '阅卷方式', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"TOGETHER\",\"label\":\"集中阅卷\"},{\"value\":\"ANYTIME\",\"label\":\"分散阅卷\"}]', 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (44, 'RADIO', 'FORM', 'scan_net_radio', 'scan_net_radio', '扫描场地网络情况', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"INTERNET\",\"label\":\"提供外网\"},{\"value\":\"LOCALHOST\",\"label\":\"不提供外网\"}]', 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (45, 'DATE', 'FORM', 'scan_start_time', 'scan_start_time', '扫描开始时间', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (46, 'DATE', 'FORM', 'scan_end_time', 'scan_end_time', '扫描结束时间', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (47, 'DATE', 'FORM', 'mark_start_time', 'mark_start_time', '评卷开始时间', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (48, 'DATE', 'FORM', 'mark_end_time', 'mark_end_time', '评卷结束时间', 'LONG', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (49, 'TEXTAREA', 'FORM', 'remark', 'remark', '其它特殊要求', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (50, 'FILE', 'FORM', 'exam_plan_photos', 'exam_plan_photos', '考试时间安排表拍照上传', 'ARRAY', 1, 0, 1, 1, NULL, 5, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 2, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (51, 'FORM_GROUP_TITLE', 'FORM', 'inside_title', 'inside_title', '项目内审（请于24小时内完成内审', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 3, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (52, 'RADIO', 'FORM', 'approve_radio', 'approve_radio', '我对以上项目关键信息已审核，确认内容无误：', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"同意\"},{\"value\":\"0\",\"label\":\"不同意\"}]', 'OFFICE_SOP_FLOW', 3, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (53, 'SIGN', 'FORM', 'sign', 'sign', '添加签名', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, 'OFFICE_SOP_FLOW', 3, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (54, 'TEXTAREA', 'FORM', 'approve_remark', 'approve_remark', '审批意见', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 3, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (55, 'ONLE_TITLE', 'FORM', 'device_in_out_label', 'device_in_out_label', '设备出库', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 5, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (56, 'DATE', 'FORM', 'device_out_time', 'device_out_time', '设备出库时间', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 5, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (57, 'DEVICE_OUT_TABLE', 'FORM', 'device_out_table', 'device_out_table', '设备出库表格', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 5, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (58, 'FORM_GROUP_TITLE', 'FORM', 'import_data_title', 'import_data_title', '导入数据', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 6, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (59, 'CHECKBOX', 'FORM', 'data_same', 'data_same', '导入数据', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, '[{\"value\":\"true\",\"label\":\"导入数据与原始数据是否一致\"}]', 'OFFICE_SOP_FLOW', 6, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (60, 'TEXT', 'FORM', 'import_exam_student_count', 'import_exam_student_count', '导入考生数量', 'INT', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, 'OFFICE_SOP_FLOW', 6, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (61, 'FORM_GROUP_TITLE', 'FORM', 'scan_set_title', 'scan_set_title', '扫描仪设置', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 6, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (62, 'CHECKBOX', 'FORM', 'scan_set_cb', 'scan_set_cb', '扫描仪设置', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"1、扫描仪分辨率设置是否150、扫描模式是否双面、图像类型是否灰度\"},{\"value\":\"2\",\"label\":\"2、选择“扫描模式”-“设置”-“装订边缘”-“上”\"}]', 'OFFICE_SOP_FLOW', 6, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (63, 'FORM_GROUP_TITLE', 'FORM', 'card_format_title', 'card_format_title', '卡格式制作', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 6, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (64, 'CHECKBOX', 'FORM', 'card_format_cb', 'card_format_cb', '卡格式制作', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"1、定位点、校验点是否制作\"},{\"value\":\"2\",\"label\":\"2、缺考区域是否框选\"},{\"value\":\"3\",\"label\":\"3、客观题区域是否正确框选、行列以及单选多选是否正确\"},{\"value\":\"4\",\"label\":\"4、条码识别区是否制作\"},{\"value\":\"5\",\"label\":\"5、屏蔽区是否制作\"},{\"value\":\"6\",\"label\":\"6、卷型：若有，则框选\"},{\"value\":\"7\",\"label\":\"7、页码：若答题卡超过1张，则框选\"}]', 'OFFICE_SOP_FLOW', 6, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (65, 'FORM_GROUP_TITLE', 'FORM', 'scan_test_title', 'scan_test_title', '试扫检查', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 7, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (66, 'CHECKBOX', 'FORM', 'scan_test_cb', 'scan_test_cb', '试扫检查', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"1、查看条码是否识别正确\"},{\"value\":\"2\",\"label\":\"2、缺考、客观题是否识别正确\"},{\"value\":\"3\",\"label\":\"3、扫描原图正反面是否正确显示\"},{\"value\":\"4\",\"label\":\"4、裁切图屏蔽区是否正确\"},{\"value\":\"5\",\"label\":\"5、卷型：若有，是否识别正确\"},{\"value\":\"6\",\"label\":\"6、页码：若答题卡超过1张，是否页码识别正确\"}]', 'OFFICE_SOP_FLOW', 7, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (67, 'FORM_GROUP_TITLE', 'FORM', 'un_upload_exam_student_title', 'un_upload_exam_student_title', '未上传考生核对', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (68, 'CHECKBOX', 'FORM', 'un_upload_exam_student_cb', 'un_upload_exam_student_cb', '未上传考生核对', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 9, NULL, '[{\"value\":\"1\",\"label\":\"1、未上传考生是否与签到表进行核对，是否为缺考、违纪、免考等情况\"},{\"value\":\"2\",\"label\":\"2、是否将未上传考生发给学校确认\"}]', 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (69, 'TEXT', 'FORM', 'finish_count', 'finish_count', '完成数量', 'INT', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (70, 'FILE', 'FORM', 'upload_file_un_upload_exam_student_photo', 'upload_file_un_upload_exam_student_photo', '上传学校未上传考生沟通确认截图', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (71, 'FORM_GROUP_TITLE', 'FORM', 'Identify_title', 'Identify_title', '识别对照', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (72, 'CHECKBOX', 'FORM', 'Identify_cb', 'Identify_cb', '识别对照', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"true\",\"label\":\"是否将客观题识别异常的全部人工修改处理\"}]', 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (73, 'FORM_GROUP_TITLE', 'FORM', 'absent_exam_student_title', 'absent_exam_student_title', '缺考名单比对', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (74, 'CHECKBOX', 'FORM', 'absent_exam_student_cb', 'absent_exam_student_cb', '缺考名单比对', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"true\",\"label\":\"核对未上传条数是否与学校提供的缺考名单吻合，人工指定为缺考（考生管理>导入名单>导入缺考名单）\"}]', 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (75, 'TEXT', 'FORM', 'absent_count', 'absent_count', '缺考科次数量', 'INT', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (76, 'FORM_GROUP_TITLE', 'FORM', 'manual_code_title', 'manual_code_title', '手工输入条码确认', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (77, 'CHECKBOX', 'FORM', 'manual_code_cb', 'manual_code_cb', '手工输入条码确认', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"true\",\"label\":\"“数据检查” -“人工确认”，“确认完成”}]', 'OFFICE_SOP_FLOW', 8, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (78, 'FORM_GROUP_TITLE', 'FORM', 'mark_model_title', 'mark_model_title', '评卷模式确认', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 9, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (79, 'RADIO', 'FORM', 'mark_model_radio', 'mark_model_radio', '评卷模式', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"TRAIL\",\"label\":\"轨迹模式\"},{\"value\":\"NORMAL\",\"label\":\"普通模式\"}]', 'OFFICE_SOP_FLOW', 9, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (80, 'FORM_GROUP_TITLE', 'FORM', 'mark_params_title', 'mark_params_title', '评卷参数核对', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 9, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (81, 'CHECKBOX', 'FORM', 'mark_params_cb', 'mark_params_cb', '评卷参数核对', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"1、核查每个科目的满分是否正确（大部分科目都是100分）\"},{\"value\":\"2\",\"label\":\"2、核对客观题标答以及分数是否录入正确、多选题判分规则（漏选是否得分、任选得分）\"},{\"value\":\"3\",\"label\":\"检查所有科目结构和分组是否全部导入。（评卷管理>评卷进度查看分组状态）\"}]', 'OFFICE_SOP_FLOW', 9, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (82, 'FORM_GROUP_TITLE', 'FORM', 'mark_submit_title', 'mark_submit_title', '成绩提交核查', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 10, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (83, 'CHECKBOX', 'FORM', 'mark_submit_cb', 'mark_submit_cb', '成绩提交核查', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"1、是否已核对不缺考、客观题为0分的情况\"},{\"value\":\"2\",\"label\":\"2、是否已核对主观题为0、客观题有分的情况\"},{\"value\":\"3\",\"label\":\"3、是否检查客观题小题得分率低于20%的情况\"},{\"value\":\"4\",\"label\":\"4、核对导出成绩表数据条数是否与考生表数量一致，不能带有“未导出全量数据”字样；请填写导出成绩数量以及完成时间\"},{\"value\":\"5\",\"label\":\"5、核对导出图片工具是否正常运行\"}]', 'OFFICE_SOP_FLOW', 10, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (84, 'FILE', 'FORM', 'upload_success_photos', 'upload_success_photos', '上传验收报告(纸质)拍照', 'ARRAY', 0, 0, 1, 1, NULL, 5, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 10, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (85, 'ONLE_TITLE', 'FORM', 'device_in_out_label', 'device_in_out_label', '设备入库', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, 'OFFICE_SOP_FLOW', 11, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (86, 'DATE', 'FORM', 'device_in_time', 'device_in_time', '设备入库时间', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, 'yyyy-MM-dd', 6, NULL, NULL, 'OFFICE_SOP_FLOW', 11, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (87, 'DEVICE_IN_TABLE', 'FORM', 'device_in_table', 'device_in_table', '设备入库表格', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 11, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (88, 'FORM_GROUP_TITLE', 'FORM', 'inside_title', 'inside_title', '项目内审（请于24小时内完成内审', 'STRING', 0, 1, 0, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 4, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (89, 'RADIO', 'FORM', 'approve_radio', 'approve_radio', '我对以上项目关键信息已审核，确认内容无误：', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, '[{\"value\":\"1\",\"label\":\"同意\"},{\"value\":\"0\",\"label\":\"不同意\"}]', 'OFFICE_SOP_FLOW', 4, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (90, 'SIGN', 'FORM', 'sign', 'sign', '添加签名', 'STRING', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, 'OFFICE_SOP_FLOW', 4, 0, 1, 1);
INSERT INTO `t_d_form_widget` VALUES (91, 'TEXTAREA', 'FORM', 'approve_remark', 'approve_remark', '审批意见', 'STRING', 0, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, 'OFFICE_SOP_FLOW', 4, 0, 1, 1);
